# Pipelines installer

## CLI usage

```
  Usage:
    ./pipelines <command> [flags]

  Examples:
    ./pipelines install

  Commands:
    install                 Run Pipelines installation
      --installer-ip                       Internal IP of the host [mandatory]
      --base-url-ui                        Unified UI URL
      --artifactory-joinkey                Join key to connect with Artifactory [mandatory]
      --api-url                            Use provided url for API [mandatory]
      --base-url                           Internal Artifactory URL
      --global-password                    Set one password for all services (db, rabbitmq, pipelines). Can be changed later
      --install-user                       User (and Group) that owns the installer generated files and folders ($USER by default) e.g. obie, obie:obie, 1001:obie, 1002:1002
      --artifactory-proxy                  Proxy server to use for connecting to Artifactory
      --artifactory-proxy-username         User for the proxy server
      --artifactory-proxy-password         Password for proxy server
      --artifactory-service-id             Service Id to register with Artifactory. Format "jft@<id>"
      --image-registry-url                 Docker registry url for Pipelines component images
      --image-registry-creds               Path to a file containing Docker credentials for the image registry as an alternative to --image-registry-url
      --build-image-registry-url           Docker registry url for images used by default in Pipelines steps
      --state-bucket                       Root bucket name for storing state
      --skip-image-pull                    Do not pull images
      --db-connection-string               A connection string to use an existing Postgres database
      --no-verify-ssl                      If true, pass -no-verify-ssl flag to services
      --global-http-proxy                  HTTP proxy to be used in Pipelines in place of any proxy information fetched from Artifactory
      --global-https-proxy                 HTTPS proxy to be used in Pipelines in place of any proxy information fetched from Artifactory
      --global-no-proxy                    No proxy settings to be used in Pipelines in place of any proxy information fetched from Artifactory
      --access-control-allow-origins       API will return these as allowed origins. A comma-separated list of origins should be provided.
      --disable-call-home                  Disable call home functionality
      --enable-call-home                   Enables call home functionality if previously disabled
      --rabbitmq-health-check-interval     RabbitMQ health check interval in mins
      --artifactory-health-check-interval  Artifactory health check interval in mins
      --db-health-check-interval           DB health check interval in mins
      --vault-url                          An existing vault URL
      --vault-root-token                   Root token of the vault
      --config-backup-count                Number of upgrades for which to keep backup configurations
    upgrade                 Upgrade current installation
    restart                 Restart Pipelines
    clean                   Remove Pipelines components and files
    info                    Print information about current installation on console
      -j | --json                    Print info as json
    version                 Print current installation control and build plane versions
      -j | --json                    Print info as json
    help                    Print this message
```
## Installation

### Onebox

- Provision an instance on GCP/EC2 (only Ubuntu 16.04 and CentOS 7 supported right now)

```
############# Ubuntu 16.04 - Install docker ################
# Install docker using instructions: https://docs.docker.com/install/linux/docker-ce/ubuntu/#install-using-the-repository OR follow instructions below

$ sudo apt-get update
$ sudo apt-get install -y \
    apt-transport-https \
    ca-certificates \
    curl \
    software-properties-common
$ curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
$ sudo add-apt-repository \
   "deb [arch=amd64] https://download.docker.com/linux/ubuntu \
   $(lsb_release -cs) \
   stable"
$ sudo apt-get update
$ sudo apt-get install -y docker-ce=5:18.09.5~3-0~ubuntu-xenial

############# Centos 7.6 - Install docker ################
$ sudo yum install -y yum-utils \
  device-mapper-persistent-data \
  lvm2
$ sudo yum-config-manager \
    --add-repo \
    https://download.docker.com/linux/centos/docker-ce.repo
$ sudo yum -y install docker-ce-18.06.3.ce-3.el7
$ sudo yum -y install containerd.io
$ sudo systemctl start docker

############# Install docker compose ###########

$ sudo wget "https://github.com/docker/compose/releases/download/1.24.0/docker-compose-$(uname -s)-$(uname -m)" -O /usr/local/bin/docker-compose
$ sudo chmod +x /usr/local/bin/docker-compose

############# Get Installer  ################
## Configure Artifactory endpoint
$ jfrog config
$ RT_FILE="pipelines-installers/installer/pipelines-master.tar.gz
# OR
$ RT_FILE="pipelines-installers/installer/pipelines-<release>.tar.gz
$ jfrog rt dl --flat  --limit=1 --sort-by=created --sort-order=desc "${RT_FILE}" installer.tar.gz
$ installer -xvzf installer.tar.gz
```

############# Run installation  ################

### If Artifactory is running on the same host as Pipelines

```
$ sudo ./pipelines install \
    --base-url-ui http://<external-ip-of-host>:8082 \
    --installer-ip <internal-ip-of-host> \
    --api-url http://<external-ip-of-host>:9092/pipelines/api \
    --artifactory-joinkey <join-key> \
    --devmode

### If Artifactory is running on a different host
$ sudo ./pipelines install \
    --base-url-ui <unified-ui-url> \
    --installer-ip <internal-ip-of-host> \
    --api-url http://<external-ip-of-host>:8082/pipelines/api \
    --artifactory-joinkey <join-key>
```

### Production
- Production setup assumes availability of an existing `postgres`

- Install docker
```
############# Install docker ################
# Install docker using instructions: https://docs.docker.com/install/linux/docker-ce/ubuntu/#install-using-the-repository OR follow instructions below

$ sudo apt-get update
$ sudo apt-get install -y \
    apt-transport-https \
    ca-certificates \
    curl \
    software-properties-common
$ curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
$ sudo add-apt-repository \
   "deb [arch=amd64] https://download.docker.com/linux/ubuntu \
   $(lsb_release -cs) \
   stable"
$ sudo apt-get update
$ sudo apt-get install -y docker-ce=5:18.09.5~3-0~ubuntu-xenial

############# Centos 7.6 - Install docker ################
$ sudo yum install -y yum-utils \
  device-mapper-persistent-data \
  lvm2
$ sudo yum-config-manager \
    --add-repo \
    https://download.docker.com/linux/centos/docker-ce.repo
$ sudo yum -y install docker-ce-18.06.3.ce-3.el7
$ sudo yum -y install containerd.io
$ sudo systemctl start docker

############# Get Installer  ################
$ export RT_USERNAME="<your_username>"
$ export RT_API_KEY="<your_api_key>"
$ curl -o installer.tar.gz https://entplus.jfrog.io/artifactory/pipelines-installers/pipelines/pipelines-master.tar.gz -u$RT_USERNAME:$RT_API_KEY
$ mkdir -p installer && tar -C installer -xvzf installer.tar.gz
```
- [optional] install `postgresql` using the following instructions

```
############# for Ubuntu 16.04 #######################
$ sudo apt-get install -y postgresql=9.5+173ubuntu0.2
$ sudo systemctl enable postgresql
$ sudo vim /etc/postgresql/9.5/main/postgresql.conf
    # update listen_address directive
    # listen_address='*'
$ echo "host all  all    0.0.0.0/0  md5" | sudo tee -a /etc/postgresql/9.5/main/pg_hba.conf
$ sudo systemctl enable postgresql
$ sudo systemctl restart postgresql.service

############# for CentOS 7.6 #########################
$ sudo rpm -ivh --force http://yum.postgresql.org/9.5/redhat/rhel-7-x86_64/pgdg-centos95-9.5-3.noarch.rpm
$ sudo yum install -y postgresql95 postgresql95-server postgresql95-contrib

$ sudo systemctl enable postgresql-9.5.service
$ sudo /usr/pgsql-9.5/bin/postgresql95-setup initdb
$ sudo systemctl start postgresql-9.5.service

$ sudo vi /var/lib/pgsql/9.5/data/postgresql.conf
    # update listen_address directive
    # listen_address='*'

$ sudo vi /var/lib/pgsql/9.5/data/pg_hba.conf

### Add/Edit following lines ###
# IPv4 local connections:
host    all             all             127.0.0.1/32            md5
# IPv6 local connections:
host    all             all             ::1/128                 md5
host all  all    0.0.0.0/0  md5
### Save and exit file

$ sudo systemctl restart postgresql-9.5.service

############# Configuration ###########################

$ sudo -u postgres psql -c "CREATE ROLE dbo INHERIT"
$ sudo -u postgres psql -c "CREATE USER apiuser IN ROLE dbo PASSWORD 'testing1234' LOGIN INHERIT"
$ sudo -u postgres psql -c "CREATE DATABASE pipelinesdb OWNER dbo"
$ sudo -u postgres psql -c "REVOKE CONNECT ON DATABASE pipelinesdb FROM PUBLIC"
$ sudo -u postgres psql -c "GRANT CONNECT ON DATABASE pipelinesdb TO dbo"
```

- Run installation

```
$ sudo ./pipelines install \
    --base-url-ui <unified-ui-url> \
    --installer-ip <internal-ip-of-host> \
    --api-url http://<external-ip-of-host>:8082/pipelines/api \
    --artifactory-joinkey <join-key>
```

## HA Setup
- Additional instances can be added to an existing Pipelines installation to
    create a HA cluster.
- To do this, provision an instance that preferably has the same configuration
    as the first instance that is already running Pipelines
- Copy the `system.yaml` file from the first instance to the new instance and
    place it in the standard location at `$JFROG_HOME/pipelines/var/etc/system.yaml`. The default location is
    `/opt/jfrog/pipelines/var/etc/system.yaml`
- Download and install Pipelines CLI

```
############# Get Installer  ################
## Configure Artifactory endpoint
$ jfrog config

## For Ubuntu/Debian based systems
$ RT_FILE="pipelines-installers/installer/pipelines-<release>.deb
$ jfrog rt dl --flat  --limit=1 --sort-by=created --sort-order=desc "${RT_FILE}" pipelines.deb
$ sudo dpkg -i pipelines.rpm

## For CentOS/RHEL/Fedora
$ RT_FILE="pipelines-installers/installer/pipelines-<release>.rpm
$ jfrog rt dl --flat  --limit=1 --sort-by=created --sort-order=desc "${RT_FILE}" pipelines.rpm
$ rpm -Uvh pipelines.rpm

```
- Install Pipelines
```
$ export PIPELINES_NODE_IP=<new_instance_ip>
$ sudo pipelines install \
    --installer-ip $PIPELINES_NODE_IP \
    --api-url http://$PIPELINES_NODE_IP:8082/pipelines/api \
```

- Once installation is complete, check the service status by calling health check route on local router

```
$ curl -XGET http://localhost:8046/router/api/v1/topology/health | jq '.'
```

## Upgrade

```
$ ./pipelines upgrade
```

## Cleanup

```
$ ./pipelines clean

[optional]
$ sudo -u postgres psql -c "DROP DATABASE pipelinesdb"
```

## Proxy

- `pipelines` accepts proxy configuration to use a proxy server to connect to the JFrog Artifactory instance.
    This can be set up using `--artifactory-proxy <url>` argument from cli during installation
- `pipelines` also fetches proxy configurations from the JFrog Artifactory instance
    and injects them into the `onebox` or k8s master host (based on the installation type)
    - `pipelines` also injects the proxy configurations into microservices
    - this is to ensure that any outgoing connections use the same proxy settings
        as are being used by the parent artifactory instance
    - proxy settings fetched from artifactory can be overridden from cli by
        using `--global-http-proxy`, `--global-https-proxy` and
        `--global-no-proxy` settings


## Development
- To install locally, first update the files in `bin/` directory with the required version

```
$ echo master > bin/controlplaneVersion.txt
$ echo master > bin/buildplaneVersion.txt
```

- Once the files are updated, run the installation command to mentioned in the
    previous sections to install Pipelines locally

## FAQ's


1. Can I change the default directory which is used by the installer?

- The environment variable `JFROG_HOME` is used to determine where all the configuration files and data is stored for the installer. In any installation command, export this variable to the location
of your choice e.g.
    - `JFROG_HOME=/my/dir/location ./pipelines install ....`
    - `sudo JFROG_HOME=/my/dir/location ./pipelines install ....`
If the installation is not being run by a user with `sudo `permissions, the
user needs to have full read/write permissions on the `JFROG_HOME` directory.
All installer commands (`upgrade`, `clean,` etc) will need `JFROG_HOME` environment variable to
run successfully.


## Provisioning
- All services and core components will run on a single instance. The
  requirements for the instance are:
    - 4 core (min)
    - 8 Gb memory
    - 100 Gb disk
    - Ubuntu 14.04 LTS/Ubuntu 16.04 LTS/CentOS 7/RHEL 7
- The following ports must be exposed on this instance:
    - 22: ssh into the machine
    - 5432: database
    - 5672: amqp
    - 15672: amqp admin
    - 6379: redis
    - 8200: vault
    - 30000: Pipelines api
    - 30001: Pipelines front end

## Load balancers
TBD
