#!/bin/bash
set -e
set -o pipefail

readonly DEB_PKG_NAME="$INSTALLER_BUILD_NAME.deb"
readonly DEB_FAKEROOT="/pipelines/fakeroot"
readonly DEB_FAKEROOT_SRC="$DEB_FAKEROOT/$INSTALLER_BUILD_NAME/opt/jfrog/pipelines/installer"
readonly DEB_FAKEROOT_CONFIG="$DEB_FAKEROOT/$INSTALLER_BUILD_NAME/DEBIAN"

__validate_envs() {
  if [ -z "$JFROG_HOME" ]; then
    echo "Missing JFROG_HOME environment variable, cannot create deb archive"
    exit 1
  fi

  ## This directory has the installer source code
  if [ -z "$JF_PIPELINES_HOME" ]; then
    echo "Missing JF_PIPELINES_HOME environment variable, cannot create deb archive"
    exit 1
  fi

  if [ -z "$PIPELINES_VERSION" ]; then
    echo "Incorrect or missing control plane version, cannot create deb archive"
    exit 1
  fi

  if [ -z "$INSTALLER_BUILD_NAME" ]; then
    echo "Incorrect or missing build name, cannot create deb archive"
    exit 1
  fi
}

__create_build_dir() {
  echo "Creating directories for debian archive"
  rm -rf $DEB_FAKEROOT || true
  mkdir -p $DEB_FAKEROOT \
    $DEB_FAKEROOT_SRC \
    $DEB_FAKEROOT_CONFIG
}

__copy_files() {
  echo "Copying source files into build directory"
  rsync -az $JF_PIPELINES_HOME/ $DEB_FAKEROOT_SRC

  echo "Copying bootstrap scripts"
  local deb_config_dir="$JF_PIPELINES_HOME/build/debian"
  cp -vr $deb_config_dir/compat $DEB_FAKEROOT_CONFIG
  cp -vr $deb_config_dir/preinst $DEB_FAKEROOT_CONFIG
  cp -vr $deb_config_dir/postinst $DEB_FAKEROOT_CONFIG
}

__update_version() {
  echo "Updating package version"

  local deb_config_dir="$JF_PIPELINES_HOME/build/debian"
  local deb_config_template="$deb_config_dir/control.template"
  local deb_config_path="$DEB_FAKEROOT_CONFIG/control"

  echo "Creating debian package configuration file and updating version "
  cp -vr $deb_config_template $deb_config_path

  local release="$PIPELINES_VERSION"
  sed -i 's#{{VERSION}}#'$release'#g' $deb_config_path

}

__build_archive() {
  echo "Building debian archive"

  pushd $DEB_FAKEROOT

  time fakeroot dpkg-deb --verbose --build $INSTALLER_BUILD_NAME

  cp -vr $DEB_PKG_NAME $JF_PIPELINES_HOME
  popd
}

main() {
  echo "=================================================================="
  echo "================== Building Pipelines debian archive ============="
  echo "=================================================================="
  __validate_envs
  __create_build_dir
  __copy_files
  __update_version
  __build_archive
}

main
