#!/bin/bash
set -e
set -o pipefail

readonly RUNTIME_DIR="$JF_PIPELINES_HOME/var"
readonly INSTALLER_HOME="$JF_PIPELINES_HOME/installer"
readonly TMP_DIR="$RUNTIME_DIR/tmp"

__validate_envs() {
  if [ -z "$JFROG_HOME" ]; then
    echo "Missing JFROG_HOME environment variable, cannot create RPM archive"
    exit 1
  fi

  if [ -z "$JF_PIPELINES_HOME" ]; then
    echo "Missing JF_PIPELINES_HOME environment variable, cannot create RPM archive"
    exit 1
  fi

  if [ -z "$PIPELINES_VERSION" ]; then
    echo "Incorrect or missing control plane version, cannot create RPM archive"
    exit 1
  fi

  if [ -z "$RPMBUILD_HOME" ]; then
    echo "Missing RPMBUILD_HOME environment variable, cannot create RPM archive"
    exit 1
  fi

  if [ -z "$INSTALLER_ARCHIVE" ]; then
    echo "Missing INSTALLER_ARCHIVE environment variable, cannot create RPM archive"
    exit 1
  fi

  export EXTRACTED_DIR="pipelines-$PIPELINES_VERSION"
}

__copy_source() {
  echo "Copying installer source tarfile"
  local installer_source="$JF_PIPELINES_BUILD_DIR/$INSTALLER_ARCHIVE"
  local installer_dest="$RPMBUILD_HOME/SOURCES/$INSTALLER_ARCHIVE"
  if [ ! -f "$installer_source" ]; then
    echo "Missing installer archive at $installer_source, cannot create RPM archive"
    exit 1
  fi

  cp -vr $installer_source $installer_dest
  echo "Successfully copied installer source archive"

}

__copy_specfile() {
  echo "Copying specfile to the RPM build root"
  local specfile_loc="$JF_PIPELINES_BUILD_DIR/pipelines.spec"
  local specfile_dest="$RPMBUILD_HOME/SPECS/pipelines.spec"

  if [ ! -d "$RPMBUILD_HOME/SPECS" ]; then
    echo "Missing specfile directory: $RPMBUILD_HOME/SPECS"
    exit 1
  fi

  cp -vr $specfile_loc $specfile_dest
  echo "Successfully copied installer RPM specfile"
}

__build_archive() {
  echo "Building rpm archive"
  local buildroot="$RPMBUILD_HOME/BUILDROOT/pipelines-$PIPELINES_VERSION"
  echo "PIPELINES_VERSION: $PIPELINES_VERSION"
  local release=1000$(echo "${PIPELINES_VERSION/-/.}" | cut -d. -f3)
  local version=$(echo $PIPELINES_VERSION | tr '-' '.')
  rpmbuild -v -bb \
    --define="_tmppath $TMP_DIR" \
    --define="pipelines_version $version" \
    --define="pipelines_release $release" \
    --define="source_tarfile $INSTALLER_ARCHIVE" \
    --define="rpm_filename $RPM_FILENAME" \
    --define="extracted_dir $EXTRACTED_DIR" \
    --define="buildroot $buildroot" \
    $RPMBUILD_HOME/SPECS/pipelines.spec
}

__copy_archive() {
  echo "Copying archive to mounted directory"
  local rpm_loc="$RPMBUILD_HOME/RPMS/$RPM_FILENAME"
  local rpm_dest="$JF_PIPELINES_BUILD_DIR/"
  cp -vr $rpm_loc $rpm_dest
}

main() {
  echo "=================================================================="
  echo "================== Building Pipelines RPM archive ================"
  echo "=================================================================="
  __validate_envs
  __copy_specfile
  __copy_source
  __build_archive
  __copy_archive
}

main
