# vault-init

The `vault-init` service automates the process of [initializing](https://www.vaultproject.io/docs/commands/operator/init.html) and [unsealing](https://www.vaultproject.io/docs/concepts/seal.html#unsealing) HashiCorp Vault instances running on [Kubernetes](https://kubernetes.io).

After `vault-init` initializes a Vault server it stores master keys and root tokens as [Kubernetes secrets](https://kubernetes.io/docs/concepts/configuration/secret/).

## Usage

The `vault-init` service is designed to be run alongside a Vault server and communicate over local host.

## Kubernetes

Run `vault-init` in the same Pod as the Vault container. See the [vault statefulset](statefulset.yaml) for a complete example.

## Configuration

The vault-init service supports the following environment variables for configuration:

* `VAULT_ADDRESS`: The host of the Vault API (defaults to `http://localhost:8200`)
* `VAULT_SECRET_SHARES`: Specifies the number of shares to split the Vault master key into (defaults to `5`)
* `VAULT_SECRET_THRESHOLD`: Specifies the number of shares required to reconstruct the Vault master key (defaults to `3`)
* `VAULT_AUTO_UNSEAL`: Specifies whether the Vault should be unsealed after initializing (defaults to `true`)
* `VAULT_STORED_SHARES`: Specifies the number of shares that should be encrypted by the HSM and stored for auto-unsealing (defaults to `1`, only supported when `VAULT_TYPE` is set to `pro` or `enterprise`)
* `VAULT_RECOVERY_SHARES`: Specifies the number of shares to split the recovery key into (defaults to `1`, only supported when `VAULT_TYPE` is set to `pro` or `enterprise`)
* `VAULT_RECOVERY_THRESHOLD`: Specifies the number of shares required to reconstruct the recovery key (defaults to `1`, only supported when `VAULT_TYPE` is set to `pro` or `enterprise`)
* `VAULT_TYPE`: Specifies the type of Vault (possible values are `oss`, `pro`, and `enterprise`. The default value is `oss`)
* `VAULT_NAMESPACE`: Specifies the Kubernetes namespace the secrets are created in (defaults to `default`)
* `CHECK_INTERVAL`: The time in seconds between Vault health checks (defaults to `10`)
* `LOGLEVEL`: Specifies the log level for `vault-init` (possible values are `panic`, `fatal`, `error`, `warn`, `info`, and `debug`. Defaults to `info`)
* `CONSOLELOG`: Specifies whether the output should be human-friendly, colorized output (defaults to `false`)
