#!/bin/bash

set -e
set -o pipefail

__check_vault_seal() {
  log_proc_msg "Checking if vault is sealed"
  _vault_get_seal_status
  if [ $is_request_success == true ]; then
    log_proc_msg "Successfully checked seal status"
  else
    log_proc_error "Error checking vault seal status: $response"
    log_proc_error "Status code: $response_status_code"
    exit 1
  fi

  if [ ! -z "$response" ]; then
    local sealed=$(echo $response | jq '.sealed')
    if [ "$sealed" == "true" ]; then
      log_proc_error "Cannot initialize vault, server is in sealed state"
      exit 1
    else
      log_proc_success "Vault is unsealed"
    fi
  fi
}

__create_secrets_mount() {
  log_proc_msg "Creating vault secrets mount"

  _vault_post_mount "pipelines" '{"type": "generic", "description": "Pipelines secrets mount"}'
  if [ $is_request_success != true ] && [ $response_status_code != 400 ]; then
    log_proc_error "Error creating vault secrets mount: $response"
    log_proc_error "Status code: $response_status_code"
    exit 1
  fi
}

__write_test_secret() {
  log_proc_msg "Writing secret to vault"

  _vault_post_secret "pipelines/testPermissions" '{"testValue": "testSecret"}'
  if [ $is_request_success != true ]; then
    log_proc_error "Error writing secret to vault: $response"
    log_proc_error "Status code: $response_status_code"
    exit 1
  fi
}

__get_test_secret() {
  log_proc_msg "Getting secret from vault"

  _vault_get_secret "pipelines/testPermissions"
  if [ $is_request_success != true ]; then
    log_proc_error "Error getting secret from vault: $response"
    log_proc_error "Status code: $response_status_code"
    exit 1
  fi

  if [ ! -z "$response" ]; then
    local test_value=$(echo $response | jq '.data.testValue')
    if [ "$test_value" == "testSecret" ]; then
      log_proc_error "Failed to retrieve secret"
      exit 1
    fi
  fi
}

__delete_test_secret() {
  log_proc_msg "Deleting secret from vault"

  _vault_delete_secret "pipelines/testPermissions"
  if [ $is_request_success != true ]; then
    log_proc_error "Error deleting secret from vault: $response"
    log_proc_error "Status code: $response_status_code"
    exit 1
  fi
}

main() {
  log_proc_msg "Initializing vault"
  __check_vault_seal
  __create_secrets_mount
  __write_test_secret
  __get_test_secret
  __delete_test_secret
}

main
