#!/bin/bash
set -e
set -o pipefail

__clean_dirs() {
  log_proc_msg "Cleaning up directories"
  if [ -d "$CONFIG_DIR" ]; then
    log_proc_msg "Removing previously created $CONFIG_DIR"
    rm -rf "$CONFIG_DIR"
  fi
  mkdir -p "$CONFIG_DIR"

  if [ -d "$RUNTIME_DIR" ]; then
    log_proc_msg "Removing previously created $RUNTIME_DIR"
    rm -rf "$RUNTIME_DIR"
  fi
  mkdir -p "$RUNTIME_DIR"
}

__remove_services() {
  local count=$(docker ps -aq | wc -l)
  if [[ "$count" -ne 0 ]]; then
    local container_ids=$(docker ps -a | grep 'pipelines-' | awk '{print $1}')
    local remove_cmd="docker rm -f"
    log_proc_msg "Executing: $remove_cmd"
    for id in ${container_ids[@]}; do
      eval "$remove_cmd $id"
    done
  else
    log_proc_msg "No containers found. Skipping removal."
  fi
}

__cleanup_proxy() {
  log_proc_msg "Cleaning up proxy settings from $SYSTEM_ENV"

  if [ ! -w "$SYSTEM_ENV" ]; then
    log_proc_warn "Skipping proxy cleanup"
    log_proc_warn "User $PIPELINES_CORE_USER does not have permissions to edit $SYSTEM_ENV"
    return
  fi

  log_proc_msg "Removing http_proxy"
  unset http_proxy
  sed -i '/^export http_proxy=/d' $SYSTEM_ENV || true

  log_proc_msg "Removing https_proxy"
  unset https_proxy
  sed -i '/^export https_proxy=/d' $SYSTEM_ENV || true

  log_proc_msg "Removing no_proxy"
  unset no_proxy
  sed -i '/^export no_proxy=/d' $SYSTEM_ENV || true
}

main() {
  log_proc_marker "Cleaning installation"
  log_proc_msg "WARNING: this will erase your Pipelines installation..."
  log_proc_msg "WARNING: including all containers and the database."
  log_proc_msg "Do you wish to continue? (type y/Y to confirm)"
  read -r confirmation
  confirmation=$(echo "$confirmation" | awk '{print toupper($0)}')

  if [ ! -f "$PIPELINES_YAML_CONFIG" ]; then
    log_proc_error "Installer config file not found, skipping cleanup"
    exit 1
  fi

  load_system_config
  if [[ "$confirmation" =~ "Y" ]] || [[ "$confirmation" =~ "y" ]]; then
    log_proc_msg "Removing all containers"
    __remove_services
    __cleanup_proxy
    __clean_dirs
    log_proc_success "Clean is complete. Reinstall by running './pipelines install'"
    exit 0
  fi
}

main
