#!/bin/bash
set -e
set -o pipefail

export PIPELINES_SHARED_DB_IMAGE="$PIPELINES_CORE_REGISTRYURL/$PIPELINES_SHARED_DB_IMAGE:$PIPELINES_CORE_CONTROLPLANEVERSION"
export DB_COMPOSE="$DB_CONFIG_DIR/db_compose.yml"
export TIMEOUT=180

__check_db() {
  log_proc_msg "Checking $COMPONENT container status on: $PIPELINES_SHARED_DB_IP:$PIPELINES_SHARED_DB_PORT"
  check_service_connection "$PIPELINES_SHARED_DB_IP" "$PIPELINES_SHARED_DB_PORT" "$COMPONENT" "$TIMEOUT"
}

__generate_compose_config() {
  log_proc_msg "Generating database compose config"

  local compose_template="$INSTALLER_SCRIPTS_DIR/configs/db_compose.yml.template"
  cp -vr $compose_template $DB_COMPOSE

  log_proc_msg "Updating component name"
  sed -i 's#{{COMPONENT}}#'$COMPONENT'#g' $DB_COMPOSE

  log_proc_msg "Updating db image"
  sed -i 's#{{PIPELINES_SHARED_DB_IMAGE}}#'$PIPELINES_SHARED_DB_IMAGE'#g' $DB_COMPOSE

  log_proc_msg "Updating db port"
  sed -i 's#{{PIPELINES_SHARED_DB_PORT}}#'$PIPELINES_SHARED_DB_PORT'#g' $DB_COMPOSE

  log_proc_msg "Updating db password"
  sed -i 's#{{PIPELINES_SHARED_DB_PASSWORD}}#'$PIPELINES_SHARED_DB_PASSWORD'#g' $DB_COMPOSE

  log_proc_msg "Updating db username"
  sed -i 's#{{PIPELINES_SHARED_DB_USERNAME}}#'$PIPELINES_SHARED_DB_USERNAME'#g' $DB_COMPOSE

  log_proc_msg "Updating db name"
  sed -i 's#{{PIPELINES_SHARED_DB_NAME}}#'$PIPELINES_SHARED_DB_NAME'#g' $DB_COMPOSE

  log_proc_msg "Updating db data directory"
  sed -i 's#{{DB_DATA_DIR}}#'$DB_DATA_DIR'#g' $DB_COMPOSE

  log_proc_msg "Updating db config directory"
  sed -i 's#{{DB_CONFIG_DIR}}#'$DB_CONFIG_DIR'#g' $DB_COMPOSE
}

__run_db() {
  log_proc_msg "Running database container"
  docker-compose \
    --file $DB_COMPOSE down || true

  docker-compose \
    --file $DB_COMPOSE \
    up \
    --detach $COMPONENT
}

main() {
  log_proc_msg "Booting database"
  __generate_compose_config
  __run_db
  __check_db
  log_proc_msg "Database container successfully running"
}

main
