#!/bin/bash
set -e
set -o pipefail

readonly STATE_REPO_CONFIG="$CONFIG_DIR/state_repository.json"
export STATE_EXISTS=false

__get_repositories() {
  log_proc_msg "Getting existing repositories from artifactory"
  local repositories=""
  _rt_get_repositories
  if [ $is_request_success == true ]; then
    log_proc_msg "Successfully fetched repositories from artifactory"
    repositories="$response"
  else
    log_proc_error "Error getting repositories: $response"
    log_proc_error "Status code: $response_status_code"
    exit 1
  fi

  if [ ! -z "$repositories" ]; then
    local existing_repo=$(echo $repositories \
      | jq '.[] | select(.key=="'$PIPELINES_RUNTIME_ROOTBUCKET'")')
    if [ ! -z "$existing_repo" ]; then
      local repo_url=$(echo $existing_repo \
        | jq '.url')
      log_proc_msg "State repository already exists at: $repo_url"
      STATE_EXISTS=true
    else
      log_proc_msg "State repository does not exist"
    fi
  fi
}

__create_state_config() {
  if [ $STATE_EXISTS == false ]; then
    log_proc_msg "Creating state repository config"
    local state_repo_config_template="$INSTALLER_SCRIPTS_DIR/configs/state_repository.json.template"
    cp -vr "$state_repo_config_template" "$STATE_REPO_CONFIG"

    sed -i "s#{{PIPELINES_RUNTIME_ROOTBUCKET}}#$PIPELINES_RUNTIME_ROOTBUCKET#g" $STATE_REPO_CONFIG
  else
    log_proc_msg "Skipping config creation for an existing repository"
  fi
}
__create_state_repository() {
  if [ $STATE_EXISTS == false ]; then
    log_proc_msg "Creating state repository: $PIPELINES_RUNTIME_ROOTBUCKET"
    local data=$(printf '%s' $(cat $STATE_REPO_CONFIG))
    _rt_put_repository "$PIPELINES_RUNTIME_ROOTBUCKET" "$data"
    if [ $is_request_success == true ]; then
      log_proc_msg "Successfully created repository on artifactory"
    else
      log_proc_error "Error getting repositories: $response"
      log_proc_error "Status code: $response_status_code"
      exit 1
    fi
  else
    log_proc_msg "Skipping repo creation"
  fi
}

main() {
  log_proc_marker "Configuring system state"
  __get_repositories
  __create_state_config
  __create_state_repository
}

main
