#!/bin/bash
set -e
set -o pipefail

export COMPONENT="vault"
export VAULT_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"

__validate_vault_store() {
  log_proc_msg "Validating vault store script"

  if [ ! -d "$VAULT_CONFIG_DIR" ]; then
    log_proc_msg "Vault config dir not present, creating"
    mkdir -p "$VAULT_CONFIG_DIR"
  else
    log_proc_msg "Vault config dir already present"
  fi
}

__upsert_vault_tables() {
  log_proc_msg "Upserting vault store and vault HA lock in db"

  local vault_kv_store_script_host_location="$INSTALLER_SCRIPTS_DIR/configs/vault_kv_store.sql"
  local vault_ha_locks_script_host_location="$INSTALLER_SCRIPTS_DIR/configs/vault_ha_locks.sql"
  local vault_tables_script_host_location="$INSTALLER_SCRIPTS_DIR/configs/vault_tables.sql"

  cat "$vault_kv_store_script_host_location" > "$vault_tables_script_host_location"
  cat "$vault_ha_locks_script_host_location" >> "$vault_tables_script_host_location"

  local upsert_cmd="psql $PIPELINES_SHARED_DB_CONNECTIONSTRING \
    -v ON_ERROR_STOP=1 \
    -f $vault_tables_script_host_location"

  eval "$upsert_cmd"
  rm "$vault_tables_script_host_location"
}

main() {
  log_proc_marker "Creating vault table in database"
  __validate_vault_store
  __upsert_vault_tables
}

main
