#!/bin/bash
set -e
set -o pipefail

__validate_msg_envs() {
  log_proc_msg "Initializing RabbitMQ environment variables"
  log_proc_msg "PIPELINES_SHARED_MSG_IP: $PIPELINES_SHARED_MSG_IP"
  log_proc_msg "PIPELINES_SHARED_MSG_PORT: $PIPELINES_SHARED_MSG_PORT"
  log_proc_msg "PIPELINES_SHARED_MSG_ADMINPORT: $PIPELINES_SHARED_MSG_ADMINPORT"
  log_proc_msg "PIPELINES_SHARED_MSG_UI_USERNAME: $PIPELINES_SHARED_MSG_UI_USERNAME"
  log_proc_msg "PIPELINES_SHARED_MSG_UI_PASSWORD_LENGTH: ${#PIPELINES_SHARED_MSG_UI_PASSWORD}"
  log_proc_msg "PIPELINES_SHARED_MSG_USERNAME: $PIPELINES_SHARED_MSG_USERNAME"
  log_proc_msg "PIPELINES_SHARED_MSG_PASSWORD_LENGTH: ${#PIPELINES_SHARED_MSG_PASSWORD}"
}

__check_cluster() {
  if [ ! -z "$RABBITMQ_CLUSTER_HOST" ]; then
    log_proc_msg "Checking RabbitMQ cluster connection"
    check_service_connection "$RABBITMQ_CLUSTER_HOST" "$PIPELINES_SHARED_MSG_ADMINPORT" "RabbitMQ" 15
  fi
}

__connect_to_cluster() {
  if [ ! -z "$RABBITMQ_CLUSTER_HOST" ]; then
    log_proc_msg "Connecting to RabbitMQ cluster"
    docker exec msg /bin/sh -c "rabbitmqctl stop_app"
    docker exec msg /bin/sh -c "rabbitmqctl reset"
    docker exec msg /bin/sh -c "rabbitmqctl join_cluster rabbit@$RABBITMQ_CLUSTER_HOST"
    docker exec msg /bin/sh -c "rabbitmqctl start_app"
    docker exec msg /bin/sh -c "rabbitmqctl cluster_status"
  fi
}

main() {
  log_proc_marker "Initializing RabbitMQ"
  __validate_msg_envs
  __check_cluster
  __connect_to_cluster
}

main
