#!/bin/bash
set -e
set -o pipefail

export COMPONENT="db"
export DB_DATA_DIR="$RUNTIME_DIR/data/$COMPONENT"
export DB_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export DB_INSTALL_SCRIPT="installDb.sh"

__validate_db_envs() {
  log_proc_msg "Validating db ENV variables"
  if [ "$PIPELINES_SHARED_DB_IP" == "" ]; then
    log_proc_error "PIPELINES_SHARED_DB_IP cannot be empty, exiting"
    exit 1
  fi

  if [ "$PIPELINES_SHARED_DB_PORT" == "" ]; then
    log_proc_error "PIPELINES_SHARED_DB_PORT cannot be empty, exiting"
    exit 1
  fi

  if [ "$PIPELINES_SHARED_DB_USERNAME" == "" ]; then
    log_proc_error "PIPELINES_SHARED_DB_USERNAME cannot be empty, exiting"
    exit 1
  fi

  if [ "$PIPELINES_SHARED_DB_NAME" == "" ]; then
    log_proc_error "PIPELINES_SHARED_DB_NAME cannot be empty, exiting"
    exit 1
  fi

  if [ "$PIPELINES_SHARED_DB_PASSWORD" == "" ]; then
    log_proc_error "PIPELINES_SHARED_DB_PASSWORD cannot be empty, exiting"
    exit 1
  fi

  if [ "$PIPELINES_SHARED_DB_TYPE" == "" ]; then
    log_proc_error "PIPELINES_SHARED_DB_TYPE cannot be empty, exiting"
    exit 1
  fi
}

__validate_db_mounts() {
  log_proc_msg "Validating db data mounts from host"

  if [ ! -d "$DB_DATA_DIR" ]; then
    log_proc_msg "Creating data directory $DB_DATA_DIR"
    mkdir -p $DB_DATA_DIR
  else
    log_proc_msg "Data directory already present: $DB_DATA_DIR"
  fi

  if [ ! -d "$DB_CONFIG_DIR" ]; then
    log_proc_msg "Creating config directory $DB_CONFIG_DIR"
    mkdir -p $DB_CONFIG_DIR
  else
    log_proc_msg "Config directory already present: $DB_CONFIG_DIR"
  fi
}

__normalize_db_connection_string() {
  if [ -z "$PIPELINES_SHARED_DB_CONNECTIONSTRING" ]; then
    log_proc_msg "Updating database connection string"
    export PIPELINES_SHARED_DB_CONNECTIONSTRING="postgres://$PIPELINES_SHARED_DB_USERNAME:$PIPELINES_SHARED_DB_PASSWORD@$PIPELINES_SHARED_DB_IP:$PIPELINES_SHARED_DB_PORT/$PIPELINES_SHARED_DB_NAME"
  fi
}

__install_db_compose() {
  source "$INSTALLER_SCRIPTS_DIR/compose/$DB_INSTALL_SCRIPT"
}

__install_db_kubernetes() {
  source "$INSTALLER_SCRIPTS_DIR/kubernetes/$DB_INSTALL_SCRIPT"
}

main() {
  log_proc_marker "Installing database"
  if check_db_variables; then
    log_proc_msg "Installing database using docker compose"
    __normalize_db_connection_string
    __validate_db_envs
    __validate_db_mounts
    create_user_volume_dirs "$PIPELINES_SERVICE_UID:$PIPELINES_SERVICE_GID" \
    "$DB_DATA_DIR"
    __install_db_compose
  else
    __validate_db_mounts
    log_proc_success "Skipping database installation since DB is externalized"
  fi
  test_db_connection
}

main
