#!/bin/bash
set -e
set -o pipefail

export COMPONENT="msg"
export MSG_DATA_DIR="$RUNTIME_DIR/data/$COMPONENT"
export MSG_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export PIPELINES_SHARED_MSG_IMAGE="$PIPELINES_CORE_REGISTRYURL/$PIPELINES_SHARED_MSG_IMAGE:$PIPELINES_CORE_CONTROLPLANEVERSION"
export SCRIPTS_DIR="$SCRIPTS_DIR"
export LOGS_FILE="$LOGS_DIR/$COMPONENT.log"
export TIMEOUT=120
export MSG_INSTALL_SCRIPT="installMsg.sh"

## Write logs of this script to component specific file
exec &> >(tee -a "$LOGS_FILE")

__validate_msg_envs() {
  log_proc_msg "Initializing RabbitMQ environment variables"
  log_proc_msg "SCRIPTS_DIR: $SCRIPTS_DIR"
  log_proc_msg "MSG_DATA_DIR: $MSG_DATA_DIR"
  log_proc_msg "MSG_CONFIG_DIR: $MSG_CONFIG_DIR"
  log_proc_msg "PIPELINES_SHARED_MSG_IP: $PIPELINES_SHARED_MSG_IP"
  log_proc_msg "PIPELINES_SHARED_MSG_PORT: $PIPELINES_SHARED_MSG_PORT"
  log_proc_msg "PIPELINES_SHARED_MSG_ADMINPORT: $PIPELINES_SHARED_MSG_ADMINPORT"
  log_proc_msg "PIPELINES_SHARED_MSG_UI_USERNAME: $PIPELINES_SHARED_MSG_UI_USERNAME"
  log_proc_msg "PIPELINES_SHARED_MSG_UI_PASSWORD_LENGTH: ${#PIPELINES_SHARED_MSG_UI_PASSWORD}"
  log_proc_msg "PIPELINES_SHARED_MSG_USERNAME: $PIPELINES_SHARED_MSG_USERNAME"
  log_proc_msg "PIPELINES_SHARED_MSG_PASSWORD_LENGTH: ${#PIPELINES_SHARED_MSG_PASSWORD}"
  log_proc_msg "LOGS_FILE: $LOGS_FILE"
}

__validate_msg_mounts() {
  log_proc_msg "Validating msg mounts"
  if [ ! -d "$MSG_DATA_DIR" ]; then
    log_proc_msg "Creating data directory $MSG_DATA_DIR"
    mkdir -p $MSG_DATA_DIR
  else
    log_proc_msg "Data directory already present: $MSG_DATA_DIR"
  fi

  if [ ! -d "$MSG_CONFIG_DIR" ]; then
    log_proc_msg "Creating config directory $MSG_CONFIG_DIR"
    mkdir -p $MSG_CONFIG_DIR
  else
    log_proc_msg "Config directory already present: $MSG_CONFIG_DIR"
  fi

  mkdir -p $MSG_CONFIG_DIR/scripts
}

__update_msg_config() {
  log_proc_msg "Updating RabbitMQ configuration file"
  local rabbitmq_config=$MSG_CONFIG_DIR/rabbitmq.config
  cp -vr $INSTALLER_SCRIPTS_DIR/configs/rabbitmq.config.template $rabbitmq_config

  log_proc_msg "Updating rabbitmq port"
  sed -i 's#{{PIPELINES_SHARED_MSG_PORT}}#'$PIPELINES_SHARED_MSG_PORT'#g' $rabbitmq_config

  log_proc_msg "Updating msg rabbitmq port"
  sed -i 's#{{PIPELINES_SHARED_MSG_ADMINPORT}}#'$PIPELINES_SHARED_MSG_ADMINPORT'#g' $rabbitmq_config

  log_proc_msg "Updating enabled plugins configuration"
  cp -vr $INSTALLER_SCRIPTS_DIR/configs/rabbitmq_enabled_plugins $MSG_CONFIG_DIR/enabled_plugins

  log_proc_msg "Updating rabbitmq environment"
  local rabbitmq_env=$MSG_CONFIG_DIR/rabbitmq-env.conf
  cp -vr $INSTALLER_SCRIPTS_DIR/configs/rabbitmq-env.conf.template $rabbitmq_env

  sed -i 's#{{PIPELINES_SHARED_MSG_IP}}#'$PIPELINES_SHARED_MSG_IP'#g' $rabbitmq_env
}

__install_msg_compose() {
  source "$INSTALLER_SCRIPTS_DIR/compose/$MSG_INSTALL_SCRIPT"
}

main() {
  log_proc_marker "Installing RabbitMQ"
  __validate_msg_envs
  __validate_msg_mounts
  __update_msg_config
  create_user_volume_dirs "$PIPELINES_SERVICE_UID:$PIPELINES_SERVICE_GID" \
  "$MSG_DATA_DIR" \
  "$MSG_CONFIG_DIR"
  __install_msg_compose
  log_proc_msg "RabbitMQ installed successfully"
}

main
