#!/bin/bash
set -e
set -o pipefail

export COMPONENT="router"
export ROUTER_DATA_DIR="$RUNTIME_DIR/$COMPONENT/data"
export ROUTER_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export PIPELINES_SHARED_ROUTER_IMAGE="$PIPELINES_CORE_REGISTRYURL/$PIPELINES_SHARED_ROUTER_IMAGE:$PIPELINES_CORE_CONTROLPLANEVERSION"
export LOGS_FILE="$LOGS_DIR/$COMPONENT.log"

exec &> >(tee -a "$LOGS_FILE")

__validate_router_envs() {
  log_proc_msg "Initializing Router environment variables"
  log_proc_msg "SCRIPTS_DIR: $SCRIPTS_DIR"
  log_proc_msg "ROUTER_CONFIG_DIR: $ROUTER_CONFIG_DIR"
  log_proc_msg "PIPELINES_SHARED_ROUTER_IP: $PIPELINES_SHARED_ROUTER_IP"
  log_proc_msg "PIPELINES_SHARED_ROUTER_ACCESSPORT: $PIPELINES_SHARED_ROUTER_ACCESSPORT"
  log_proc_msg "PIPELINES_SHARED_ROUTER_DATAPORT: $PIPELINES_SHARED_ROUTER_DATAPORT"
}

__create_dirs() {
  mkdir -p $ROUTER_CONFIG_DIR
}

__install_router_compose() {
  source "$INSTALLER_SCRIPTS_DIR/compose/installRouter.sh"
}

main() {
  log_proc_msg "Installing router"
  __validate_router_envs
  __create_dirs
  __install_router_compose
  decrypt_secrets
}

main
