'use strict';

var self = ConfigHandler;
module.exports = self;

var yaml = require('js-yaml');
var fs = require('fs');
var _ = require('underscore');
var ConfigurationManager = require('@jfrog/configuration-manager');

function ConfigHandler() {
  var config = ConfigurationManager.default({
    productHome: '/opt/jfrog/pipelines',
    microservice: 'pipelines.installer',
    aliases: {}
  });

  this.globalConfig = {};

  this.globalConfig.runMode = config.get('core.runMode');
  this.globalConfig.ignoreTLSErrors = config.get('core.ignoreTLSErrors') || false;
  this.globalConfig.installUser = config.get('core.user') || 0;
  this.globalConfig.installerIP = config.get('core.installerIP');
  this.globalConfig.controlplaneVersion = config.get('core.controlplaneVersion');
  this.globalConfig.buildplaneVersion = config.get('core.buildplaneVersion');
  this.globalConfig.installerAuthToken =
    config.get('core.installerAuthToken');

  var dbType = config.get('shared.db.type');
  var dbIp = config.get('shared.db.ip');
  var dbPort = config.get('shared.db.port');
  var dbName = config.get('shared.db.name');
  var dbUsername = config.get('shared.db.username');
  var dbPassword = config.get('shared.db.password');

  var dbHost;
  if (dbIp && dbPort)
    dbHost = util.format('%s:%s', dbIp, dbPort)
  else
    dbHost = dbIp;

  if (!_.isUndefined(dbType) && !_.isUndefined(dbHost) &&
    !_.isUndefined(dbName) && !_.isUndefined(dbUsername) &&
    !_.isUndefined(dbPassword))
    this.globalConfig.dbConnectionString = util.format('%s://%s:%s@%s/%s',
      dbType,
      dbUsername,
      dbPassword,
      dbHost,
      dbName
    );

  this.globalConfig.dbPassword =
    config.get('shared.db.password');

  var artifactoryUiUrl = config.get('shared.artifactory.baseUrlUI') || '';
  this.globalConfig.artifactoryUiUrl = '';
  if (artifactoryUiUrl !== '') {
    this.globalConfig.artifactoryUiUrl = artifactoryUiUrl.replace(/\/+$/, '');
  }

  let internalUrl = config.get('shared.artifactory.baseUrl') || '';
  internalUrl = internalUrl.replace(/\/+$/, '');
  if (internalUrl.endsWith('/artifactory')) {
    internalUrl = internalUrl.substring(0, internalUrl.length - 12);
  }
  this.globalConfig.internalUrl = internalUrl;

  this.globalConfig.shouldReadFromVault = config.get('shared.access.shouldReadFromVault');
  this.globalConfig.shouldJustUpdateAccess = config.get('shared.access.shouldJustUpdateAccess');
  this.globalConfig.vaultUrl = config.get('shared.vault.url');
  this.globalConfig.vaultToken = config.get('shared.vault.token');

  this.globalConfig.msgPassword = config.get('shared.msg.password');

  this.globalConfig.isSaas = (config.get('runtime.isSaas') === true ||
                              config.get('runtime.isSaas') === 'true');
  this.globalConfig.saasEnvironment = config.get('runtime.saasEnvironment');

  this.globalConfig.isMacOSEnabled = config.get('runtime.isMacOSEnabled');
  this.globalConfig.macOSNodeLimit = config.get('runtime.macOSNodeLimit') || 5;
  this.globalConfig.runOnePodInOneNode = config.get('runtime.runOnePodInOneNode') || true;
}
