#!/bin/bash
set -e
set -o pipefail

readonly API_RESPONSE_FILE="$TMP_DIR/api_response.tmp"

__initialize() {
  INSTALLER_URL="http://$PIPELINES_CORE_INSTALLERIP:$PIPELINES_CORE_INSTALLERPORT/api"
  INSTALLER_TOKEN="$PIPELINES_CORE_INSTALLERAUTHTOKEN"
  RESPONSE_CODE=404
  RESPONSE_DATA=""
  CURL_EXIT_CODE=0

  touch $API_RESPONSE_FILE
}

__installer_get() {
  __initialize

  local url="$INSTALLER_URL/$1"
  echo "" > $API_RESPONSE_FILE
  {
    RESPONSE_CODE=$(curl \
      -H "Content-Type: application/json" \
      -H "Authorization: apiToken $INSTALLER_TOKEN" \
      -X GET $url \
      --silent --write-out "%{http_code}\n" \
      --output $API_RESPONSE_FILE)
  } || {
    CURL_EXIT_CODE=$(echo $?)
  }

  is_request_success=false
  if [ $RESPONSE_CODE -ne 200 ]; then
    response="Failed request on $url. Error: $(cat $API_RESPONSE_FILE)"
    response_status_code="$RESPONSE_CODE"
  elif [ $CURL_EXIT_CODE -gt 0 ]; then
    # we are assuming that if curl cmd failed, API is unavailable
    response="curl failed with error code $CURL_EXIT_CODE. API might be down."
    response_status_code=503
  else
    is_request_success=true
    response_status_code="$RESPONSE_CODE"
    response=$(cat $API_RESPONSE_FILE)
  fi
}

__installer_post() {
  __initialize

  local url="$INSTALLER_URL/$1"
  local body="$2"
  echo "" > $API_RESPONSE_FILE
  {
    RESPONSE_CODE=$(curl \
      -H "Content-Type: application/json" \
      -H "Authorization: apiToken $INSTALLER_TOKEN" \
      -X POST $url \
      -d "$body" \
      --write-out "%{http_code}\n" \
      --silent \
      --output $API_RESPONSE_FILE)
  } || {
    CURL_EXIT_CODE=$(echo $?)
  }

  is_request_success=false
  if [ $RESPONSE_CODE -ne 200 ]; then
    response="Failed request on $url. Error: $(cat $API_RESPONSE_FILE)"
    response_status_code="$RESPONSE_CODE"
  elif [ $CURL_EXIT_CODE -gt 0 ]; then
    # we are assuming that if curl cmd failed, API is unavailable
    response="curl failed with error code $CURL_EXIT_CODE. API might be down."
    response_status_code=503
  else
    is_request_success=true
    response_status_code="$RESPONSE_CODE"
    response=$(cat $API_RESPONSE_FILE)
  fi
}

__installer_put() {
  __initialize

  local url="$INSTALLER_URL/$1"
  local update="$2"
  echo "" > $API_RESPONSE_FILE
  {
    RESPONSE_CODE=$(curl \
      -H "Content-Type: application/json" \
      -H "Authorization: apiToken $INSTALLER_TOKEN" \
      -X PUT $url \
      -d "$update" \
      --write-out "%{http_code}\n" \
      --silent \
      --output $API_RESPONSE_FILE)
  } || {
    CURL_EXIT_CODE=$(echo $?)
  }

  is_request_success=false
  if [ $RESPONSE_CODE -ne 200 ]; then
    response="Failed request on $url. Error: $(cat $API_RESPONSE_FILE)"
    response_status_code="$RESPONSE_CODE"
  elif [ $CURL_EXIT_CODE -gt 0 ]; then
    # we are assuming that if curl cmd failed, API is unavailable
    response="curl failed with error code $CURL_EXIT_CODE. API might be down."
    response_status_code=503
  else
    is_request_success=true
    response_status_code="$RESPONSE_CODE"
    response=$(cat $API_RESPONSE_FILE)
  fi

}

__installer_delete() {
  __initialize

  local url="$INSTALLER_URL/$1"
  local body="$2"
  echo "" > $API_RESPONSE_FILE
  {
    RESPONSE_CODE=$(curl \
      -H "Content-Type: application/json" \
      -H "Authorization: apiToken $INSTALLER_TOKEN" \
      -X DELETE $url \
      -d "$body" \
      --write-out "%{http_code}\n" \
      --silent \
      --output $API_RESPONSE_FILE)
  } || {
    CURL_EXIT_CODE=$(echo $?)
  }

  is_request_success=false
  if [ $RESPONSE_CODE -ne 200 ]; then
    response="Failed request on $url. Error: $(cat $API_RESPONSE_FILE)"
    response_status_code="$RESPONSE_CODE"
  elif [ $CURL_EXIT_CODE -gt 0 ]; then
    # we are assuming that if curl cmd failed, API is unavailable
    response="curl failed with error code $CURL_EXIT_CODE. API might be down."
    response_status_code=503
  else
    is_request_success=true
    response_status_code="$RESPONSE_CODE"
    response=$(cat $API_RESPONSE_FILE)
  fi

}

### GET

_get_installer() {
  local installer_get_endpoint="installer/status"
  __installer_get $installer_get_endpoint
}

_get_db_status() {
  local db_status_get_endpoint="db/status"
  __installer_get $db_status_get_endpoint
}

_get_installer_status() {
  local installer_status_get_endpoint="installer/status"
  __installer_get $installer_status_get_endpoint
}

### POST

_post_user() {
  local body="{}"
  local db_user_endpoint="db/user"
  __installer_post $db_user_endpoint "$body"
}

_post_provider() {
  local body="$1"
  local provider_endpoint="providers"
  __installer_post $provider_endpoint "$body"
}

_post_project() {
  local body="$1"
  local project_endpoint="projects"
  __installer_post $project_endpoint "$body"
}

_post_services() {
  local body="$1"
  local db_post_endpoint="services"
  __installer_post $db_post_endpoint "$body"
}

### DELETE
_delete_service() {
  local serviceName=$1
  local body=$2
  local service_delete_by_name_endpoint="services/$serviceName"
  __installer_delete $service_delete_by_name_endpoint $body
}
