#!/bin/bash
set -e
set -o pipefail

readonly ROUTER_RESPONSE_FILE="$TMP_DIR/router_response.tmp"

__router_initialize() {
  RESPONSE_CODE=404
  RESPONSE_DATA=""
  CURL_EXIT_CODE=0

  touch $ROUTER_RESPONSE_FILE
}

__router_get() {
  ROUTER_URL="http://localhost:$PIPELINES_SHARED_ROUTER_ACCESSPORT/router/api/v1"
  __router_initialize

  local url="$ROUTER_URL/$1"
  echo "" > $ROUTER_RESPONSE_FILE
  {
    if [ "$PIPELINES_CORE_NOVERIFYSSL" == "true" ]; then
      RESPONSE_CODE=$(curl \
        -H "Content-Type: application/json" \
        -X GET $url --insecure \
        --silent --write-out "%{http_code}\n" \
        --output $ROUTER_RESPONSE_FILE)
    else
      RESPONSE_CODE=$(curl \
        -H "Content-Type: application/json" \
        -X GET $url \
        --silent --write-out "%{http_code}\n" \
        --output $ROUTER_RESPONSE_FILE)
    fi
  } || {
    CURL_EXIT_CODE=$(echo $?)
  }

  is_request_success=false
  if [ $RESPONSE_CODE -ne 200 ]; then
    response="Failed request on $url. Error: $(cat $ROUTER_RESPONSE_FILE)"
    response_status_code="$RESPONSE_CODE"
  elif [ $CURL_EXIT_CODE -gt 0 ]; then
    # we are assuming that if curl cmd failed, router is unavailable
    response="curl failed with error code $CURL_EXIT_CODE. Router might be down."
    response_status_code=503
  else
    is_request_success=true
    response_status_code="$RESPONSE_CODE"
    response=$(cat $ROUTER_RESPONSE_FILE)
  fi
}

### GET
_router_get_health() {
  local db_status_get_endpoint="system/health"
  __router_get $db_status_get_endpoint
}

_router_get_topology() {
  local router_topology_get_endpoint="topology/health"
  __router_get $router_topology_get_endpoint
}
