'use strict';

process.title = 'pipelines.migration';

var _ = require('underscore');
var util = require('util');
var async = require('async');
var pg = require('pg');

//bigint in postgres gets parsed as a string by default
//https://github.com/sequelize/sequelize/issues/2383#issuecomment-58006083
pg.defaults.parseInt8 = true;

require('./lib/ActErr.js');

process.on('uncaughtException',
  function (err) {
    util.log('uncaughtException thrown:', err);
    process.exit(1);
  }
);

var filePath = process.argv[2];

util.log(filePath)
if (_.isEmpty(filePath)) {
  throw new Error('Migration filepath cannot be empty');
}

var bag = {
  filePath: filePath,
  args: process.argv.slice(2),
  env: process.env,
  config: {},
};

bag.who = util.format('installer.migration');

async.series([
  _initializeConfig.bind(null, bag),
  _createClient.bind(null, bag),
  _runMigration.bind(null, bag)
],
  function (err) {
    if (err) {
      throw new Error('Could not run migration: ' + util.inspect(err));
      process.exit(1);
    } else {
      util.log(bag.who, 'Completed');
      process.exit(0);
    }
  }
);

function _initializeConfig(bag, next) {
  var who = bag.who + '|' + _initializeConfig.name;

  var configErrors = [];

  if (process.env.DBCONNECTIONSTRING)
    bag.config.dbConnectionString = process.env.DBCONNECTIONSTRING;
  else
		throw new Error('DBCONNECTIONSTRING is not defined');

	return next();
}

function _createClient(bag, next) {
  var who = bag.who + '|' + _createClient.name;
  util.log(who, 'Inside');
  
  var dbConnectionString = bag.config.dbConnectionString;
  var connectionDetails = {};
  if (dbConnectionString &&
    (dbConnectionString.includes('sslmode=require') ||
     dbConnectionString.includes('ssl=true') ||
     dbConnectionString.includes('sslmode=prefer'))
 ){  
   connectionDetails = {
      connectionString: dbConnectionString,
      ssl: {
        require: true,
        rejectUnauthorized: false // disable SSL validation for self-signed certificates
      }    
    };
  } else {
    connectionDetails = {
      connectionString: dbConnectionString,
    };
  }

  bag.client = new pg.Client(connectionDetails);

  bag.client.connect(
    function (err) {
      return next(err);
    }
  );
}

function _runMigration(bag, next) {
  var who = bag.who + '|' + _runMigration.name;
  util.log(who, 'Inside');

  var migrationsFile = require(bag.filePath);
  migrationsFile(bag.client, next);
}
