'use strict';
const async = require('async');
const fs = require('fs-extra');
const path = require('path');
const _ = require('underscore');

const systemYamlHandler = require('./lib/systemYamlHandler.js');

module.exports = function (params, callback) {
  let bag = {
    runMode: global.config.runMode,
    name: params.name,
    apiAdapter: params.apiAdapter,
    envs: '',
    mounts: '',
    runCommand: ''
  };
  bag.who = util.format('nodePoolServiceConfig|%s','');
  logger.info(bag.who, 'Starting');
  async.series([
      _getConfigs.bind(null, bag),
      _generateEnvs.bind(null, bag),
      _generateMounts.bind(null, bag),
      _generateRunCommandOnebox.bind(null, bag),
    ],
    function (err) {
      logger.info(bag.who, 'Completed');
      if (err) {
        return callback(err);
      }
      callback(null, bag.runCommand);
    }
  );
}

function _getConfigs(bag, next) {
  const who = bag.who + '|' + _getConfigs.name;
  logger.verbose(who, 'Inside');

  systemYamlHandler.get(
    function (err, config) {
      if (err) {
        return next(
          new ActErr(who, ActErr.DataNotFound,
            'Failed to get ' + bag.component, err)
        );
      }

      if (config.core) {
        bag.imageRegistryUrl = config.core.registryUrl;
        bag.pipelinesNodeId = config.core.id;
        bag.httpProxy = config.core.proxy && config.core.proxy.httpProxy;
        bag.httpsProxy = config.core.proxy && config.core.proxy.httpsProxy;
        bag.noProxy = config.core.proxy && config.core.proxy.noProxy;
        bag.noVerifySsl = config.core.noVerifySsl;
        bag.configDir = global.config.hostConfigDir;
        bag.logsDir = global.config.logsDir;
        if (!_.isEmpty(config.core.customCACertsPath))
          bag.customCAEnabled = true
        else
          bag.customCAEnabled = false

        if (config.core.services && config.core.services.nodepoolservice) {
          bag.image = config.core.services.nodepoolservice.image;
        } else {
          return next(
            new ActErr(who, ActErr.DataNotFound,
              'Failed to get core config')
          );
        }
      } else {
        return next(
          new ActErr(who, ActErr.DataNotFound,
            'Failed to get core core.services.' + bag.name)
        );
      }

      bag.componentName = bag.name.toLowerCase();
      bag.deploymentName = util.format('%s-deployment', bag.componentName);
      bag.image = util.format('%s/%s:%s',
        bag.imageRegistryUrl, bag.image, global.config.controlplaneVersion);
      return next();
    }
  );
}

function _generateEnvs(bag, next) {
  const who = bag.who + '|' + _generateEnvs.name;
  logger.verbose(who, 'Inside');
  const composeTemplate = util.format('%s_compose.yml.template', bag.name);
  const composeTemplatePath = path.join(global.config.scriptsDir, 'configs', composeTemplate);
  const composeYml = util.format('%s_compose.yml', bag.componentName);
  const composeYmlPath = path.join(global.config.containerConfigDir,
    'master', composeYml);

  const fileContent = fs.readFileSync(composeTemplatePath).toString();
  const template = _.template(fileContent);

  const ymlContent = template(bag);

  fs.writeFileSync(composeYmlPath, ymlContent, 'utf8');
  logger.info(
    util.format(
      'Successfully generated docker compose file for %s', bag.componentName));

  return next();
}

function _generateMounts(bag, next) {
  const who = bag.who + '|' + _generateMounts.name;
  logger.verbose(who, 'Inside');

  bag.mounts = '';
  return next();
}

function _generateRunCommandOnebox(bag, next) {
  const who = bag.who + '|' + _generateRunCommandOnebox.name;
  logger.verbose(who, 'Inside');

  const composeYml = util.format('%s_compose.yml', bag.componentName);
  const composeYmlPath = path.join(global.config.containerConfigDir,
    'master', composeYml);

  const runCommand = util.format('docker-compose ' +
    ' --file %s ' +
    ' up ' +
    ' --force-recreate ' +
    ' --detach %s',
    composeYmlPath,
    bag.componentName
  );

  bag.runCommand = runCommand;
  return next();
}
