#!/bin/bash
set -e
set -o pipefail

__load_config() {
  log_proc_msg "Loading system configuration"
  bootstrap_platform_config
  load_system_config
  log_system_info
}

__stop_services() {
  log_proc_marker "Stopping running services"
  stop_stateless_services
  stop_stateful_services
}

__restart_router() {
  log_proc_msg "Restarting router"
  source "$INSTALLER_SCRIPTS_DIR/restartRouter.sh"
}

__restart_observability() {
  log_proc_msg "Restarting observability"
  source "$INSTALLER_SCRIPTS_DIR/restartObservability.sh"
}

__restart_database() {
  if check_db_variables; then
    log_proc_msg "Restarting database"
    source "$INSTALLER_SCRIPTS_DIR/restartDb.sh"
  fi
}

__restart_vault() {
  log_proc_msg "Restarting vault"
  source "$INSTALLER_SCRIPTS_DIR/restartVault.sh"
}

__restart_msg() {
  log_proc_msg "Restarting msg"
  source "$INSTALLER_SCRIPTS_DIR/restartMsg.sh"
}

__restart_redis() {
  log_proc_msg "Restarting redis"
  source "$INSTALLER_SCRIPTS_DIR/restartRedis.sh"
}

__boot_nodepoolservice() {
  log_proc_marker "Booting NodePoolService"
  exec_util "CreateService" "nodepoolservice"
}

__boot_stepService() {
  log_proc_marker "Booting Step Service"
  exec_util "CreateService" "stepservice"
}

__boot_runService() {
  log_proc_marker "Booting Run Service"
  exec_util "CreateService" "runservice"
}

__boot_logService() {
  log_proc_marker "Booting Log Service"
  exec_util "CreateService" "logservice"
}

__boot_services() {
  log_proc_marker "Booting services"
  boot_stateless_services
}

__boot_www() {
  log_proc_marker "Booting WWW"
  exec_util "CreateService" "www"
}

__boot_frontend() {
  log_proc_marker "Booting frontend"
  exec_util "CreateService" "frontend"
}

__boot_api() {
  log_proc_marker "Booting API"
  exec_util "CreateService" "api"
}

__boot_analyticsservice() {
  log_proc_marker "Booting Analytics Service"
  exec_util "CreateService" "analyticsservice"
}

main() {
  log_proc_marker  "Restarting services"
  __load_config
  __stop_services
  __restart_router
  __restart_observability
  decrypt_secrets
  __restart_database
  __restart_vault
  __restart_msg
  __restart_redis
  __boot_api
  __boot_www
  __boot_services
}

main
