#!/bin/bash
set -e
set -o pipefail

export COMPONENT="router"
export ROUTER_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export ROUTER_COMPOSE="$ROUTER_CONFIG_DIR/router_compose.yml"

__restart_router_compose() {
  log_proc_msg "Restarting router container"
  docker-compose \
    --file $ROUTER_COMPOSE down || true

  docker-compose \
    --file $ROUTER_COMPOSE  \
    up \
    --detach $COMPONENT

  log_proc_msg "Router container successfully running"
}

__check_router() {
  sleep 5
  log_proc_msg "Checking router container status on: $PIPELINES_CORE_INSTALLERIP:$PIPELINES_SHARED_ROUTER_DATAPORT"
  check_service_connection "$PIPELINES_CORE_INSTALLERIP" "$PIPELINES_SHARED_ROUTER_DATAPORT" "$COMPONENT"
}

main() {
  log_proc_marker "Restarting Router"
  __restart_router_compose
  __check_router
  # give time to router to boot
  sleep 10
  decrypt_secrets
}

main
