#!/bin/bash
set -e
set -o pipefail

export COMPONENT="vault"
export VAULT_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export VAULT_COMPOSE="$VAULT_CONFIG_DIR/vault_compose.yml"

__check_vault() {
  log_proc_msg "Checking vault container status on: $PIPELINES_SHARED_VAULT_IP:$PIPELINES_SHARED_VAULT_PORT"
  check_service_connection "$PIPELINES_SHARED_VAULT_IP" "$PIPELINES_SHARED_VAULT_PORT" "$COMPONENT"
}

__initialize_vault() {
  log_proc_msg "Initializing vault"
  source "$INSTALLER_SCRIPTS_DIR/initializeVault.sh"
}

__restart_vault_compose() {
  log_proc_msg "Restarting vault container"
  docker-compose \
    --file $VAULT_COMPOSE down || true

  docker-compose \
    --file $VAULT_COMPOSE  \
    up \
    --detach $COMPONENT

  log_proc_msg "Vault container successfully running"
}

main() {
  log_proc_marker "Restarting Vault"
  __restart_vault_compose
  __check_vault
  __initialize_vault
}

main
