const _ = require('underscore');
const util = require('util');
const pg = require('pg');
const fs = require('fs');
const path = require('path');

//bigint in postgres gets parsed as a string by default
//https://github.com/sequelize/sequelize/issues/2383#issuecomment-58006083
pg.defaults.parseInt8 = true;

module.exports = insertOOTBExtensions;

async function insertOOTBExtensions(client){
    var bag = {
        client: client,
        installerBin:  path.resolve(__dirname + "/../../../", "bin").trim(),
    }
  
    await _insertOotbExtensions(bag);
}
  
async function _insertOotbExtensions(bag){
    util.log("Processing ootb extensions update");
    var extensionsFile = `${bag.installerBin}/ootb-extensions.json`;
    if (! fs.existsSync(extensionsFile)){
      util.log(`Extensions file (${extensionsFile}) does not exist, skipping update`);
      return;
    }
    
    var extensionsJson = JSON.parse(fs.readFileSync(extensionsFile, 'utf8'));
    if (! extensionsJson) {
      util.log(`Extensions content is empty, skipping update`);
      return;
    }
  
    var keys = Object.keys( extensionsJson );
    for( var i = 0,length = keys.length; i < length; i++ ) {
        var OOTBextension        = extensionsJson[keys[i]];
        var name                 = OOTBextension.name;
        var namespace            = OOTBextension.namespace;
        var resourceType         = OOTBextension.resourceType;
        var syntaxVersion        = OOTBextension.syntaxVersion;
        var createdAt            = OOTBextension.createdAt;
        var updatedAt            = OOTBextension.updatedAt;
        var platformsPropertyBag = JSON.stringify(OOTBextension.platformsPropertyBag);
        var description          = OOTBextension.description;

        var values = `'${name}', '${resourceType}', '${description}', `
                                        +`false, '${syntaxVersion}', false, '${platformsPropertyBag}', `
                                        +`4002, '${namespace}', '${createdAt}', '${updatedAt}'`;

        var whereCondition = `name = '${name}' and namespace = '${namespace}' `
                                          +`and "resourceType" = '${resourceType}' `
                                          +`and "syntaxVersion" = '${syntaxVersion}'`;
        var updateConditionWhere = `name = '${name}' AND namespace = '${namespace}' `
                                                       +`AND "resourceType" = '${resourceType}' `
                                                       +`AND "syntaxVersion" = '${syntaxVersion}'`;

        var updateConditionSet = `description='${description}', "platformsPropertyBag"='${platformsPropertyBag}', "updatedAt"='${updatedAt}'`;
        var isMasterResourcesUpdated = `select 1 from "masterResources" where ${whereCondition};`;

        var insertQuery = `INSERT into "masterResources" (name, "resourceType", description, `
                                             +`"isInternal", "syntaxVersion", "isSyncing", `
                                             +`"platformsPropertyBag", "lastSyncStatusCode", `
                                             +`namespace, "createdAt", "updatedAt")
                                                 VALUES (${values});`;

        var updateQuery = `UPDATE "masterResources" SET ${updateConditionSet}
                             WHERE ${updateConditionWhere};`;

        var result = await bag.client.query(isMasterResourcesUpdated);
        var rowsExist = result && result.rows;
        if (rowsExist && result.rows.length == 0){
            await bag.client.query(insertQuery);
        } else if(rowsExist && result.rows.length > 0) {
            await bag.client.query(updateQuery);
        }    
    }
    return;
}
