-- Add route Roles
create or replace function set_route_role(
  httpVerb varchar, routePattern varchar, roleCode int)

  returns void as $$
  begin

    -- insert if not exists
    if not exists (select 1 from "routeRoles"
      where "httpVerb" = httpVerb and
        "routePattern" = routePattern and
        "roleCode" = roleCode
    ) then
      insert into "routeRoles" ("httpVerb", "routePattern", "roleCode",
        "createdAt", "updatedAt")
      values (httpVerb, routePattern, roleCode,
        now(), now());
    end if;
  end
$$ LANGUAGE plpgsql;

create or replace function remove_route_role(
  httpVerb varchar, routePattern varchar, roleCode int)

  returns void as $$
  begin
    DELETE
    FROM "routeRoles"
    where ("httpVerb" = httpVerb and "roleCode" = roleCode and "routePattern" = routePattern);
  end

$$ LANGUAGE plpgsql;

do $$
  begin
    -- set GET /deployKeys routeRoles
    perform set_route_role(
      routePattern := '/deployKeys',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/deployKeys',
      httpVerb := 'GET',
      roleCode := 6150
    );

    perform set_route_role(
      routePattern := '/deployKeys',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set DELETE /deployKeys/:deployKeyId routeRoles
    perform set_route_role(
      routePattern := '/deployKeys/:deployKeyId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /extensionSources routeRoles
    perform set_route_role(
      routePattern := '/extensionSources',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /extensionSources routeRoles
    perform set_route_role(
      routePattern := '/extensionSources',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /extensionSources/:extensionSourceId routeRoles
    perform set_route_role(
      routePattern := '/extensionSources/:extensionSourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /extensionSources routeRoles
    perform set_route_role(
      routePattern := '/extensionSources',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set PUT /extensionSources/:extensionSourceId routeRoles
    perform set_route_role(
      routePattern := '/extensionSources/:extensionSourceId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set DELETE /extensionSources/:extensionSourceId routeRoles
    perform set_route_role(
      routePattern := '/extensionSources/:extensionSourceId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set POST /effectivePermissions routeRoles
    perform set_route_role(
      routePattern := '/effectivePermissions',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set GET /hooks routeRoles
    perform set_route_role(
      routePattern := '/hooks',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /hooks/:hookId routeRoles
    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /hooks routeRoles
    perform set_route_role(
      routePattern := '/hooks',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/hooks',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/hooks',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /hooks/:hookId routeRoles
    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /hooks/:hookId routeRoles
    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'DELETE',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /identities routeRoles
    perform set_route_role(
      routePattern := '/identities',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /identities/:identityId routeRoles
    perform set_route_role(
      routePattern := '/identities/:identityId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /identityFavorites routeRoles
    perform set_route_role(
      routePattern := '/identityFavorites',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /identityFavorites routeRoles
    perform set_route_role(
      routePattern := '/identityFavorites',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set DELETE /identityFavorites/:identityFavoriteId routeRoles
    perform set_route_role(
      routePattern := '/identityFavorites/:identityFavoriteId',
      httpVerb := 'DELETE',
      roleCode := 6060
    );

    -- set GET /views routeRoles
    perform set_route_role(
      routePattern := '/userViews',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /views routeRoles
    perform set_route_role(
      routePattern := '/userViews',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set PUT /views routeRoles
    perform set_route_role(
      routePattern := '/userViews/:userViewId',
      httpVerb := 'PUT',
      roleCode := 6060
    );

    -- set DELETE /views/:viewId routeRoles
    perform set_route_role(
      routePattern := '/userViews/:userViewId',
      httpVerb := 'DELETE',
      roleCode := 6060
    );

    -- set GET /adminViews routeRoles
    perform set_route_role(
      routePattern := '/adminViews',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /adminViews routeRoles
    perform set_route_role(
      routePattern := '/adminViews',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set POST /adminViews routeRoles
    perform set_route_role(
      routePattern := '/adminViews',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set PUT /adminViews routeRoles
    perform set_route_role(
      routePattern := '/adminViews/:adminViewId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set PUT /adminViews routeRoles
    perform set_route_role(
      routePattern := '/adminViews/:adminViewId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set DELETE /adminViews/:viewId routeRoles
    perform set_route_role(
      routePattern := '/adminViews/:adminViewId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set DELETE /adminViews/:viewId routeRoles
    perform set_route_role(
      routePattern := '/adminViews/:adminViewId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /identityRoles routeRoles
    perform set_route_role(
      routePattern := '/identityRoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /identityTokens routeRoles
    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /identityTokens/:identityTokenId routeRoles
    perform set_route_role(
      routePattern := '/identityTokens/:identityTokenId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /identityTokens routeRoles
    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set DELETE /identityTokens/:identityTokenId routeRoles
    perform set_route_role(
      routePattern := '/identityTokens/:identityTokenId',
      httpVerb := 'DELETE',
      roleCode := 6060
    );

    -- set GET /nodePools routeRoles
    perform set_route_role(
      routePattern := '/nodePools',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /systemConfigs/customNodesAllowed routeRoles
    perform set_route_role(
      routePattern := '/systemConfigs/customNodesAllowed',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /systemConfigs/properties/:propertyKey routeRoles
    perform set_route_role(
      routePattern := '/systemConfigs/properties/:propertyKey',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /nodePools routeRoles
    perform set_route_role(
      routePattern := '/nodePools',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodePools',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /nodePools/:nodePoolId routeRoles
    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set GET /nodeMetaDataMap routeRoles
    perform set_route_role(
      routePattern := '/nodeMetaDataMap',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodeMetaDataMap',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set DELETE /nodePools/:nodePoolId routeRoles
    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /nodePools/:nodePoolId/share routeRoles
    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId/share',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId/share',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set GET /nodePools/machineTypes routeRoles
    perform set_route_role(
      routePattern := '/nodePools/machineTypes',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodePools/machineTypes',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set PUT /nodePools/:nodePoolId/share routeRoles
    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId/share',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodePools/:nodePoolId/share',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set GET /nodes routeRoles
    perform set_route_role(
      routePattern := '/nodes',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /nodes/:nodeId routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /nodes/:nodeId/validate routeRoles
     perform set_route_role(
       routePattern := '/nodes/:nodeId/validate',
       httpVerb := 'POST',
       roleCode := 6150
     );

    perform set_route_role(
        routePattern := '/nodes/:nodeId/validate',
        httpVerb := 'GET',
        roleCode := 6150
      );

     perform remove_route_role(
       routePattern := '/nodes/:nodeId/validate',
       httpVerb := 'GET',
       roleCode := 6040
     );

     perform remove_route_role(
       routePattern := '/nodes/:nodeId/validate',
       httpVerb := 'GET',
       roleCode := 6060
     );

    -- set GET /nodes/:nodeId/initScript routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId/initScript',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /nodes/:nodeId routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId',
      httpVerb := 'PUT',
      roleCode := 6150
    );

    perform remove_route_role(
      routePattern := '/nodes/:nodeId',
      httpVerb := 'PUT',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/nodes/:nodeId',
      httpVerb := 'PUT',
      roleCode := 6060
    );

    -- set POST /nodes routeRoles
    perform set_route_role(
      routePattern := '/nodes',
      httpVerb := 'POST',
      roleCode := 6140
    );

    perform set_route_role(
      routePattern := '/nodes',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set POST /nodes/updateStatistics routeRoles
    perform set_route_role(
      routePattern := '/nodes/updateStatistics',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set DELETE /nodes/:nodeId routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodes/:nodeId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /nodes/:nodeId/loggingConfiguration routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId/loggingConfiguration',
      httpVerb := 'GET',
      roleCode := 6150
    );

    -- set PUT /buildPlaneMessages/:buildPlaneMessageId routeRoles
    perform set_route_role(
      routePattern := '/buildPlaneMessages/:buildPlaneMessageId',
      httpVerb := 'PUT',
      roleCode := 6150
    );

    -- set GET /buildPlaneMessages routeRoles
    perform set_route_role(
      routePattern := '/buildPlaneMessages',
      httpVerb := 'GET',
      roleCode := 6150
    );

    -- set POST /nodes/:nodeId/nextMessage routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId/nextMessage',
      httpVerb := 'POST',
      roleCode := 6150
    );

    -- set DELETE /buildPlaneMessages/:buildPlaneMessageId routeRoles
    perform set_route_role(
      routePattern := '/buildPlaneMessages/:buildPlaneMessageId',
      httpVerb := 'DELETE',
      roleCode := 6150
    );

    -- set GET /nodes/:nodeId/nodeConsoles route roles
    perform set_route_role(
      routePattern := '/nodes/:nodeId/nodeConsoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /nodeConsoles route roles
    perform set_route_role(
      routePattern := '/nodeConsoles',
      httpVerb := 'POST',
      roleCode := 6120
    );
    -- set POST /nodeConsoles route roles
    perform set_route_role(
      routePattern := '/nodeConsoles',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set POST /nodeConsoles route roles
     perform set_route_role(
       routePattern := '/nodeConsoles',
       httpVerb := 'POST',
       roleCode := 6150
     );    

    -- set DELETE /nodes/:nodeId/nodeConsoles route roles
    perform set_route_role(
      routePattern := '/nodes/:nodeId/nodeConsoles',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodes/:nodeId/nodeConsoles',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /nodeStats routeRoles
    perform set_route_role(
      routePattern := '/nodeStats',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /nodeStats routeRoles
    perform set_route_role(
      routePattern := '/nodeStats',
      httpVerb := 'POST',
      roleCode := 6150
    );

    perform remove_route_role(
      routePattern := '/nodeStats',
      httpVerb := 'POST',
      roleCode := 6040
    );

    -- set DELETE /nodes/:nodeId/nodeStats routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId/nodeStats',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodes/:nodeId/nodeStats',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /projectIntegrations routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /projectIntegrations/:projectIntegrationId routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /projectIntegrations/:projectIntegrationId/validateRepositoryOwnerToken routeRoles
    perform set_route_role(
      routePattern :=
        '/projectIntegrations/:projectIntegrationId/validateRepositoryOwnerToken',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /projectIntegrations/:projectIntegrationId/sendEmail routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/sendEmail',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/sendEmail',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/sendEmail',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set POST /projectIntegrations routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projectIntegrations',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set POST /projectIntegrations/test routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/test',
      httpVerb := 'POST',
      roleCode := 6130
    );
    perform set_route_role(
      routePattern := '/projectIntegrations/test',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /projectIntegrations/:projectIntegrationId routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set POST /projectIntegrations/:projectIntegrationId/test routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/test',
      httpVerb := 'POST',
      roleCode := 6130
    );
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/test',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set POST /projectIntegrations/:projectIntegrationId/hook routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/hook',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/hook',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set DELETE /projectIntegrations/:projectIntegrationId routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /projectIntegrations/:projectIntegrationId/share routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/share',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/share',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set PUT /projectIntegrations/:projectIntegrationId/share routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/share',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/share',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set GET /masterIntegrations routeRoles
    perform set_route_role(
      routePattern := '/masterIntegrations',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /masterIntegrationFields routeRoles
    perform set_route_role(
      routePattern := '/masterIntegrationFields',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set passthrough routeRoles

    -- set GET /passthrough/projectIntegration/:id/branches routeRoles
    perform set_route_role(
      routePattern := '/passthrough/projectIntegrations/:projectIntegrationId/branches',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/projectIntegration/:id/tags routeRoles
    perform set_route_role(
      routePattern := '/passthrough/projectIntegrations/:projectIntegrationId/tags',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/projectIntegrations/:projectIntegrationId/repositoryNames
    perform set_route_role(
      routePattern := '/passthrough/projectIntegrations/:projectIntegrationId/repositoryNames',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set GET /passthrough/projectIntegrations/:projectIntegrationId/repositoryNames
    perform set_route_role(
      routePattern := '/passthrough/projectIntegrations/:projectIntegrationId/repositoryNames',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set GET /passthrough/missionControl/executionNodes routeRoles
    perform set_route_role(
      routePattern := '/passthrough/missionControl/executionNodes',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/nodes/scripts routeRoles
    perform set_route_role(
      routePattern := '/passthrough/nodes/scripts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/nodes/platforms routeRoles
    perform set_route_role(
      routePattern := '/passthrough/nodes/platforms',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/sockets/socketsUrl routeRoles
    perform set_route_role(
      routePattern := '/passthrough/sockets/socketsUrl',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /passthrough/sockets/joinRoom routeRoles
    perform set_route_role(
      routePattern := '/passthrough/sockets/joinRoom',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /passthrough/pipeInfo/:objectType/:objectId routeRoles
    perform set_route_role(
      routePattern := '/passthrough/pipeInfo/:objectType/:objectId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelines routeRoles
    perform set_route_role(
      routePattern := '/pipelines',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelines/latest routeRoles
    perform set_route_role(
      routePattern := '/pipelines/latest',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelines/:pipelineId routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set DELETE /pipelines/:pipelineId routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'DELETE',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /pipelines/:pipelineId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /pipelines/:pipelineId/latestState routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/latestState',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /pipelines/:pipelineId/artifacts routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /pipelines routeRoles
    perform set_route_role(
      routePattern := '/pipelines',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelines',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /pipelines/:pipelineId routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set POST /pipelines/deleteEntities
    perform set_route_role(
      routePattern := '/pipelines/deleteEntities',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set GET /pipelineSources routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineSources/:pipelineSourceId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- anonymous access
        perform set_route_role(
          routePattern := '/pipelineSources/:pipelineSourceId',
          httpVerb := 'GET',
          roleCode := 6160
        );

    -- set POST /pipelineSources routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSources',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /pipelineSources/:pipelineSourceId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /pipelineSources/:pipelineSourceId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /pipelineSyncStatuses routeRoles
    perform set_route_role(
      routePattern := '/pipelineSyncStatuses',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineSyncStatuses/:pipelineSyncStatusId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSyncStatuses/:pipelineSyncStatusId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /pipelineSyncStatuses routeRoles
    perform set_route_role(
      routePattern := '/pipelineSyncStatuses',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSyncStatuses',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /pipelineSyncStatuses/:pipelineSyncStatusId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSyncStatuses/:pipelineSyncStatusId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSyncStatuses/:pipelineSyncStatusId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /pipelineSyncStatuses/:pipelineSyncStatusId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSyncStatuses/:pipelineSyncStatusId',
      httpVerb := 'DELETE',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/pipelineSyncStatuses/:pipelineSyncStatusId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSyncStatuses/:pipelineSyncStatusId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /pipelineSourceObjectPermissions routeRoles
    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /pipelineSourceObjectPermissions routeRoles
    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set DELETE /pipelineSourceObjectPermissions/:pipelineSourceObjectPermissionId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions/:pipelineSourceObjectPermissionId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions/:pipelineSourceObjectPermissionId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set DELETE /pipelineSourceObjectPermissions/pipelineSource/:pipelineSourceId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions/pipelineSource/:pipelineSourceId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions/pipelineSource/:pipelineSourceId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set DELETE /pipelineSourceObjectPermissions/:objectType/:objectId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions/:objectType/:objectId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions/:objectType/:objectId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /pipelineStepConnections routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineStepConnections/pipelineConnections routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections/pipelineConnections',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineStepConnections/:pipelineStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /pipelineStepConnections routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set POST /pipelineStepConnections/bulk routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections/bulk',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections/bulk',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /pipelineStepConnections/:pipelineStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /pipelineStepConnections/:pipelineStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /pipelines/:pipelineId/pipelineConnections routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/pipelineConnections',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/pipelineConnections',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/pipelineConnections',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set GET /pipelineSteps routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineSteps/:pipelineStepId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineSteps/:pipelineStepId/latestArchive routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/latestArchive',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /pipelineSteps/:pipelineStepId/trigger routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/trigger',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/trigger',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set POST /pipelines/trigger routeRoles
    perform set_route_role(
      routePattern := '/pipelines/trigger',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelines/trigger',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set GET /pipelineSteps/:pipelineStepId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set POST /pipelineSteps routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSteps',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /pipelineSteps/:pipelineStepId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /pipelineSteps/:pipelineStepId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /pipelineSteplets routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteplets',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineSteplets/:pipelineStepletId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineSteplets/:pipelineStepletId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /pipelineSteplets routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteplets',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /pipelineSteplets/:pipelineStepletId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /pipelineSteplets/:pipelineStepletId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'DELETE',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /projects routeRoles
    perform set_route_role(
      routePattern := '/projects',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /projects/:projectId routeRoles
    perform set_route_role(
      routePattern := '/projects/:projectId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /projects/:projectId/state routeRoles
    perform set_route_role(
      routePattern := '/projects/:projectId/state',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /projects routeRoles
    perform set_route_role(
      routePattern := '/projects',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set PUT /projects/:projectId routeRoles
    perform set_route_role(
      routePattern := '/projects/:projectId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projects/:projectId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /projects/:projectId/clean/pipelineSources
    perform remove_route_role(
      routePattern := 'projects/:projectId/clean/pipelineSources',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform remove_route_role(
      routePattern := '/projects/:projectId/clean/pipelineSources',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/projects/:projectId/clean/platformResources',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /projectPermissions routeRoles
    perform set_route_role(
      routePattern := '/projectPermissions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /projectPermissions routeRoles
    perform set_route_role(
      routePattern := '/projectPermissions',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set DELETE /projectPermissions/:projectPermissionId routeRoles
    perform set_route_role(
      routePattern := '/projectPermissions/:projectPermissionId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /providers/:providerId routeRoles
    perform remove_route_role(
      routePattern := '/providers/:providerId',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/providers/:providerId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /providers routeRoles
    perform remove_route_role(
      routePattern := '/providers',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/providers',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resources routeRoles
    perform set_route_role(
      routePattern := '/resources',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resources/:resourceId routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /resources/:resourceId routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /resources/:resourceId routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'DELETE',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /resources/:resourceId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set POST /resources routeRoles
    perform set_route_role(
      routePattern := '/resources',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resources',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set GET /resourceVersions routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resourceVersions/light routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions/light',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resourceVersions/:resourceVersionId routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /resourceVersions routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set DELETE /resourceVersions/:resourceVersionId routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set DELETE /resources/:resourceId/resourceVersions routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId/resourceVersions',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId/resourceVersions',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId/resourceVersions',
      httpVerb := 'DELETE',
      roleCode := 6120
    );

    -- set GET /runResourceVersions routeRoles
    perform set_route_role(
      routePattern := '/runResourceVersions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runResourceVersions/light routeRoles
    perform set_route_role(
      routePattern := '/runResourceVersions/light',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runResourceVersions/:runResourceVersionId routeRoles
    perform set_route_role(
      routePattern := '/runResourceVersions/:runResourceVersionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /runResourceVersions routeRoles
    perform set_route_role(
      routePattern := '/runResourceVersions',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/runResourceVersions',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /runResourceVersions/:runResourceVersionId routeRoles
    perform set_route_role(
      routePattern := '/runResourceVersions/:runResourceVersionId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/runResourceVersions/:runResourceVersionId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /pipelines/:pipelineId/runResourceVersions routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/runResourceVersions',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/runResourceVersions',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set POST /resourceVersions/:resourceVersionId/updateCommitStatus routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId/updateCommitStatus',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId/updateCommitStatus',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId/updateCommitStatus',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set GET /runs routeRoles
    perform set_route_role(
      routePattern := '/runs',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runs/:runId routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /runs/:runId routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId',
      httpVerb := 'PUT',
      roleCode := 6060
    );

    -- set GET /runs/:runId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /runs/:runId/runState routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/runState',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /runs/:runId/artifacts routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/artifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set HEAD /runs/:runId/artifacts routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/artifacts',
      httpVerb := 'HEAD',
      roleCode := 6060
    );

    -- set POST /runs/:runId/nextSteps routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/nextSteps',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/runs/:runId/nextSteps',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set POST /runs routeRoles
    perform set_route_role(
      routePattern := '/runs',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/runs',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set POST /runs/:runId/cancel routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/cancel',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runs/:runId/cancel',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set DELETE /pipelines/:pipelineId/runs routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/runs',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/runs',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /runStepConnections routeRoles
    perform set_route_role(
      routePattern := '/runStepConnections',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runStepConnections/:runStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /runStepConnections routeRoles
    perform set_route_role(
      routePattern := '/runStepConnections',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/runStepConnections',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /runStepConnections/:runStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /runStepConnections/:runStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set DELETE /pipelines/:pipelineId/runStepConnections routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/runStepConnections',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/runStepConnections',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /steps/:stepId/consoles routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/consoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /stepContext/artifactoryBuilds routeRoles
    perform set_route_role(
      routePattern := '/stepContext/artifactoryBuilds',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/stepContext/artifactoryBuilds',
      httpVerb := 'GET',
      roleCode := 6160
    );

    -- set GET /stepContext/codeAnalysis routeRoles
    perform set_route_role(
      routePattern := '/stepContext/codeAnalysis',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/stepContext/codeAnalysis',
      httpVerb := 'GET',
      roleCode := 6160
    );

    -- set POST /stepConsoles routeRoles
    perform set_route_role(
      routePattern := '/stepConsoles',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/stepConsoles',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set DELETE /steps/:stepId/stepConsoles routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/stepConsoles',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /pipelines/:pipelineId/stepConsoles routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/stepConsoles',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /steplets/:stepletId/consoles routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/consoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /stepletConsoles routeRoles
    perform set_route_role(
      routePattern := '/stepletConsoles',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/stepletConsoles',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set DELETE /steplets/:stepletId/consoles routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/stepletConsoles',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /pipelines/:pipelineId/stepletConsoles routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/stepletConsoles',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /steplets routeRoles
    perform set_route_role(
      routePattern := '/steplets',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steplets/:stepletId routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /steplets/:stepletId routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    -- set GET /steplets/:stepletId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /steplets/:stepletId/testReportArtifactUrl routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/testReportArtifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set POST /steplets routeRoles
    perform set_route_role(
      routePattern := '/steplets',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/steplets',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set DELETE /steplets/:stepletId routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    -- set GET /steplets/:stepletId/runArtifactUrl routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/runArtifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /steplets/:stepletId/runState routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/runState',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set HEAD  /steplets/:stepletId/runState routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/runState',
      httpVerb := 'HEAD',
      roleCode := 6060
    );

    -- set DELETE /pipelines/:pipelineId/steplets routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/steplets',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steps/:stepId/stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set DELETE /stepTestReports/:stepTestReportId routeRoles
    perform set_route_role(
      routePattern := '/stepTestReports/:stepTestReportId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /steps/:stepId/stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/stepTestReports',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /testElements routeRoles
    perform set_route_role(
            routePattern := '/testElements',
            httpVerb := 'GET',
            roleCode := 6060
        );

    -- set POST /testElements routeRoles
    perform set_route_role(
            routePattern := '/testElements',
            httpVerb := 'POST',
            roleCode := 6120
        );

    perform set_route_role(
            routePattern := '/testElements',
            httpVerb := 'POST',
            roleCode := 6130
        );

    -- set DELETE /pipelines/:pipelineId/testElements routeRoles
    perform set_route_role(
            routePattern := '/pipelines/:pipelineId/testElements',
            httpVerb := 'DELETE',
            roleCode := 6130
        );

    perform set_route_role(
            routePattern := '/pipelines/:pipelineId/testElements',
            httpVerb := 'DELETE',
            roleCode := 6120
        );

    -- set GET /stepletTestReports routeRoles
    perform set_route_role(
      routePattern := '/stepletTestReports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steplets/:stepletId/stepletTestReports routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/stepletTestReports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /stepletTestReports routeRoles
    perform set_route_role(
      routePattern := '/stepletTestReports',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/stepletTestReports',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set DELETE /stepletTestReports/:stepletTestReportId routeRoles
    perform set_route_role(
      routePattern := '/stepletTestReports/:stepletTestReportId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /steps/:stepId/stepletTestReports routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/stepletTestReports',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /steplets/:stepletId/stepletTestReports routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/stepletTestReports',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /pipelines/:pipelineId/stepletTestReports routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/stepletTestReports',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /pipelines/:pipelineId/stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/stepTestReports',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /steps routeRoles
    perform set_route_role(
      routePattern := '/steps',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steps/:stepId routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steplets/:stepletId/testReport routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/testReport',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steps/:stepId/testStackTrace/:traceId routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/testStackTrace/:traceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /steps/:stepId routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set PUT /steps/:stepId/finalizeStatus routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/finalizeStatus',
      httpVerb := 'PUT',
      roleCode := 6020
    );
    -- set PUT /steps/:stepId/finalizeStatus routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/finalizeStatus',
      httpVerb := 'PUT',
      roleCode := 6120
    );
    -- set PUT /steps/:stepId/finalizeStatus routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/finalizeStatus',
      httpVerb := 'PUT',
      roleCode := 6130
    );


    -- set DELETE /steps/:stepId/runSetupKey routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/runSetupKey',
      httpVerb := 'DELETE',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/runSetupKey',
      httpVerb := 'DELETE',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/runSetupKey',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /steps/:stepId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /steps/:stepId/reports routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/reports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set HEAD /steps/:stepId/reports routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/reports',
      httpVerb := 'HEAD',
      roleCode := 6060
    );

    -- set POST /steps routeRoles
    perform set_route_role(
      routePattern := '/steps',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/steps',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set GET /steps/:stepId/executionEligibility routeRoles

    perform set_route_role(
      routePattern := '/steps/:stepId/executionEligibility',
      httpVerb := 'GET',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/executionEligibility',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set PUT /steps/:stepId/status routeRoles

    perform set_route_role(
      routePattern := '/steps/:stepId/status',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/status',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/status',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set PUT /steps/:stepId/heartbeat routeRoles

    perform set_route_role(
      routePattern := '/steps/:stepId/heartbeat',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/heartbeat',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/heartbeat',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set GET /steps/:stepId/runArtifactUrl routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/runArtifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set POST /steps/:stepId/approvalResponse routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/approvalResponse',
      httpVerb := 'POST',
      roleCode := 6060
    );

    perform remove_route_role(
      routePattern := '/steps/:stepId/approvalResponse',
      httpVerb := 'POST',
      roleCode := 6020
    );

    -- set POST /steps/:stepId/requestApproval routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/requestApproval',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/requestApproval',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set GET /stepVariables routeRoles
    perform set_route_role(
      routePattern := '/stepVariables',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /stepVariables/:stepVariableId routeRoles
    perform set_route_role(
      routePattern := '/stepVariables/:stepVariableId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /stepVariables routeRoles
    perform set_route_role(
      routePattern := '/stepVariables',
      httpVerb := 'POST',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/stepVariables',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set PUT /stepVariables/:stepVariableId routeRoles
    perform set_route_role(
      routePattern := '/stepVariables/:stepVariableId',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    perform set_route_role(
      routePattern := '/stepVariables/:stepVariableId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set DELETE /stepVariables/:stepVariableId routeRoles
    perform set_route_role(
      routePattern := '/stepVariables/:stepVariableId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /pipelines/:pipelineId/stepVariables routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/stepVariables',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /steplets/:stepletId/stepVariables routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/stepVariables',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set DELETE /pipelines/:pipelineId/steps routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/steps',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /systemCodes routeRoles
    perform set_route_role(
      routePattern := '/systemCodes',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/systemCodes',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/systemCodes',
      httpVerb := 'GET',
      roleCode := 6150
    );

    -- set GET /passthrough/access/pipelineSourcePermissions/:pipelineSourceId
    perform set_route_role(
      routePattern := '/passthrough/access/pipelineSourcePermissions/:pipelineSourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/access/projectPermissions/:projectId
    perform set_route_role(
      routePattern := '/passthrough/access/projectPermissions/:projectId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/access/projects/:projectId/pipelineSources
    perform set_route_role(
      routePattern := '/passthrough/access/projects/:projectId/pipelineSources',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set PUT /passthrough/access/projects/:projectId/pipelineSources
    perform set_route_role(
      routePattern := '/passthrough/access/projects/:projectId/pipelineSources',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set GET /passthrough/access/projects/:projectId/projectIntegrations
    perform set_route_role(
      routePattern := '/passthrough/access/projects/:projectId/projectIntegrations',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set PUT /passthrough/access/projects/:projectId/projectIntegrations
    perform set_route_role(
      routePattern := '/passthrough/access/projects/:projectId/projectIntegrations',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set GET /passthrough/access/projects/:projectId/nodePools
    perform set_route_role(
      routePattern := '/passthrough/access/projects/:projectId/nodePools',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set PUT /passthrough/access/projects/:projectId/nodePools
    perform set_route_role(
      routePattern := '/passthrough/access/projects/:projectId/nodePools',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set GET /passthrough/projectIntegrations/:projectIntegrationId/sha
    perform set_route_role(
      routePattern := '/passthrough/projectIntegrations/:projectIntegrationId/sha',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/passthrough/projectIntegrations/:projectIntegrationId/sha',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set POST /validateYaml
    perform set_route_role(
      routePattern := '/validateYaml/pde',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /pde/files
    perform set_route_role(
      routePattern := '/pde/files',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /pde/files
    perform set_route_role(
      routePattern := '/pde/files/save',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set POST /validateYaml
    perform set_route_role(
      routePattern := '/validateYaml',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set POST /validateYaml/json
    perform set_route_role(
      routePattern := '/validateYaml/json',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set POST /validateTemplate
    perform set_route_role(
      routePattern := '/validateTemplate',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /buildPlaneImages
    perform set_route_role(
      routePattern := '/buildPlaneImages',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /buildPlaneImages
    perform set_route_role(
      routePattern := '/buildPlaneImages',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set PUT /buildPlaneImages/:buildPlaneImageId
    perform set_route_role(
      routePattern := '/buildPlaneImages/:buildPlaneImageId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set DELETE /buildPlaneImages/:buildPlaneImageId
    perform set_route_role(
      routePattern := '/buildPlaneImages/:buildPlaneImageId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /internal/usage
    perform set_route_role(
      routePattern := '/internal/usage',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set GET /webhooks
    perform set_route_role(
      routePattern := '/webhooks',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /webhooks/:webhookId
    perform set_route_role(
      routePattern := '/webhooks/:webhookId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /resources/:resourceId/hook
    perform set_route_role(
      routePattern := '/resources/:resourceId/hook',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId/hook',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId/hook',
      httpVerb := 'POST',
      roleCode := 6120
    );

    -- set GET /masterResources/:masterResourceId routeRoles
    perform set_route_role(
      routePattern := '/masterResources/:masterResourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set DELETE /masterResources/:masterResourceId routeRoles
    perform set_route_role(
      routePattern := '/masterResources/:masterResourceId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set POST /masterResources routeRoles
    perform set_route_role(
      routePattern := '/masterResources',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set POST /masterResources/:masterResourceId/release routeRoles
    perform set_route_role(
      routePattern := '/masterResources/:masterResourceId/release',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set GET /masterResources/:masterResourceId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/masterResources/:masterResourceId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /masterResources routeRoles
    perform set_route_role(
      routePattern := '/masterResources',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/masterResources',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set PUT /masterResources/:masterResourceId routeRoles
    perform set_route_role(
      routePattern := '/masterResources/:masterResourceId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set GET /masterResources/:masterResourceId/artifacts routeRoles
    perform set_route_role(
      routePattern := '/masterResources/:masterResourceId/artifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );


    -- set GET /templates routeRoles
    perform set_route_role(
      routePattern := '/templates',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/templates',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set GET /templates/:templateId routeRoles
    perform set_route_role(
      routePattern := '/templates/:templateId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/templates/:templateId',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set DELETE /templates/:templateId routeRoles
    perform set_route_role(
      routePattern := '/templates/:templateId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set GET /templates/versions routeRoles
    perform set_route_role(
      routePattern := '/templates/versions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /templates/retire routeRoles (admin saas)
    perform set_route_role(
      routePattern := '/templates/retire',
      httpVerb := 'PATCH',
      roleCode := 6130
    );

    -- set GET /templates/retire routeRoles (project admin)
    perform set_route_role(
      routePattern := '/templates/retire',
      httpVerb := 'PATCH',
      roleCode := 6140
    );

    -- set GET /templates/artifacts routeRoles
    perform set_route_role(
      routePattern := '/templates/artifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /templates routeRoles
    perform remove_route_role(
      routePattern := '/templates',
      httpVerb := 'POST',
      roleCode := 6140
    );

    perform set_route_role(
      routePattern := '/templates',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set POST /templates/:templateId/release routeRoles
    perform set_route_role(
      routePattern := '/templates/:templateId/release',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set GET /templates/:templateId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/templates/:templateId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set PUT /templates/:templateId routeRoles
    perform set_route_role(
      routePattern := '/templates/:templateId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

     -- set GET /templates/:templateId/artifacts routeRoles
    perform set_route_role(
      routePattern := '/templates/:templateId/artifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /templates/content routeRoles
    perform set_route_role(
      routePattern := '/templates/content',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /templatesInUse/pipelines/count routeRoles
    perform set_route_role(
      routePattern := '/templatesInUse/pipelines/count',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /templatesInUse/pipelines/names routeRoles
    perform set_route_role(
      routePattern := '/templatesInUse/pipelines/names',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /templatesInUse/pipelines/:pipelineId routeRoles
    perform set_route_role(
      routePattern := '/templatesInUse/pipelines/:pipelineId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /templateSources routeRoles
    perform set_route_role(
      routePattern := '/templateSources',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /templateSources routeRoles
    perform set_route_role(
      routePattern := '/templateSources',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /templateSources/:templateSourceId routeRoles
    perform set_route_role(
      routePattern := '/templateSources/:templateSourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /templateSources routeRoles
    perform set_route_role(
      routePattern := '/templateSources',
      httpVerb := 'POST',
      roleCode := 6130
    );

    -- set PUT /templateSources/:templateSourceId routeRoles
    perform set_route_role(
      routePattern := '/templateSources/:templateSourceId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    -- set DELETE /templateSources/:templateSourceId routeRoles
    perform set_route_role(
      routePattern := '/templateSources/:templateSourceId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    -- set POST /pipelineObjects routeRoles
    perform set_route_role(
      routePattern := '/pipelineObjects',
      httpVerb := 'POST',
      roleCode := 6120
    );

    -- set GET /pipelineObjects routeRoles
    perform set_route_role(
      routePattern := '/pipelineObjects',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /pipeInfo/verify routeRoles
    perform set_route_role(
      routePattern := '/pipeInfo/verify',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipeInfo/verify routeRoles
    perform set_route_role(
      routePattern := '/pipeInfo/verify',
      httpVerb := 'GET',
      roleCode := 6120
    );

    -- set GET /pipeInfo/verifyStep/:stepId routeRoles
    perform set_route_role(
      routePattern := '/pipeInfo/verifyStep/:stepId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipeInfo/verifyRun/:runId routeRoles
    perform set_route_role(
      routePattern := '/pipeInfo/verifyRun/:runId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /unifiedUiUrl routeRoles
    perform set_route_role(
      routePattern := '/unifiedUiUrl',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/unifiedUiUrl',
      httpVerb := 'GET',
      roleCode := 6140
    );

    perform set_route_role(
      routePattern := '/unifiedUiUrl',
      httpVerb := 'GET',
      roleCode := 6150
    );

    -- set GET /search/pipelines routeRoles
    perform set_route_role(
      routePattern := '/search/pipelines',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /disabledEntities routeRoles
    perform set_route_role(
      routePattern := '/disabledEntities',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/disabledEntities',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/disabledEntities',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set POST /disabledEntities routeRoles
    perform set_route_role(
      routePattern := '/disabledEntities',
      httpVerb := 'POST',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/disabledEntities',
      httpVerb := 'POST',
      roleCode := 6140
    );

    -- set PUT /disabledEntities/:disabledEntityId routeRoles
    perform set_route_role(
      routePattern := '/disabledEntities/:disabledEntityId',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/disabledEntities/:disabledEntityId',
      httpVerb := 'PUT',
      roleCode := 6140
    );

    -- set DELETE /disabledEntities/:disabledEntityId routeRoles
    perform set_route_role(
      routePattern := '/disabledEntities/:disabledEntityId',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/disabledEntities/:disabledEntityId',
      httpVerb := 'DELETE',
      roleCode := 6140
    );

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/effectivePermissions') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/effectivePermissions';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6060 and "routePattern" = '/pipelines/:pipelineId/latestState') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6060 and "routePattern" = '/pipelines/:pipelineId/latestState';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6130 and "routePattern" = '/pipelineSteps/:pipelineStepId/artifactUrl') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6130 and "routePattern" = '/pipelineSteps/:pipelineStepId/artifactUrl';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6130 and "routePattern" = '/masterResources/:masterResourceId/artifactUrl') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6130 and "routePattern" = '/masterResources/:masterResourceId/artifactUrl';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/extensionSources') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/extensionSources';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/extensionSources/:extensionSourceId') then
      DELETE FROM "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/extensionSources/:extensionSourceId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/extensionSources/:extensionSourceId') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/extensionSources/:extensionSourceId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/internal/usage') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/internal/usage';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/masterResources/:masterResourceId') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/masterResources/:masterResourceId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/masterResources') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/masterResources';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/masterResources/:masterResourceId/release') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/masterResources/:masterResourceId/release';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/masterResources/:masterResourceId') then
      DELETE FROM "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/masterResources/:masterResourceId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/nodeConsoles') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/nodeConsoles';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/nodeMetaDataMap') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/nodeMetaDataMap';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/nodes/updateStatistics') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/nodes/updateStatistics';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6130 and "routePattern" = '/passthrough/artifacts/:artifactName') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6130 and "routePattern" = '/passthrough/artifacts/:artifactName';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/passthrough/artifacts/:artifactName') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/passthrough/artifacts/:artifactName';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/pipelineSteps/:pipelineStepId/trigger') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/pipelineSteps/:pipelineStepId/trigger';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/projectPermissions') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/projectPermissions';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/projectPermissions/:projectPermissionId') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/projectPermissions/:projectPermissionId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/projects') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/projects';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/resources/:resourceId/hook') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/resources/:resourceId/hook';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/resources/:resourceId/hook') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/resources/:resourceId/hook';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/runs/:runId/nextSteps') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/runs/:runId/nextSteps';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId') then
      DELETE FROM "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/steps') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/steps';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepConsoles') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepConsoles';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepConsoles') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepConsoles';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/stepConsoles') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/stepConsoles';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepletConsoles') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepletConsoles';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steplets/:stepletId/stepletConsoles') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steplets/:stepletId/stepletConsoles';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepletConsoles') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepletConsoles';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/steplets/:stepletId') then
      DELETE FROM "routeRoles" where "httpVerb"='PUT' and "roleCode" = 6140 and "routePattern" = '/steplets/:stepletId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/steplets') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/steplets';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepTestReports') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepTestReports';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/stepTestReports/:stepTestReportId') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/stepTestReports/:stepTestReportId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/stepTestReports') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/stepTestReports';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepTestReports') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepTestReports';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepletTestReports') then
      DELETE FROM "routeRoles" where "httpVerb"='POST' and "roleCode" = 6140 and "routePattern" = '/stepletTestReports';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/stepletTestReports') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/stepletTestReports';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steplets/:stepletId/stepletTestReports') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/steplets/:stepletId/stepletTestReports';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/stepletTestReports/:stepletTestReportId') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/stepletTestReports/:stepletTestReportId';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepletTestReports') then
      DELETE FROM "routeRoles" where "httpVerb"='DELETE' and "roleCode" = 6140 and "routePattern" = '/pipelines/:pipelineId/stepletTestReports';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/executionEligibility') then
      DELETE FROM "routeRoles" where "httpVerb"='GET' and "roleCode" = 6140 and "routePattern" = '/steps/:stepId/executionEligibility';
    end if;

    -- set GET /system/logs/config routeRoles
    perform set_route_role(
      routePattern := '/system/logs/config',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set GET /system/logs/data routeRoles
    perform set_route_role(
      routePattern := '/system/logs/data',
      httpVerb := 'GET',
      roleCode := 6130
    );

    if exists (select 1 from "routeRoles" where "httpVerb" = 'POST' and "roleCode" = 6060 and "routePattern" = '/vortex') then
      DELETE FROM "routeRoles" where "httpVerb" = 'POST' and "roleCode" = 6060 and "routePattern" = '/vortex';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6060 and "routePattern" = '/vortex') then
      DELETE FROM "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6060 and "routePattern" = '/vortex';
    end if;

    -- set POST /extensionSources/:extensionSourceId/triggerSync routeRoles
    perform set_route_role(
      routePattern := '/extensionSources/:extensionSourceId/triggerSync',
      httpVerb := 'POST',
      roleCode := 6120
    );

    -- set POST /pipelineSources/:pipelineSourceId/triggerSync routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId/triggerSync',
      httpVerb := 'POST',
      roleCode := 6120
    );

    -- set POST /templateSources/:templateSourceId/triggerSync routeRoles
    perform set_route_role(
      routePattern := '/templateSources/:templateSourceId/triggerSync',
      httpVerb := 'POST',
      roleCode := 6120
    );

    -- set POST /runs/triggerRun routeRoles
    perform set_route_role(
      routePattern := '/runs/triggerRun',
      httpVerb := 'POST',
      roleCode := 6120
    );

    -- set GET /stepArtifacts routeRoles
    perform set_route_role(
      routePattern := '/stepArtifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /stepArtifacts routeRoles
    perform set_route_role(
      routePattern := '/stepArtifacts',
      httpVerb := 'PUT',
      roleCode := 6120
    );

    -- set GET /frontend/pipeinfo routeRoles
    perform set_route_role(
      routePattern := '/frontend/pipeinfo',
      httpVerb := 'GET',
      roleCode := 6060
    );
    -- set GET /events/domains routeRoles
    perform set_route_role(
        routePattern := '/events/domains',
        httpVerb := 'GET',
        roleCode := 6020
      );

    -- set POST /events/subscriptions/validate routeRoles
    perform set_route_role(
        routePattern := '/events/subscriptions/validate',
        httpVerb := 'POST',
        roleCode := 6020
      );

-- set GET /system/info routeRoles
    perform set_route_role(
      routePattern := '/system/info',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/system/info',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/system/info',
      httpVerb := 'GET',
      roleCode := 6150
    );

-- set GET /system/configStatus routeRoles
    perform set_route_role(
      routePattern := '/system/configStatus',
      httpVerb := 'GET',
      roleCode := 6130
    );

-- set HEAD /system/health routeRoles
    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'HEAD',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'HEAD',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'HEAD',
      roleCode := 6150
    );

-- set GET /system/health routeRoles
    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'GET',
      roleCode := 6150
    );

    if exists (select 1 from "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6060 and "routePattern" = 'frontend/pipeinfo') then
      DELETE FROM "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6060 and "routePattern" = 'frontend/pipeinfo';
    end if;

    -- set GET /metrics routeRoles
    perform set_route_role(
      routePattern := '/metrics',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- set GET /passthrough/artifacts/:artifactName routeRoles
    perform set_route_role(
      routePattern := '/passthrough/artifacts/:artifactName',
      httpVerb := 'GET',
      roleCode := 6150
    );

    perform set_route_role(
      routePattern := '/passthrough/artifacts/:artifactName',
      httpVerb := 'HEAD',
      roleCode := 6150
    );

    perform set_route_role(
      routePattern := '/passthrough/artifacts/:artifactName',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/passthrough/artifacts/:artifactName',
      httpVerb := 'HEAD',
      roleCode := 6060
    );

    -- set GET /v1/swagger.yml routeRoles
    perform set_route_role(
      routePattern := '/swagger.yml',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/swagger.yml',
      httpVerb := 'GET',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/swagger.yml',
      httpVerb := 'GET',
      roleCode := 6140
    );

    -- set GET /system/activeRequests routeRoles
    perform set_route_role(
      routePattern := '/system/activeRequests',
      httpVerb := 'GET',
      roleCode := 6130
    );

    -- Anonymous user routes
    perform set_route_role(
      routePattern := '/masterResources',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/hooks',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/hooks/:hookId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identities',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identities/:identityId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identityFavorites',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identityFavorites/:identityFavoriteId',
      httpVerb := 'DELETE',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identityRoles',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identityTokens/:identityTokenId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'POST',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/identityTokens/:identityTokenId',
      httpVerb := 'DELETE',
      roleCode := 6160
    );

    if exists (select 1 from "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/systemConfigs/customNodesAllowed') then
        DELETE FROM "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/systemConfigs/customNodesAllowed';
    end if;

    perform set_route_role(
      routePattern := '/systemConfigs/properties/:propertyKey',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/systemConfigs/:configName',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/systemConfigs/:configName',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/systemConfigs/:configName',
      httpVerb := 'PUT',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/systemConfigs/:configName',
      httpVerb := 'DELETE',
      roleCode := 6130
    );

    perform set_route_role(
      routePattern := '/nodeMetaDataMap',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/masterIntegrations',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/masterIntegrationFields',
      httpVerb := 'GET',
      roleCode := 6160
    );

    if exists (select 1 from "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/passthrough/missionControl/executionNodes') then
        DELETE FROM "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/passthrough/missionControl/executionNodes';
    end if;

    perform set_route_role(
      routePattern := '/passthrough/sockets/socketsUrl',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/passthrough/sockets/joinRoom',
      httpVerb := 'POST',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/passthrough/pipeInfo/:objectType/:objectId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelines',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelines/latest',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifacts',
      httpVerb := 'GET',
      roleCode := 6160
    );

    if exists (select 1 from "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/pipelineSyncStatuses') then
      DELETE FROM "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/pipelineSyncStatuses';
    end if;

    if exists (select 1 from "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/pipelineSyncStatuses/:pipelineSyncStatusId') then
      DELETE FROM "routeRoles" where "httpVerb" = 'GET' and "roleCode" = 6160 and "routePattern" = '/pipelineSyncStatuses/:pipelineSyncStatusId';
    end if;

    -- commenting the anonymous user access for pipelineSyncStatuses. we need to revisit the same
    -- perform set_route_role(
    --   routePattern := '/pipelineSyncStatuses',
    --   httpVerb := 'GET',
    --   roleCode := 6160
    -- );

    -- perform set_route_role(
    --   routePattern := '/pipelineSyncStatuses/:pipelineSyncStatusId',
    --   httpVerb := 'GET',
    --   roleCode := 6160
    -- );

    perform set_route_role(
      routePattern := '/pipelineSourceObjectPermissions',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections/pipelineConnections',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/pipelineConnections',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineSteps',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/latestArchive',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipelineSteplets/:pipelineStepletId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/projects',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/projects/:projectId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/projects/:projectId/state',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/projectPermissions',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/providers/:providerId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/providers',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/resources',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/resourceVersions/light',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runResourceVersions',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runResourceVersions/light',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runResourceVersions/:runResourceVersionId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runs',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runs/:runId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runs/:runId',
      httpVerb := 'PUT',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runs/:runId/artifacts',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runs/:runId/artifacts',
      httpVerb := 'HEAD',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runStepConnections',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/consoles',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/consoles',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steplets',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/runState',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/runState',
      httpVerb := 'HEAD',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
        routePattern := '/testElements',
        httpVerb := 'GET',
        roleCode := 6160
    );

    perform set_route_role(
        routePattern := '/steplets/:stepletId/testReport',
        httpVerb := 'GET',
        roleCode := 6160
    );

    perform set_route_role(
        routePattern := '/steps/:stepId/testStackTrace/:traceId',
        httpVerb := 'GET',
        roleCode := 6160
    );

    perform set_route_role(
        routePattern := '/steplets/:stepletId/testReport',
        httpVerb := 'GET',
        roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/stepletTestReports',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/stepletTestReports',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steps',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/reports',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/reports',
      httpVerb := 'HEAD',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/approvalResponse',
      httpVerb := 'POST',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/stepVariables',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/stepVariables/:stepVariableId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/systemCodes',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/passthrough/access/pipelineSourcePermissions/:pipelineSourceId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/passthrough/access/projectPermissions/:projectId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/validateYaml',
      httpVerb := 'POST',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/buildPlaneImages',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/webhooks',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/webhooks/:webhookId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/pipeInfo/verify',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/search/pipelines',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/stepArtifacts',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/frontend/pipeinfo',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/system/info',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'HEAD',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/system/health',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/passthrough/artifacts/:artifactName',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/passthrough/artifacts/:artifactName',
      httpVerb := 'HEAD',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/swagger.yml',
      httpVerb := 'GET',
      roleCode := 6160
    );

    perform set_route_role(
      routePattern := '/templatesInUse/pipelines/:pipelineId',
      httpVerb := 'GET',
      roleCode := 6160
    );

    -- set GET /tasks routeRoles
    perform set_route_role(
      routePattern := '/tasks',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /tasks/versions routeRoles
    perform set_route_role(
      routePattern := '/tasks/versions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /tasks/readme routeRoles
    perform set_route_role(
      routePattern := '/tasks/readme',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /nodes/:nodeId/stop routeRoles
    perform set_route_role(
      routePattern := '/nodes/:nodeId/stop',
      httpVerb := 'POST',
      roleCode := 6150
    );

    perform set_route_role(
      routePattern := '/validateWorkspace',
      httpVerb := 'POST',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/workspaces',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/syncWorkspace',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/workspaces/:projectName',
      httpVerb := 'DELETE',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/analytics/testReports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/analytics/codeAnalysis',
      httpVerb := 'GET',
      roleCode := 6060
    );

end

$$;
