const _ = require('underscore');
const util = require('util');
const pg = require('pg');
const fs = require('fs');
const path = require('path');

//bigint in postgres gets parsed as a string by default
//https://github.com/sequelize/sequelize/issues/2383#issuecomment-58006083
pg.defaults.parseInt8 = true;

module.exports = updateBuildPlaneJson;

async function updateBuildPlaneJson(client){
    var buildPlaneVersion=`${process.env.PIPELINEVERSION}`;

    var bag = {
        client: client,
        installerBin:  path.resolve(__dirname + "/../../../", "bin").trim(),
    }
  
    util.log(`Updating build plane version (${buildPlaneVersion}) for all nodes`);
    var sql = `update nodes set "intendedBuildPlaneVersion"='${buildPlaneVersion}';`;
    await bag.client.query(sql);
    await _updateBuildPlaneImages(bag);
}

function _getMasterIntegrationId(provider, masterIntegrationList){
    var id = "";
    if (masterIntegrationList && masterIntegrationList[provider]){
      id = masterIntegrationList[provider];
    }
    return id;
}
  
async function _createMasterIntegrationList(bag){
    var sql = `select id,name from "masterIntegrations";`;
    try {
      var result = await bag.client.query(sql);
    } catch (err) {
      util.log(err);
      util.log("Failed to get master integrations from database");
      return;
    }
  
    var masterIntegrationList = result && result.rows || [];
    var parsedMasterIntegrationList = {};
  
    for( var i = 0,length = masterIntegrationList.length; i < length; i++ ) {
      var id = masterIntegrationList[i].id;
      var name = masterIntegrationList[i].name;
      parsedMasterIntegrationList[name] = id;
    }
    return parsedMasterIntegrationList;
}
  
async function _updateBuildPlaneImages(bag){
    util.log("Processing build plane images update");
    var buildPlaneImagesFile = `${bag.installerBin}/buildplaneImages.json`;
    if (! fs.existsSync(buildPlaneImagesFile)){
      util.log(`Build plane images file (${buildPlaneImagesFile}) does not exist, skipping update`);
      return;
    }
    
    var buildPlaneImagesJson = JSON.parse(fs.readFileSync(buildPlaneImagesFile, 'utf8'));
    if (! buildPlaneImagesJson) {
      util.log(`Build plane images content is empty, skipping update`);
      return;
    }
  
    var masterIntegrationList = await _createMasterIntegrationList(bag);
    var keys = Object.keys( buildPlaneImagesJson );
    for( var i = 0,length = keys.length; i < length; i++ ) {
        var buildPlaneImage     = buildPlaneImagesJson[keys[i]];
        var name                = buildPlaneImage.name;
        var imageId             = buildPlaneImage.imageId;
        var region              = buildPlaneImage.region;
        var architecture        = buildPlaneImage.architecture;
        var operatingSystem     = buildPlaneImage.os;
        var createdAt           = buildPlaneImage.createdAt;
        var provider            = buildPlaneImage.provider;
        var metadataPropertyBag = JSON.stringify(buildPlaneImage.metadataPropertyBag);

        if (!metadataPropertyBag)
          metadataPropertyBag = "{}";

        var masterIntegrationId = _getMasterIntegrationId(provider, masterIntegrationList);
        if (! masterIntegrationId) {
          util.log(`No masterIntegration found for provider name: ${provider}`);
          continue;
        }

        var values          = `'${name}', ${masterIntegrationId}, '${imageId}', true, `
                              +`'${architecture}', '${operatingSystem}', '${region}', '${metadataPropertyBag}',  `
                              +`true, '${createdAt}', '${createdAt}'`;

        var whereCondition  = `name = '${name}' `
                              +`and region = '${region}' `
                              +`and "operatingSystem" = '${operatingSystem}' `
                              +`and architecture = '${architecture}' `
                              +`and "masterIntegrationId" = ${masterIntegrationId}`;

        var updateCondition = `update "buildPlaneImages" set "imageId"                 = '${imageId}'`
                                                         +`, "metadataPropertyBag"     = '${metadataPropertyBag}'`
                                                         +`, "isInternal"              = true `
                                                         +`where name                  = '${name}'            and `
                                                         +`      region                = '${region}'          and `
                                                         +`     "operatingSystem"      = '${operatingSystem}' and `
                                                         +`      architecture          = '${architecture}'    and `
                                                         +`      "masterIntegrationId" = ${masterIntegrationId}`;

        var imageExists     = `select 1 from "buildPlaneImages" where ${whereCondition}`;
        var insertCondition = `INSERT into "buildPlaneImages" `
                                     +`(name, "masterIntegrationId", "imageId", `
                                     +`"isAvailable", architecture, "operatingSystem", `
                                     +`region, "metadataPropertyBag", "isInternal", "createdAt", "updatedAt")`
                                     +`VALUES (${values});`

        var result = await bag.client.query(imageExists);
        var rowsExist = result && result.rows;
        if (rowsExist && result.rows.length > 0){
            await bag.client.query(updateCondition);
        } else if(rowsExist && result.rows.length == 0) {
            await bag.client.query(insertCondition);
        }   
    }
}
