'use strict';

module.exports = executeNatMigration;

var _ = require('underscore');
var util = require('util');
var async = require('async');

function executeNatMigration(client, callback) {
  var fileName = process.argv[1];

  var bag = {
    who: util.format('installer.migration|%s', fileName),
    client: client,
    skipNatMigration: true
  };

  async.series([
    _getNatEnabledNodePools.bind(null, bag),
    _updateSubnetIdForNodePools.bind(null, bag),
  ],
    function (err) {
      if (err) {
        return  callback(err);
      } else {
        util.log(bag.who, 'Completed');
        return callback();
      }
    }
  );
}

function _getNatEnabledNodePools(bag, next) {
  var who = bag.who + '|' + _getNatEnabledNodePools.name;
  util.log(who, 'Inside');

  var query = 'SELECT * FROM "nodePools" WHERE ' +
    '"isNatEnabled"=true AND "isOnDemand"=true;';

  bag.client.query(query,
    function (err, nodePools) {
      if (err)
        return next(
          new ActErr(who, ActErr.DBOperationFailed,
            'Failed to find NAT enabled nodePools with error: ' +
              util.inspect(err))
        );
      if (nodePools.rowCount > 0)
        bag.skipNatMigration = false;
      bag.dynamicNodePools = nodePools.rows;

      return next();
    }
  );
}

function _updateSubnetIdForNodePools(bag, next) {
  if (bag.skipNatMigration) return next();
  var who = bag.who + '|' + _updateSubnetIdForNodePools.name;
  util.log(who, 'Inside');

  async.eachLimit(bag.dynamicNodePools, 10,
    function (np, done) {
      if (np.providerMetadataPropertyBag &&
        _.isString(np.providerMetadataPropertyBag)) {
        try {
          np.providerMetadataPropertyBag = JSON.parse(
            np.providerMetadataPropertyBag);
        } catch (error) {
          util.log(who, 'Failed to parse providerMetadataPropertyBag for ' +
            'nodePool id: ', np.id);
          return done();
        }
      } else {
        return done();
      }
      if (!_.has(np.providerMetadataPropertyBag, 'privateSubnetId'))
        return done();
      np.providerMetadataPropertyBag.subnetId =
        np.providerMetadataPropertyBag.privateSubnetId;
      delete np.providerMetadataPropertyBag.privateSubnetId;

      var updatedProviderMetaDataPropertyBag = JSON.stringify(
        np.providerMetadataPropertyBag);

      var updatedQuery = util.format('UPDATE "nodePools" SET ' +
        '"providerMetadataPropertyBag"=\'%s\',"isNatEnabled"=false ' +
        'WHERE id = \'%s\';', updatedProviderMetaDataPropertyBag, np.id);

      bag.client.query(updatedQuery,
        function (err) {
          if (err)
            return done(
              new ActErr(who, ActErr.DBOperationFailed,
                'Failed to update node pool with error: ' +
                util.inspect(err))
            );
          return done();
        }
      );
    },
    function (err) {
      return next(err);
    }
  );
}
