do $$
  begin

    -- set syntaxVersion to v1.0 in pipelines if its null
    UPDATE public.pipelines SET "syntaxVersion" = 'v1.0' where "syntaxVersion" is null;

    -- set syntaxVersion to v1.0 in resources if its null
    UPDATE public.resources SET "syntaxVersion" = 'v1.0' where "syntaxVersion" is null;

    -- set pipelineSourceId of the steplets from its parent step where it is null
    if exists (select 1 from "steplets" where "pipelineSourceId" IS NULL) then
      UPDATE steplets SET "pipelineSourceId" = (SELECT steps."pipelineSourceId" FROM steps WHERE steps."id" = steplets."stepId") WHERE "pipelineSourceId" IS NULL;
    end if;

    -- set pipelineSourceId to not allow null in steplets table
    if exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'pipelineSourceId' and is_nullable = 'YES') then
      ALTER TABLE "steplets" ALTER COLUMN "pipelineSourceId" SET NOT NULL;
    end if;

    -- delete email masterIntegrationField from the docker registry integration
    if exists (select 1 from "masterIntegrationFields" where "id" = 244) then
      DELETE FROM "masterIntegrationFields" WHERE id=244;
    end if;

    -- update isSecure for jsonKey from the Google cloud integration type
    if exists (select 1 from "masterIntegrationFields" where "id" = 240 AND "isSecure" = false) then
      UPDATE "masterIntegrationFields" SET "isSecure" = true WHERE "id" = 240;
    end if;

    -- change the case of powershell step type
    if exists (select 1 from "systemCodes" where "code" = 2017 AND "name" = 'powershell') then
      UPDATE "systemCodes" SET "name" = 'PowerShell' where "code" = 2017;
    end if;

    -- change the FanIn step to PostMatrix
    if exists (select 1 from "systemCodes" where "code" = 2039 AND "name" = 'FanIn') then
      UPDATE "systemCodes" SET "name" = 'PostMatrix' where "code" = 2039;
    end if;

    -- change the FanOut step to PreMatrix
    if exists (select 1 from "systemCodes" where "code" = 2040 AND "name" = 'FanOut') then
      UPDATE "systemCodes" SET "name" = 'PreMatrix' where "code" = 2040;
    end if;

    -- disable old jenkins integration
    if exists (select 1 from "masterIntegrations" where "name" = 'jenkins' AND "typeCode" = 5012 AND "isEnabled" = 't') then
      UPDATE "masterIntegrations" SET "isEnabled" = 'f' where "name" = 'jenkins' AND "typeCode" = 5012;
    end if;

    -- rename project name to global
    if not exists (select 1 from "projects" where "name" = 'default') then
      if exists (select 1 from "projects" where "name" = 'global') then
        UPDATE "projects" SET "name" = 'default' where "name" = 'global';
      else
        if exists (select 1 from "projects" where "name" =  'default_project') then
          UPDATE "projects" SET "name" = 'default' where "name" = 'default_project';
        end if;
      end if;
    end if;

    -- update os field for master resource
    if exists (select 1 from "masterResources" where "platformsPropertyBag" IS NULL) then
      UPDATE "masterResources" SET "platformsPropertyBag" = '[{"os": "Linux"}]' where "platformsPropertyBag" IS NULL;
    end if;

    if exists (select 1 from "masterIntegrationFields" where id = 354 and "name" = 'url' and "masterIntegrationId" = 103) then
    -- we need to delete this entry with id 354 if it exists, this was the 'url' field
      DELETE from "masterIntegrationFields" where id = 354 and "name" = 'url' and "masterIntegrationId" = 103;
    end if;

    -- set accessResourceNamePrefix for projectIntegrations not in default project
    UPDATE "projectIntegrations"
      SET "accessResourceNamePrefix" =
        (SELECT projects."sourceId" || '/' FROM projects WHERE projects.id = "projectIntegrations"."projectId")
      WHERE "accessResourceNamePrefix" IS NULL AND "projectId" != (select id from projects where name = 'default');

    -- set accessResourceNamePrefix for projectIntegrations in default project
    UPDATE "projectIntegrations"
      SET "accessResourceNamePrefix" = ''
      WHERE "accessResourceNamePrefix" IS NULL AND "projectId" = (select id from projects where name = 'default');

    -- set accessResourceNamePrefix for nodePools not in default project
    UPDATE "nodePools"
      SET "accessResourceNamePrefix" =
        (SELECT projects."sourceId" || '/' FROM projects WHERE projects.id = "nodePools"."projectId")
      WHERE "accessResourceNamePrefix" IS NULL AND "projectId" != (select id from projects where name = 'default');

    -- set accessResourceNamePrefix for nodePools not in default project
    UPDATE "nodePools"
      SET "accessResourceNamePrefix" = ''
      WHERE "accessResourceNamePrefix" IS NULL AND "projectId" = (select id from projects where name = 'default');

    -- populate values for runs column 'durationSeconds'
    if exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'durationSeconds') then
      UPDATE "runs" set "durationSeconds" = ROUND(EXTRACT (EPOCH FROM ("endedAt" - "startedAt"))) where "startedAt" IS NOT NULL and "endedAt" IS NOT NULL and "durationSeconds" IS NULL;
    end if;

    -- deprecate u16 buildplane images
    if exists (SELECT 1 FROM information_schema.tables WHERE table_schema = current_schema() AND table_name = 'buildPlaneImages') then
      UPDATE "buildPlaneImages" set "isAvailable" = false where "operatingSystem" = 'Ubuntu_16.04' AND "isAvailable" = true;
    end if;

   -- upgrade buildplaneImage based dynamic u16 NodePools to u18 nodepools
    UPDATE 
      "nodePools" n
    SET 
      "buildPlaneImageId" = (
        SELECT id FROM "buildPlaneImages" 
        WHERE
          region = bpi.region
          AND "isInternal"= true
          AND "operatingSystem" = 'Ubuntu_18.04'
          AND "architecture" = 'x86_64'
          AND "isAvailable" = true
      ),
      "operatingSystem" = 'Ubuntu_18.04'
    FROM 
      "buildPlaneImages" bpi
    WHERE n."buildPlaneImageId" = bpi.id
      AND n."isOnDemand"= true
      AND bpi."isInternal"= true
      AND n."operatingSystem"= 'Ubuntu_16.04'
      AND n."architecture"= 'x86_64';
    
   -- upgrade k8 u16 nodepools to u18 nodepools
    UPDATE 
      "nodePools" n
    SET 
      "operatingSystem" ='Ubuntu_18.04'
    FROM 
      "projectIntegrations" pInt
    WHERE 
      pInt.id = n."projectIntegrationId"
      AND n."isOnDemand" = true
      AND pInt."masterIntegrationName" = 'kubernetesConfig'
      AND pInt."isInternal"=true
      AND n."operatingSystem"= 'Ubuntu_16.04'
      AND n."architecture"= 'x86_64';

-- deprecate CentOS_8 buildplane images
    if exists (SELECT 1 FROM information_schema.tables WHERE table_schema = current_schema() AND table_name = 'buildPlaneImages') then
      UPDATE "buildPlaneImages" set "isAvailable" = false where "operatingSystem" = 'CentOS_8' AND "isAvailable" = true;
    end if;

   -- downgrade buildplaneImage based dynamic CentOS_8 NodePools to CentOS 7 nodepools
    UPDATE
      "nodePools" n
    SET
      "buildPlaneImageId" = (
        SELECT id FROM "buildPlaneImages"
        WHERE
          region = bpi.region
          AND "isInternal"= true
          AND "operatingSystem" = 'CentOS_7'
          AND "architecture" = 'x86_64'
          AND "isAvailable" = true
      ),
      "operatingSystem" = 'CentOS_7'
    FROM
      "buildPlaneImages" bpi
    WHERE n."buildPlaneImageId" = bpi.id
      AND n."isOnDemand"= true
      AND bpi."isInternal"= true
      AND n."operatingSystem"= 'CentOS_8'
      AND n."architecture"= 'x86_64';

   -- Downgrade k8 CentOS 8 nodepools to CentOS 7 nodepools
    UPDATE
      "nodePools" n
    SET
      "operatingSystem" ='CentOS_7'
    FROM
      "projectIntegrations" pInt
    WHERE
      pInt.id = n."projectIntegrationId"
      AND n."isOnDemand" = true
      AND pInt."masterIntegrationName" = 'kubernetesConfig'
      AND pInt."isInternal"=true
      AND n."operatingSystem"= 'CentOS_8'
      AND n."architecture"= 'x86_64';

    -- populate ready statusCode for buildPlaneMessages where statusCode is null
    if exists (select 1 from information_schema.columns where table_name = 'buildPlaneMessages' and column_name = 'statusCode') then
      UPDATE "buildPlaneMessages" set "statusCode" = 4016 where "statusCode" IS NULL;
    end if;

  end
$$
