do $$
  begin
    -- Delete any buildPlaneImages that would be duplicates with the new index or are not referenced by a node pool
    if exists (select 1 from information_schema.tables where table_name = 'buildPlaneImages') then
      if not exists (select 1 from pg_indexes where tablename = 'buildPlaneImages' and indexname = 'buildPlaneImageNameRegionOsArchMstIntIdU') then
        delete from "buildPlaneImages" where not exists (select 1 from "nodePools" where "nodePools"."buildPlaneImageId" = "buildPlaneImages"."id");

        if exists (select name,region,"operatingSystem","architecture","masterIntegrationId" from "buildPlaneImages" group by name,region,"operatingSystem","architecture","masterIntegrationId" having COUNT(1) > 1) then
          update "nodePools" set "buildPlaneImageId"=(select a.id from "buildPlaneImages" as b
            inner join (select * from "buildPlaneImages") as a on
              (b.name, b.region, b."operatingSystem", b.architecture, b."masterIntegrationId")
                = (a.name, a.region, a."operatingSystem", a.architecture, a."masterIntegrationId")
              where b.id = "nodePools"."buildPlaneImageId" and not exists
                ( select id
                  from "buildPlaneImages" as c
                  where c."createdAt" > a."createdAt" and
                    (c.name, c.region, c."operatingSystem", c.architecture, c."masterIntegrationId")
                      = (a.name, a.region, a."operatingSystem", a.architecture, a."masterIntegrationId")
              )
          ) where "buildPlaneImageId" is not null;
        end if;

        delete from "buildPlaneImages" where not exists (select 1 from "nodePools" where "nodePools"."buildPlaneImageId" = "buildPlaneImages"."id");
      end if;
    end if;

    -- Delete any pipelineSourceObjectPermissions that would be duplicates
    -- with the same combination of pipelineSourceId, objectType and objectId.
    -- The oldest entries for the combination would be deleted here.

    if exists (select 1 from information_schema.columns where table_name = 'pipelineSourceObjectPermissions') then
      if exists (select 1 from pg_indexes where tablename = 'pipelineSourceObjectPermissions' and indexname = 'pipelineSourceObjectPermissionsObjectTypeObjectIdI') then
        DELETE  FROM
            "pipelineSourceObjectPermissions" a
                USING "pipelineSourceObjectPermissions" b
        WHERE
            a."id" < b."id" AND
            a."pipelineSourceId" = b."pipelineSourceId" AND
            a."objectType" = b."objectType" AND
            a."objectId" = b."objectId";
      end if;
    end if;

    -- Delete `pipelinesPipelineSourceBranchI` and `pipelinesLatestRunIdI` indexes from the pipelines table
    -- in order to later recreate them during the upgrade process with `DESC NULLS LAST`
    -- to optimize queries that are using sorting by `pipelineSourceBranch` or `latestRunId`

    if exists (select 1 from pg_indexes where indexname = 'pipelinesPipelineSourceBranchI' AND indexdef NOT ILIKE '%DESC NULLS LAST%') then
      DROP INDEX "pipelinesPipelineSourceBranchI";
    end if;

    if exists (select 1 from pg_indexes where indexname = 'pipelinesLatestRunIdI' AND indexdef NOT ILIKE '%DESC NULLS LAST%') then
      DROP INDEX "pipelinesLatestRunIdI";
    end if;
  end
$$
