do $$
  begin

    --
    -- Name: artifactResourceIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourceIdU') then
      CREATE UNIQUE INDEX "artifactResourceIdU" ON public."artifactResources" USING btree (id);
    end if;

    --
    -- Name: artifactResourcePipelineSourceIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourcePipelineSourceIdI') then
      CREATE INDEX "artifactResourcePipelineSourceIdI" ON public."artifactResources" USING btree ("pipelineSourceId");
    end if;

    --
    -- Name: artifactResourceProjectIdNameBranchNotNullU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourceProjectIdNameBranchNotNullU') then
      CREATE UNIQUE INDEX "artifactResourceProjectIdNameBranchNotNullU" ON public."artifactResources" USING btree ("projectId", "name", "pipelineSourceBranch") WHERE "pipelineSourceBranch" IS NOT NULL;
    end if;

    --
    -- Name: artifactResourceProjectIdNameBranchU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourceProjectIdNameBranchU') then
      CREATE UNIQUE INDEX "artifactResourceProjectIdNameBranchU" ON public."artifactResources" USING btree ("projectId", "name") WHERE "pipelineSourceBranch" IS NULL;
    end if;

    --
    -- Name: artifactResources_resourceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'artifactResources_resourceId_fkey') then
      ALTER TABLE ONLY public."artifactResources"
          ADD CONSTRAINT "artifactResources_resourceId_fkey" FOREIGN KEY ("resourceId") REFERENCES public."resources"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: artifactResources_projectIntegrationId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'artifactResources_projectIntegrationId_fkey') then
      ALTER TABLE ONLY public."artifactResources"
          ADD CONSTRAINT "artifactResources_projectIntegrationId_fkey" FOREIGN KEY ("projectIntegrationId") REFERENCES public."projectIntegrations"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: artifactResources_pipelineSourceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'artifactResources_pipelineSourceId_fkey') then
      ALTER TABLE ONLY public."artifactResources"
          ADD CONSTRAINT "artifactResources_pipelineSourceId_fkey" FOREIGN KEY ("pipelineSourceId") REFERENCES public."pipelineSources"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: artifactResources_projectId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'artifactResources_projectId_fkey') then
      ALTER TABLE ONLY public."artifactResources"
          ADD CONSTRAINT "artifactResources_projectId_fkey" FOREIGN KEY ("projectId") REFERENCES public.projects(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: artifactResources_typeCode_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'artifactResources_typeCode_fkey') then
      ALTER TABLE ONLY public."artifactResources"
          ADD CONSTRAINT "artifactResources_typeCode_fkey" FOREIGN KEY ("typeCode") REFERENCES public."systemCodes"(code) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: artifactResourcesProjectIntegrationIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourcesProjectIntegrationIdI') then
      CREATE INDEX "artifactResourcesProjectIntegrationIdI" ON public."artifactResources" USING btree ("projectIntegrationId");
    end if;

    --
    -- Name: artifactResourcesResourceIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourcesResourceIdI') then
      CREATE INDEX "artifactResourcesResourceIdI" ON public."artifactResources" USING btree ("resourceId");
    end if;

    --
    -- Name: artifactResourcesHookIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourcesHookIdI') then
      CREATE INDEX "artifactResourcesHookIdI" ON public."artifactResources" USING btree ("hookId");
    end if;

    --
    -- Name: artifactResourcesRepositoriesI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourcesRepositoriesI') then
      CREATE INDEX "artifactResourcesRepositoriesI" ON public."artifactResources" USING btree ("repositories");
    end if;

    --
    -- Name: artifactResourcesPathIncludePatternI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourcesPathIncludePatternI') then
      CREATE INDEX "artifactResourcesPathIncludePatternI" ON public."artifactResources" USING btree ("pathIncludePattern");
    end if;

    --
    -- Name: artifactResourcesPathExcludePatternI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'artifactResources' and indexname = 'artifactResourcesPathExcludePatternI') then
      CREATE INDEX "artifactResourcesPathExcludePatternI" ON public."artifactResources" USING btree ("pathExcludePattern");
    end if;
  end
$$
