do $$
  begin

    --
    -- Name: pipelineSourcesIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSources' and indexname = 'pipelineSourcesIdU') then
      CREATE UNIQUE INDEX "pipelineSourcesIdU" ON public."pipelineSources" USING btree (id);
    end if;

    --
    -- Name: pipelineSourcesRepoNameBranchU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSources' and indexname = 'pipelineSourcesRepoNameConfigFolderBranchU') then
      CREATE UNIQUE INDEX "pipelineSourcesRepoNameConfigFolderBranchU" ON public."pipelineSources" USING btree ("projectId", "repositoryFullName", "configFolder", branch);
    end if;

    --
    -- Name: pipelineSources_projectIntegrationId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSources_projectIntegrationId_fkey') then
      ALTER TABLE ONLY public."pipelineSources"
          ADD CONSTRAINT "pipelineSources_projectIntegrationId_fkey" FOREIGN KEY ("projectIntegrationId") REFERENCES public."projectIntegrations"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSources_lastSyncStatusCode_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSources_lastSyncStatusCode_fkey') then
      ALTER TABLE ONLY public."pipelineSources"
          ADD CONSTRAINT "pipelineSources_lastSyncStatusCode_fkey" FOREIGN KEY ("lastSyncStatusCode") REFERENCES public."systemCodes"(code) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSources_projectId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSources_projectId_fkey') then
      ALTER TABLE ONLY public."pipelineSources"
          ADD CONSTRAINT "pipelineSources_projectId_fkey" FOREIGN KEY ("projectId") REFERENCES public.projects(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSources_createdBy_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSources_createdBy_fkey') then
      ALTER TABLE ONLY public."pipelineSources"
          ADD CONSTRAINT "pipelineSources_createdBy_fkey" FOREIGN KEY ("createdBy") REFERENCES public.identities(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSources_updatedBy_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSources_updatedBy_fkey') then
      ALTER TABLE ONLY public."pipelineSources"
          ADD CONSTRAINT "pipelineSources_updatedBy_fkey" FOREIGN KEY ("updatedBy") REFERENCES public.identities(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSourcesNameU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSources' and indexname = 'pipelineSourcesNameU') then
      CREATE UNIQUE INDEX "pipelineSourcesNameU" ON public."pipelineSources" USING btree ("name");
    end if;

    --
    -- Name: pipelineSourcesTemplateIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSources' and indexname = 'pipelineSourcesTemplateIdI') then
      CREATE INDEX "pipelineSourcesTemplateIdI" ON public."pipelineSources" USING btree ("templateId");
    end if;

    --
    -- Name: pipelineSourcesUpdatedAtI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSources' and indexname = 'pipelineSourcesUpdatedAtI') then
      CREATE INDEX "pipelineSourcesUpdatedAtI" ON public."pipelineSources" USING btree ("updatedAt" DESC);
    end if;

    --
    -- Drop pipelineSourcesRepoNameBranchU UNIQUE INDEX
    --

    if exists (select 1 from pg_indexes where tablename = 'pipelineSources' and indexname = 'pipelineSourcesRepoNameBranchU') then
      DROP INDEX "pipelineSourcesRepoNameBranchU";
    end if;

    --
    -- Name: pipelineSources_workspaceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSources_workspaceId_fkey') then
        ALTER TABLE ONLY public."pipelineSources"
            ADD CONSTRAINT "pipelineSources_workspaceId_fkey" FOREIGN KEY ("workspaceId") REFERENCES public."workspaces"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;
  end
$$
