do $$
  begin

    --
    -- Name: pipelineSyncStatusesIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSyncStatuses' and indexname = 'pipelineSyncStatusesIdU') then
      CREATE UNIQUE INDEX "pipelineSyncStatusesIdU" ON public."pipelineSyncStatuses" USING btree (id);
    end if;

    --
    -- Name: pipelineSyncStatusesSourceIdBranchU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSyncStatuses' and indexname = 'pipelineSyncStatusesSourceIdBranchU') then
      CREATE UNIQUE INDEX "pipelineSyncStatusesSourceIdBranchU" ON public."pipelineSyncStatuses" USING btree ("pipelineSourceId", "pipelineSourceBranch");
    end if;

    --
    -- Name: pipelineSyncStatusesProjectIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSyncStatuses' and indexname = 'pipelineSyncStatusesProjectIdI') then
      CREATE INDEX "pipelineSyncStatusesProjectIdI" ON public."pipelineSyncStatuses" USING btree ("projectId");
    end if;

    --
    -- Name: pipelineSyncStatusesTriggeredByResourceVersionIdI; Type: BTree INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSyncStatuses' and indexname = 'pipelineSyncStatusesTriggeredByResourceVersionIdI') then
      CREATE INDEX "pipelineSyncStatusesTriggeredByResourceVersionIdI" ON public."pipelineSyncStatuses" USING btree ("triggeredByResourceVersionId" DESC NULLS LAST);
    end if;

    --
    -- Name: pipelineSyncStatusesUpdatedAtI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelineSyncStatuses' and indexname = 'pipelineSyncStatusesUpdatedAtI') then
      CREATE INDEX "pipelineSyncStatusesUpdatedAtI" ON public."pipelineSyncStatuses" USING btree ("updatedAt" DESC);
    end if;

    --
    -- A code block to create Postgres pg_trgm extension and GIN indexes
    --

    declare
      stack_msg text;
      stack_hint text;
    begin

      --
      -- Name: pg_trgm; Type: Extension; Required for using GIN INDEXES
      --

      if not exists (select 1 from pg_extension where extname = 'pg_trgm') then
        CREATE EXTENSION IF NOT EXISTS pg_trgm;
      end if;

      --
      -- Name: pipelineSyncStatusesPipelineSourceBranchGINI; Type: GIN INDEX; Schema: public;
      --

      if not exists (select 1 from pg_indexes where tablename = 'pipelineSyncStatuses' and indexname = 'pipelineSyncStatusesPipelineSourceBranchGINI') then
        CREATE INDEX "pipelineSyncStatusesPipelineSourceBranchGINI" ON public."pipelineSyncStatuses" USING gin ("pipelineSourceBranch" gin_trgm_ops);
      end if;

    exception
      when syntax_error_or_access_rule_violation then
        GET STACKED DIAGNOSTICS stack_msg = MESSAGE_TEXT, stack_hint = PG_EXCEPTION_HINT;
        raise notice E'%\nHINT: %\nPlease check Pipelines user docs on how to install "pg_trgm" extension with a superuser prior to running Pipelines installation for improved search performance.', stack_msg, stack_hint;
      when others then
        GET STACKED DIAGNOSTICS stack_msg = MESSAGE_TEXT, stack_hint = PG_EXCEPTION_HINT;
        raise notice E'%\nHINT: %\nPlease check if postgresql-contrib module is installed. Please check Pipelines user docs on how to install "pg_trgm" extension with a superuser prior to running Pipelines installation for improved search performance.', stack_msg, stack_hint;

    end;

    --
    -- Name: pipelineSyncStatuses_pipelineSourceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSyncStatuses_pipelineSourceId_fkey') then
      ALTER TABLE ONLY public."pipelineSyncStatuses"
          ADD CONSTRAINT "pipelineSyncStatuses_pipelineSourceId_fkey" FOREIGN KEY ("pipelineSourceId") REFERENCES public."pipelineSources"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSyncStatuses_lastSyncStatusCode_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSyncStatuses_lastSyncStatusCode_fkey') then
      ALTER TABLE ONLY public."pipelineSyncStatuses"
          ADD CONSTRAINT "pipelineSyncStatuses_lastSyncStatusCode_fkey" FOREIGN KEY ("lastSyncStatusCode") REFERENCES public."systemCodes"(code) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSyncStatuses_projectId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSyncStatuses_projectId_fkey') then
      ALTER TABLE ONLY public."pipelineSyncStatuses"
          ADD CONSTRAINT "pipelineSyncStatuses_projectId_fkey" FOREIGN KEY ("projectId") REFERENCES public.projects(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelineSyncStatuses_triggeredByResourceVersionId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelineSyncStatuses_triggeredByResourceVersionId_fkey') then
      ALTER TABLE ONLY public."pipelineSyncStatuses"
          ADD CONSTRAINT "pipelineSyncStatuses_triggeredByResourceVersionId_fkey" FOREIGN KEY ("triggeredByResourceVersionId") REFERENCES public."resourceVersions"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

  end
$$
