do $$
  begin

    --
    -- Name: pipelinesIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesIdU') then
      CREATE UNIQUE INDEX "pipelinesIdU" ON public.pipelines USING btree (id);
    end if;

    --
    -- Name: pipelinesProjectIdNameBranchNotNullU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesProjectIdNameBranchNotNullU') then
      CREATE UNIQUE INDEX "pipelinesProjectIdNameBranchNotNullU" ON public.pipelines USING btree ("projectId", "name", "pipelineSourceBranch") WHERE "pipelineSourceBranch" IS NOT NULL;
    end if;

    --
    -- Name: pipelinesProjectIdNameBranchU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesProjectIdNameBranchU') then
      CREATE UNIQUE INDEX "pipelinesProjectIdNameBranchU" ON public.pipelines USING btree ("projectId", "name") WHERE "pipelineSourceBranch" IS NULL;
    end if;

    --
    -- Name: pipelinesProjectIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesProjectIdI') then
      CREATE INDEX "pipelinesProjectIdI" ON public."pipelines" USING btree ("projectId");
    end if;

    --
    -- Name: pipelinesPipelineSourceIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesPipelineSourceIdI') then
      CREATE INDEX "pipelinesPipelineSourceIdI" ON public.pipelines USING btree ("pipelineSourceId");
    end if;

    --
    -- Name: pipelinesCreatedAtI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesCreatedAtI') then
      CREATE INDEX "pipelinesCreatedAtI" ON public.pipelines USING btree ("createdAt");
    end if;

    --
    -- Name: pipelinesNameI; Type: BTree INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesNameI') then
      CREATE INDEX "pipelinesNameI" ON public.pipelines USING btree ("name");
    end if;

    --
    -- Name: pipelinesPipelineSourceBranchI; Type: BTree INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesPipelineSourceBranchI') then
      CREATE INDEX "pipelinesPipelineSourceBranchI" ON public.pipelines USING btree ("pipelineSourceBranch" DESC NULLS LAST);
    end if;

    --
    -- Name: pipelinesLatestRunIdI; Type: BTree INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesLatestRunIdI') then
      CREATE INDEX "pipelinesLatestRunIdI" ON public.pipelines USING btree ("latestRunId" DESC NULLS LAST);
    end if;

    --
    -- Name: pipelinesRetentionMaxAgeDaysI; Type: BTree INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesRetentionMaxAgeDaysI') then
      CREATE INDEX "pipelinesRetentionMaxAgeDaysI" ON public.pipelines USING btree ("retentionMaxAgeDays" DESC NULLS LAST);
    end if;

    --
    -- Name: pipelinesRetentionMinRunsI; Type: BTree INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesRetentionMinRunsI') then
      CREATE INDEX "pipelinesRetentionMinRunsI" ON public.pipelines USING btree ("retentionMinRuns" DESC NULLS LAST);
    end if;

    --
    -- A code block to create Postgres pg_trgm extension and GIN indexes
    --

    declare
      stack_msg text;
      stack_hint text;
    begin

      --
      -- Name: pg_trgm; Type: Extension; Required for using GIN INDEXES
      --

      if not exists (select 1 from pg_extension where extname = 'pg_trgm') then
        CREATE EXTENSION IF NOT EXISTS pg_trgm;
      end if;

      --
      -- Name: pipelinesNameGINI; Type: GIN INDEX; Schema: public;
      --

      if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesNameGINI') then
        CREATE INDEX "pipelinesNameGINI" ON public.pipelines USING gin ("name" gin_trgm_ops);
      end if;

      --
      -- Name: pipelinesPipelineSourceBranchGINI; Type: GIN INDEX; Schema: public;
      --

      if not exists (select 1 from pg_indexes where tablename = 'pipelines' and indexname = 'pipelinesPipelineSourceBranchGINI') then
        CREATE INDEX "pipelinesPipelineSourceBranchGINI" ON public.pipelines USING gin ("pipelineSourceBranch" gin_trgm_ops);
      end if;

    exception
      when syntax_error_or_access_rule_violation then
        GET STACKED DIAGNOSTICS stack_msg = MESSAGE_TEXT, stack_hint = PG_EXCEPTION_HINT;
        raise notice E'%\nHINT: %\nPlease check Pipelines user docs on how to install "pg_trgm" extension with a superuser prior to running Pipelines installation for improved search performance.', stack_msg, stack_hint;
      when others then
        GET STACKED DIAGNOSTICS stack_msg = MESSAGE_TEXT, stack_hint = PG_EXCEPTION_HINT;
        raise notice E'%\nHINT: %\nPlease check if postgresql-contrib module is installed. Please check Pipelines user docs on how to install "pg_trgm" extension with a superuser prior to running Pipelines installation for improved search performance.', stack_msg, stack_hint;

    end;

    --
    -- Name: pipelines_pipelineSourceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelines_pipelineSourceId_fkey') then
      ALTER TABLE ONLY public.pipelines
          ADD CONSTRAINT "pipelines_pipelineSourceId_fkey" FOREIGN KEY ("pipelineSourceId") REFERENCES public."pipelineSources"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: pipelines_projectId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'pipelines_projectId_fkey') then
      ALTER TABLE ONLY public.pipelines
          ADD CONSTRAINT "pipelines_projectId_fkey" FOREIGN KEY ("projectId") REFERENCES public.projects(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

  end
$$
