do $$
  begin

    --
    -- Name: resourceIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourceIdU') then
      CREATE UNIQUE INDEX "resourceIdU" ON public.resources USING btree (id);
    end if;

    --
    -- Name: resourcePipelineSourceIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcePipelineSourceIdI') then
      CREATE INDEX "resourcePipelineSourceIdI" ON public.resources USING btree ("pipelineSourceId");
    end if;

    --
    -- Name: resourceProjectIdNameBranchNotNullU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourceProjectIdNameBranchNotNullU') then
      CREATE UNIQUE INDEX "resourceProjectIdNameBranchNotNullU" ON public.resources USING btree ("projectId", "name", "pipelineSourceBranch") WHERE "pipelineSourceBranch" IS NOT NULL;
    end if;

    --
    -- Name: resourceProjectIdNameBranchU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourceProjectIdNameBranchU') then
      CREATE UNIQUE INDEX "resourceProjectIdNameBranchU" ON public.resources USING btree ("projectId", "name") WHERE "pipelineSourceBranch" IS NULL;
    end if;

    --
    -- Name: resources_projectIntegrationId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'resources_projectIntegrationId_fkey') then
      ALTER TABLE ONLY public.resources
          ADD CONSTRAINT "resources_projectIntegrationId_fkey" FOREIGN KEY ("projectIntegrationId") REFERENCES public."projectIntegrations"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: resources_pipelineSourceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'resources_pipelineSourceId_fkey') then
      ALTER TABLE ONLY public.resources
          ADD CONSTRAINT "resources_pipelineSourceId_fkey" FOREIGN KEY ("pipelineSourceId") REFERENCES public."pipelineSources"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: resources_projectId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'resources_projectId_fkey') then
      ALTER TABLE ONLY public.resources
          ADD CONSTRAINT "resources_projectId_fkey" FOREIGN KEY ("projectId") REFERENCES public.projects(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: resources_typeCode_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'resources_typeCode_fkey') then
      ALTER TABLE ONLY public.resources
          ADD CONSTRAINT "resources_typeCode_fkey" FOREIGN KEY ("typeCode") REFERENCES public."systemCodes"(code) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: resourcesProjectIntegrationIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesProjectIntegrationIdI') then
      CREATE INDEX "resourcesProjectIntegrationIdI" ON public.resources USING btree ("projectIntegrationId");
    end if;

    --
    -- Name: resourcesGitRepoFullNameI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitRepoFullNameI') then
      CREATE INDEX "resourcesGitRepoFullNameI" ON public.resources USING btree ("gitRepoFullName");
    end if;

    --
    -- Name: resourcesGitIncludeBranchPatternI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitIncludeBranchPatternI') then
      CREATE INDEX "resourcesGitIncludeBranchPatternI" ON public.resources USING btree ("gitIncludeBranchPattern");
    end if;

    --
    -- Name: resourcesGitExcludeBranchPatternI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitExcludeBranchPatternI') then
      CREATE INDEX "resourcesGitExcludeBranchPatternI" ON public.resources USING btree ("gitExcludeBranchPattern");
    end if;

    --
    -- Name: resourcesGitBuildOnCommitI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitBuildOnCommitI') then
      CREATE INDEX "resourcesGitBuildOnCommitI" ON public.resources USING btree ("gitBuildOnCommit");
    end if;

    --
    -- Name: resourcesGitBuildOnPullRequestCreateI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitBuildOnPullRequestCreateI') then
      CREATE INDEX "resourcesGitBuildOnPullRequestCreateI" ON public.resources USING btree ("gitBuildOnPullRequestCreate");
    end if;

    --
    -- Name: resourcesGitBuildOnPullRequestCloseI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitBuildOnPullRequestCloseI') then
      CREATE INDEX "resourcesGitBuildOnPullRequestCloseI" ON public.resources USING btree ("gitBuildOnPullRequestClose");
    end if;

    --
    -- Name: resourcesGitBuildOnReleaseCreateI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitBuildOnReleaseCreateI') then
      CREATE INDEX "resourcesGitBuildOnReleaseCreateI" ON public.resources USING btree ("gitBuildOnReleaseCreate");
    end if;

    --
    -- Name: resourcesGitBuildOnTagCreateI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitBuildOnTagCreateI') then
      CREATE INDEX "resourcesGitBuildOnTagCreateI" ON public.resources USING btree ("gitBuildOnTagCreate");
    end if;

    --
    -- Name: resourcesGitBuildOnBranchDelete; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitBuildOnBranchDeleteI') then
      CREATE INDEX "resourcesGitBuildOnBranchDeleteI" ON public.resources USING btree ("gitBuildOnBranchDelete");
    end if;

    --
    -- Name: resourcesGitBuildOnBranchCreateI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'resources' and indexname = 'resourcesGitBuildOnBranchCreateI') then
      CREATE INDEX "resourcesGitBuildOnBranchCreateI" ON public.resources USING btree ("gitBuildOnBranchCreate");
    end if;
  end
$$
