do $$
  begin

    --
    -- Name: runsIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsIdU') then
      CREATE UNIQUE INDEX "runsIdU" ON public.runs USING btree (id);
    end if;

    --
    -- Name: runsRunNumberPipelineIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsRunNumberPipelineIdU') then
      CREATE UNIQUE INDEX "runsRunNumberPipelineIdU" ON public.runs USING btree ("runNumber", "pipelineId");
    end if;

    --
    -- Name: runsPipelineIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsPipelineIdI') then
      CREATE INDEX "runsPipelineIdI" ON public.runs USING btree ("pipelineId");
    end if;

    --
    -- Name: runsProjectIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsProjectIdI') then
      CREATE INDEX "runsProjectIdI" ON public.runs USING btree ("projectId");
    end if;

    --
    -- Name: runsParentRunIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsParentRunIdI') then
      CREATE INDEX "runsParentRunIdI" ON public.runs USING btree ("parentRunId");
    end if;

    --
    -- Name: runsCreatedAtI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsCreatedAtI') then
      CREATE INDEX "runsCreatedAtI" ON public.runs USING btree ("createdAt");
    end if;

    --
    -- Name: runsDurationSecondsI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsDurationSecondsI') then
      CREATE INDEX "runsDurationSecondsI" ON public.runs USING btree ("durationSeconds");
    end if;

    --
    -- Name: runsStatusCodeI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsStatusCodeI') then
      CREATE INDEX "runsStatusCodeI" ON public.runs USING btree ("statusCode");
    end if;

    --
    -- Name: runs_projectId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'runs_projectId_fkey') then
      ALTER TABLE ONLY public.runs
          ADD CONSTRAINT "runs_projectId_fkey" FOREIGN KEY ("projectId") REFERENCES public.projects(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: runs_statusCode_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'runs_statusCode_fkey') then
      ALTER TABLE ONLY public.runs
          ADD CONSTRAINT "runs_statusCode_fkey" FOREIGN KEY ("statusCode") REFERENCES public."systemCodes"(code) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: runs_pipelineId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'runs_pipelineId_fkey') then
      ALTER TABLE ONLY public.runs
          ADD CONSTRAINT "runs_pipelineId_fkey" FOREIGN KEY ("pipelineId") REFERENCES public.pipelines(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: runs_pipelineSourceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'runs_pipelineSourceId_fkey') then
      ALTER TABLE ONLY public.runs
          ADD CONSTRAINT "runs_pipelineSourceId_fkey" FOREIGN KEY ("pipelineSourceId") REFERENCES public."pipelineSources"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: runsPipeInfoCompleteI; Type: INDEX; Schema: public; Remove Index
    --
    DROP INDEX IF EXISTS "runsPipeInfoCompleteI";

    --
    -- Name: runsPipelineSourceIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'runsPipelineSourceIdI') then
      CREATE INDEX "runsPipelineSourceIdI" ON public.runs USING btree ("pipelineSourceId");
    end if;

    --
    -- Name: triggerIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'triggerIdI') then
      CREATE INDEX "triggerIdI" ON public.runs USING btree ("triggerId");
    end if;

    --
    -- Name: nameDescriptionI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'runs' and indexname = 'nameDescriptionI') then
      CREATE INDEX "nameDescriptionI" ON public.runs USING btree ("name", "description");
    end if;

  end
$$
