do $$
  begin

    --
    -- Name: stepIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepIdU') then
      CREATE UNIQUE INDEX "stepIdU" ON public.steps USING btree (id);
    end if;

    --
    -- Name: stepPipelineIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepPipelineIdI') then
      CREATE INDEX "stepPipelineIdI" ON public.steps USING btree ("pipelineId");
    end if;

    --
    -- Name: stepPipelineStepIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepPipelineStepIdI') then
      CREATE INDEX "stepPipelineStepIdI" ON public.steps USING btree ("pipelineStepId");
    end if;

    --
    -- Name: stepProjectIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepProjectIdI') then
      CREATE INDEX "stepProjectIdI" ON public.steps USING btree ("projectId");
    end if;

    --
    -- Name: stepRunIdPipelineStepIdU; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepRunIdPipelineStepIdU') then
      CREATE UNIQUE INDEX "stepRunIdPipelineStepIdU" ON public.steps USING btree ("runId", "pipelineStepId");
    end if;

    --
    -- Name: stepStatusCodeI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepStatusCodeI') then
      CREATE INDEX "stepStatusCodeI" ON public.steps USING btree ("statusCode");
    end if;

    --
    -- Name: steps_pipelineId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'steps_pipelineId_fkey') then
      ALTER TABLE ONLY public.steps
          ADD CONSTRAINT "steps_pipelineId_fkey" FOREIGN KEY ("pipelineId") REFERENCES public.pipelines(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: steps_projectId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'steps_projectId_fkey') then
      ALTER TABLE ONLY public.steps
          ADD CONSTRAINT "steps_projectId_fkey" FOREIGN KEY ("projectId") REFERENCES public.projects(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: steps_runId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'steps_runId_fkey') then
      ALTER TABLE ONLY public.steps
          ADD CONSTRAINT "steps_runId_fkey" FOREIGN KEY ("runId") REFERENCES public.runs(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: steps_statusCode_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'steps_statusCode_fkey') then
      ALTER TABLE ONLY public.steps
          ADD CONSTRAINT "steps_statusCode_fkey" FOREIGN KEY ("statusCode") REFERENCES public."systemCodes"(code) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: steps_typeCode_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'steps_typeCode_fkey') then
      ALTER TABLE ONLY public.steps
          ADD CONSTRAINT "steps_typeCode_fkey" FOREIGN KEY ("typeCode") REFERENCES public."systemCodes"(code) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: steps_pipelineSourceId_fkey; Type: FK CONSTRAINT; Schema: public;
    --

    if not exists (select 1 from pg_constraint where conname = 'steps_pipelineSourceId_fkey') then
      ALTER TABLE ONLY public.steps
          ADD CONSTRAINT "steps_pipelineSourceId_fkey" FOREIGN KEY ("pipelineSourceId") REFERENCES public."pipelineSources"(id) ON UPDATE RESTRICT ON DELETE RESTRICT;
    end if;

    --
    -- Name: stepPipelineSourceIdI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepPipelineSourceIdI') then
      CREATE INDEX "stepPipelineSourceIdI" ON public.steps USING btree ("pipelineSourceId");
    end if;

    --
    -- Name: stepGroupInProgressI; Type: INDEX; Schema: public;
    --

    if not exists (select 1 from pg_indexes where tablename = 'steps' and indexname = 'stepGroupInProgressI') then
      CREATE INDEX "stepGroupInProgressI" ON public.steps USING btree ("groupInProgress");
    end if;

  end
$$
