--
-- Name: buildPlaneImages; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."buildPlaneImages" (
    id integer NOT NULL,
    name character varying(80) NOT NULL,
    "masterIntegrationId" integer NOT NULL,
    "imageId" character varying(255) NOT NULL,
    region character varying(64) NOT NULL,
    "isAvailable" boolean NOT NULL,
    "architecture" character varying(24) NOT NULL,
    "operatingSystem" character varying(24) NOT NULL,
    "isInternal" boolean DEFAULT false,
    "metadataPropertyBag" text,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);

--
-- Name: systemMachineImages_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."buildPlaneImages_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."buildPlaneImages".id;


do $$
  begin

  -- add metadataPropertyBag column to buildPlaneImages table
    if exists (select 1 from information_schema.tables where table_name = 'buildPlaneImages') then
      if not exists (select 1 from information_schema.columns where table_name = 'buildPlaneImages' and column_name = 'metadataPropertyBag') then
        ALTER TABLE "buildPlaneImages" ADD COLUMN "metadataPropertyBag" text;
      end if;
    end if;

    -- increase size of imageId column in buildPlaneImages to 255
    if exists (select 1 from information_schema.columns where table_name = 'buildPlaneImages' and column_name = 'imageId' and character_maximum_length < 255) then
      ALTER TABLE "buildPlaneImages" ALTER COLUMN "imageId" TYPE varchar(255);
    end if;

    -- alter datatype of id column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'buildPlaneImages' and column_name = 'id' and data_type = 'smallint') then
      ALTER TABLE "buildPlaneImages" ALTER COLUMN id TYPE integer;
    end if;

    -- add isInternal column to buildPlaneImages table
    if not exists (select 1 from information_schema.columns where table_name = 'buildPlaneImages' and column_name = 'isInternal') then
      ALTER TABLE "buildPlaneImages" ADD COLUMN "isInternal" boolean DEFAULT false;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'buildPlaneImages' and column_name='id' and column_default='nextval(''"buildPlaneImages_id_seq"''::regclass)'
    ) then
      -- Name: buildPlaneImages_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."buildPlaneImages" ALTER COLUMN id SET DEFAULT nextval('public."buildPlaneImages_id_seq"'::regclass);
    end if;

  end
$$
