--
-- Name: extensionSources; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."extensionSources" (
    id integer NOT NULL,
    "projectIntegrationId" integer NOT NULL,
    "repositoryFullName" character varying(255) NOT NULL,
    "repositoryBranch" character varying(255) NOT NULL,
    "isSyncing" boolean DEFAULT false NOT NULL,
    "latestSha" character varying(255),
    "lastSyncStatusCode" smallint,
    "lastSyncStartedAt" timestamp with time zone,
    "lastSyncEndedAt" timestamp with time zone,
    "lastSyncLogs" text,
    "resourceId" integer,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: extensionSources_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."extensionSources_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."extensionSources".id;


do $$
  begin

    -- add latestSha column to extensionSources table
    if not exists (select 1 from information_schema.columns where table_name = 'extensionSources' and column_name = 'latestSha') then
      ALTER TABLE "extensionSources" ADD COLUMN "latestSha" character varying(255);
    end if;

    -- alter datatype of id column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'extensionSources' and column_name = 'id' and data_type = 'smallint') then
      ALTER TABLE "extensionSources" ALTER COLUMN id TYPE integer;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'extensionSources' and column_name='id' and column_default='nextval(''"extensionSources_id_seq"''::regclass)'
    ) then
      -- Name: extensionSources_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."extensionSources" ALTER COLUMN id SET DEFAULT nextval('public."extensionSources_id_seq"'::regclass);
    end if;

  end
$$
