--
-- Name: hooks; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public.hooks (
    id integer NOT NULL,
    "projectId" integer NOT NULL,
    "projectIntegrationId" integer NOT NULL,
    "identifierName" character varying(255) NOT NULL,
    "identifierValue" character varying(255) NOT NULL,
    "resourceTypeCode" integer NOT NULL,
    "propertyBag" text,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL,
    "createdBy" integer NOT NULL,
    "updatedBy" integer NOT NULL
);


--
-- Name: hooks_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.hooks_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public.hooks.id;


do $$
  begin

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'hooks' and column_name = 'projectId' and data_type = 'smallint') then
    ALTER TABLE "hooks" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'hooks' and column_name='id' and column_default='nextval(''hooks_id_seq''::regclass)'
    ) then
      -- Name: hooks_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public.hooks ALTER COLUMN id SET DEFAULT nextval('public.hooks_id_seq'::regclass);
    end if;

    -- alter datatype of resourceTypeCode column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'hooks' and column_name = 'resourceTypeCode' and data_type = 'smallint') then
        ALTER TABLE "hooks" ALTER COLUMN "resourceTypeCode" TYPE integer;
    end if;

  end
$$
