--
-- Name: masterResources; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."masterResources" (
    id integer NOT NULL,
    "resourceType" character varying(12) NOT NULL,
    name character varying(255) NOT NULL,
    description text,
    "isInternal" boolean NOT NULL,
    "lifecycleStage" character varying(12),
    "syntaxVersion" character varying(10) NOT NULL,
    "extensionSourceId" integer,
    "latestSha" character varying(255),
    "isSyncing" boolean DEFAULT false NOT NULL,
    "platformsPropertyBag" text,
    "lastSyncStatusCode" smallint,
    "lastSyncStartedAt" timestamp with time zone,
    "lastSyncEndedAt" timestamp with time zone,
    "lastSyncLogs" text,
    "namespace" character varying(255),
    "retiredAt" timestamp with time zone,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: masterResources_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."masterResources_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."masterResources".id;

do $$
  begin

    -- add namespace column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'namespace') then
      truncate "masterResources";
      ALTER TABLE "masterResources" ADD COLUMN namespace character varying(255);
    end if;

    -- drop null constraint lifecycleStage column to masterResources table
    if exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'lifecycleStage') then
      ALTER TABLE "masterResources" ALTER COLUMN "lifecycleStage" DROP NOT NULL;
    end if;

    -- add isSyncing column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'isSyncing') then
      ALTER TABLE "masterResources" ADD COLUMN "isSyncing" boolean;
      UPDATE "masterResources" set "isSyncing" = false;
      ALTER TABLE "masterResources" ALTER COLUMN "isSyncing" SET NOT NULL;
    end if;

    -- add latestSha column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'latestSha') then
      ALTER TABLE "masterResources" ADD COLUMN "latestSha" character varying(255);
    end if;

    -- add lastSyncStatusCode column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'lastSyncStatusCode') then
      ALTER TABLE "masterResources" ADD COLUMN "lastSyncStatusCode" smallint;
    end if;

    -- add lastSyncStartedAt column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'lastSyncStartedAt') then
      ALTER TABLE "masterResources" ADD COLUMN "lastSyncStartedAt" timestamp with time zone;
    end if;

    -- add lastSyncEndedAt column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'lastSyncEndedAt') then
      ALTER TABLE "masterResources" ADD COLUMN "lastSyncEndedAt" timestamp with time zone;
    end if;

    -- add lastSyncLogs column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'lastSyncLogs') then
      ALTER TABLE "masterResources" ADD COLUMN "lastSyncLogs" text;
    end if;

    -- alter datatype of id column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'id' and data_type = 'smallint') then
      ALTER TABLE "masterResources" ALTER COLUMN id TYPE integer;
    end if;

    -- alter datatype of extensionSourceId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'extensionSourceId' and data_type = 'smallint') then
      ALTER TABLE "masterResources" ALTER COLUMN "extensionSourceId" TYPE integer;
    end if;

    -- add os column to masterResources table
    if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'platformsPropertyBag') then
      ALTER TABLE "masterResources" ADD COLUMN "platformsPropertyBag" text;
    end if;

    -- add default value as false for isSyncing column
    if exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'isSyncing') then
      if not exists (select 1 from information_schema.columns where table_name = 'masterResources' and column_name = 'isSyncing' and column_default = 'false') then
        ALTER TABLE "masterResources" ALTER COLUMN "isSyncing" SET DEFAULT false;
      end if;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'masterResources' and column_name='id' and column_default='nextval(''"masterResources_id_seq"''::regclass)'
    ) then
      -- Name: masterResources_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."masterResources" ALTER COLUMN id SET DEFAULT nextval('public."masterResources_id_seq"'::regclass);
    end if;

  end
$$
