--
-- Name: "nodePools"; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."nodePools" (
    id integer NOT NULL,
    "projectId" integer NOT NULL,
    "environments" character varying(255)[],
    name character varying(255) NOT NULL,
    "queueName" character varying(255),
    "numberOfNodes" integer DEFAULT 1,
    "isOnDemand" boolean DEFAULT false NOT NULL,
    "buildPlaneImageId" integer,
    "projectIntegrationId" integer,
    architecture varchar(24) NOT NULL,
    "operatingSystem" varchar(24) NOT NULL,
    "maxDiskUsagePercentage" integer,
    "diskSizeinGB" smallint,
    "timeoutMS" integer,
    "isNatEnabled" boolean,
    "isCacheEnabled" boolean,
    "nodeIdleIntervalInMins" integer,
    "accessResourceNamePrefix" character varying(255),
    "providerMetadataPropertyBag" text,
    "cacheSettingsPropertyBag" text,
    "initPropertyBag" text,
    "permissions" text,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);

--
-- Name: "nodePools_id_seq"; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."nodePools_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."nodePools".id;


do $$
  begin

    -- alter datatype of buildPlaneImageId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'buildPlaneImageId' and data_type = 'smallint') then
      ALTER TABLE "nodePools" ALTER COLUMN "buildPlaneImageId" TYPE integer;
    end if;

    -- alter datatype of id column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'id' and data_type = 'smallint') then
      ALTER TABLE "nodePools" ALTER COLUMN id TYPE integer;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "nodePools" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- alter datatype of projectIntegrationId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'projectIntegrationId' and data_type = 'smallint') then
      ALTER TABLE "nodePools" ALTER COLUMN "projectIntegrationId" TYPE integer;
    end if;

    -- add initPropertyBag column to nodePools table
    if not exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'initPropertyBag') then
        ALTER TABLE "nodePools" ADD COLUMN "initPropertyBag" text;
    end if;

    -- add environments column to nodePools table
    if not exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'environments') then
      ALTER TABLE "nodePools" ADD COLUMN "environments" character varying(255)[];
    end if;

    -- add diskSizeinGB column to nodePools table
    if not exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'diskSizeinGB') then
      ALTER TABLE "nodePools" ADD COLUMN "diskSizeinGB" smallint;
    end if;

    -- add accessResourceNamePrefix column to nodePools table
    if not exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'accessResourceNamePrefix') then
      ALTER TABLE "nodePools" ADD COLUMN "accessResourceNamePrefix" character varying(255);
    end if;

    -- add initAsNonRoot column to nodePools table
    if not exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'initAsNonRoot') then
      ALTER TABLE "nodePools" ADD COLUMN "initAsNonRoot" boolean DEFAULT false;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'nodePools' and column_name='id' and column_default='nextval(''"nodePools_id_seq"''::regclass)'
    ) then
      -- Name: nodePools_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."nodePools" ALTER COLUMN id SET DEFAULT nextval('public."nodePools_id_seq"'::regclass);
    end if;

    -- add isBeta column to nodePools table
    if not exists (select 1 from information_schema.columns where table_name = 'nodePools' and column_name = 'isBeta') then
        ALTER TABLE "nodePools" ADD COLUMN "isBeta" boolean DEFAULT false;
    end if;

  end
$$
