--
-- Name: nodeStats; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."nodeStats" (
    id integer NOT NULL,
    "nodeId" integer NOT NULL,
    "reportedAt" timestamp with time zone NOT NULL,
    "diskUsageInPercentage" numeric,
    "memoryUsageInPercentage" numeric,
    "cpuLoadInPercentage" numeric,
    "activeContainersCount" integer,
    "totalContainersCount" integer,
    "imageCount" integer,
    "projectId" integer,
    "createdBy" character varying(24),
    "updatedBy" character varying(24),
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: nodeStats_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."nodeStats_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."nodeStats".id;


do $$
  begin

    -- alter datatype of nodeId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodeStats' and column_name = 'nodeId' and data_type = 'smallint') then
      ALTER TABLE "nodeStats" ALTER COLUMN "nodeId" TYPE integer;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodeStats' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "nodeStats" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'nodeStats' and column_name='id' and column_default='nextval(''"nodeStats_id_seq"''::regclass)'
    ) then
      -- Name: nodeStats_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."nodeStats" ALTER COLUMN "id" SET DEFAULT nextval('public."nodeStats_id_seq"'::regclass);
    end if;

  end
$$
