--
-- Name: nodes; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public.nodes (
    id integer NOT NULL,
    "projectId" integer NOT NULL,
    "statusCode" smallint DEFAULT 0 NOT NULL,
    "friendlyName" character varying(80) NOT NULL,
    "isAutoInitialized" boolean NOT NULL,
    "isDebug" boolean,
    "isSwapEnabled" boolean DEFAULT false NOT NULL,
    "isOnDemand" boolean DEFAULT false NOT NULL,
    "IPAddress" character varying(255),
    "sshPort" integer,
    "sshUser" character varying(255),
    "instanceId" character varying(80),
    "instanceInfo" text,
    "currentBuildPlaneVersion" character varying(30),
    "intendedBuildPlaneVersion" character varying(30),
    "stepId" bigint,
    "statusLastUpdatedAt" timestamp with time zone,
    "lastInitializedAt" timestamp with time zone,
    "provisionedAt" timestamp with time zone,
    "projectIntegrationId" integer,
    "nodePoolId" integer,
    "stopRequested" boolean,
    "providerMetadataPropertyBag" text,
    "systemPropertyBag" text,
    "initPropertyBag" text,
    "createdBy" character varying(24) NOT NULL,
    "updatedBy" character varying(24) NOT NULL,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL,
    "deletedAt" timestamp with time zone NULL
);


--
-- Name: nodes_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.nodes_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public.nodes.id;


do $$
  begin

    -- add deletedAt column to nodes table
    if not exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'deletedAt') then
      ALTER TABLE "nodes" ADD COLUMN "deletedAt" timestamp with time zone NULL;
    end if;

    -- drop maxNodeIdleTimeInHrs column
    if exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'maxNodeIdleTimeInHrs') then
      ALTER TABLE ONLY public.nodes DROP COLUMN "maxNodeIdleTimeInHrs";
    end if;

    -- increase id column size
    if exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'id' and data_type = 'smallint') then
      ALTER TABLE "nodes" ALTER COLUMN "id" TYPE INTEGER;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "nodes" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- alter datatype of projectIntegrationId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'projectIntegrationId' and data_type = 'smallint') then
      ALTER TABLE "nodes" ALTER COLUMN "projectIntegrationId" TYPE integer;
    end if;

    -- alter datatype of nodePoolId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'nodePoolId' and data_type = 'smallint') then
      ALTER TABLE "nodes" ALTER COLUMN "nodePoolId" TYPE integer;
    end if;

    -- create nullable field of lastInitializedAt in nodes to
    if not exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'lastInitializedAt') then
      ALTER TABLE "nodes" ADD COLUMN "lastInitializedAt" timestamp with time zone NULL;
    end if;

    -- add initPropertyBag column to nodes table
    if not exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'initPropertyBag') then
      ALTER TABLE "nodes" ADD COLUMN "initPropertyBag" text;
    end if;

    -- add systemPropertyBag column to nodes table
    if not exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'systemPropertyBag') then
      ALTER TABLE "nodes" ADD COLUMN "systemPropertyBag" text;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'nodes' and column_name='id' and column_default='nextval(''nodes_id_seq''::regclass)'
    ) then
      -- Name: nodes_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public.nodes ALTER COLUMN id SET DEFAULT nextval('public.nodes_id_seq'::regclass);
    end if;

    -- increase size of intendedBuildPlaneVersion column in node to 30
    if exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'intendedBuildPlaneVersion' and character_maximum_length = 12) then
      ALTER TABLE "nodes" ALTER COLUMN "intendedBuildPlaneVersion" TYPE varchar(30);
    end if;

    -- increase size of currentBuildPlaneVersion column in node to 30
    if exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'currentBuildPlaneVersion' and character_maximum_length = 12) then
      ALTER TABLE "nodes" ALTER COLUMN "currentBuildPlaneVersion" TYPE varchar(30);
    end if;

    -- add runtime column to nodes table
    if not exists (select 1 from information_schema.columns where table_name = 'nodes' and column_name = 'runtime') then
        ALTER TABLE "nodes" ADD COLUMN "runtime" text;
    end if;
  end
$$
