--
-- Name: pipelineSources; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."pipelineSources" (
    id integer NOT NULL,
    name character varying(255),
    "projectId" integer NOT NULL,
    "projectIntegrationId" integer,
    "repositoryFullName" character varying(255),
    "branch" character varying(255),
    "fileFilter" character varying(510),
    "configFolder" character varying(255),
    "isMultiBranch" boolean DEFAULT false NOT NULL,
    "branchExcludePattern" character varying(255),
    "branchIncludePattern" character varying(255),
    "environments" character varying(255)[],
    "isSyncing" boolean DEFAULT false NOT NULL,
    "lastSyncStatusCode" smallint,
    "lastSyncStartedAt" timestamp with time zone,
    "lastSyncEndedAt" timestamp with time zone,
    "lastSyncLogs" text,
    "resourceId" integer,
    "templateId" integer,
    "valuesYmlPropertyBag" text,
    "pipelinesYmlPropertyBag" text,
    "accessResourceNamePrefix" character varying(255),
    "artifactoryTokenPermissions" character varying(255)[],
    "createdBy" integer NOT NULL,
    "updatedBy" integer NOT NULL,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL,
    "isInternal" boolean,
    "isDeleting" boolean,
    "workspaceId" integer
);


--
-- Name: pipelineSources_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."pipelineSources_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."pipelineSources".id;


do $$
  begin

  -- add isDeleting column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'isDeleting') then
      ALTER TABLE "pipelineSources" ADD COLUMN "isDeleting" boolean;
    end if;

    -- add isInternal column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'isInternal') then
      ALTER TABLE "pipelineSources" ADD COLUMN "isInternal" boolean;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "pipelineSources" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- add templateId column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'templateId') then
      ALTER TABLE "pipelineSources" ADD COLUMN "templateId" integer;
    end if;

    -- drop null constraint projectIntegrationId column to pipelineSources table
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'projectIntegrationId' and is_nullable = 'NO') then
      ALTER TABLE "pipelineSources" ALTER COLUMN "projectIntegrationId" DROP NOT NULL;
    end if;

    -- drop null constraint repositoryFullName column to pipelineSources table
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'repositoryFullName' and is_nullable = 'NO') then
      ALTER TABLE "pipelineSources" ALTER COLUMN "repositoryFullName" DROP NOT NULL;
    end if;

    -- drop null constraint fileFilter column to pipelineSources table
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'fileFilter' and is_nullable = 'NO') then
      ALTER TABLE "pipelineSources" ALTER COLUMN "fileFilter" DROP NOT NULL;
    end if;

    -- add valuesYmlPropertyBag column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'valuesYmlPropertyBag') then
      ALTER TABLE "pipelineSources" ADD COLUMN "valuesYmlPropertyBag" text;
    end if;

    -- add pipelinesYmlPropertyBag column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'pipelinesYmlPropertyBag') then
      ALTER TABLE "pipelineSources" ADD COLUMN "pipelinesYmlPropertyBag" text;
    end if;

    -- add environments column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'environments') then
      ALTER TABLE "pipelineSources" ADD COLUMN "environments" character varying(255)[];
    end if;

     -- add name column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'name') then
      ALTER TABLE "pipelineSources" ADD COLUMN "name" character varying(255);
    end if;

    -- add accessResourceNamePrefix column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'accessResourceNamePrefix') then
        ALTER TABLE "pipelineSources" ADD COLUMN "accessResourceNamePrefix" character varying(255);
    end if;

    -- add configFolder column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'configFolder') then
      ALTER TABLE "pipelineSources" ADD COLUMN "configFolder" character varying(255);
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'pipelineSources' and column_name='id' and column_default='nextval(''"pipelineSources_id_seq"''::regclass)'
    ) then
      -- Name: pipelineSources_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."pipelineSources" ALTER COLUMN id SET DEFAULT nextval('public."pipelineSources_id_seq"'::regclass);
    end if;

    -- add artifactoryTokenPermissions column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'artifactoryTokenPermissions') then
      ALTER TABLE "pipelineSources" ADD COLUMN "artifactoryTokenPermissions" character varying(255)[];
    end if;

    -- add workspaceId column to pipelineSources table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSources' and column_name = 'workspaceId') then
      ALTER TABLE "pipelineSources" ADD COLUMN "workspaceId" integer;
    end if;

  end
$$
