--
-- Name: pipelineSteps; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."pipelineSteps" (
    id integer NOT NULL,
    name character varying(255) NOT NULL,
    "ymlConfigPropertyBag" text,
    "ymlExecPropertyBag" text,
    "typeCode" integer NOT NULL,
    "latestStepId" integer,
    "projectId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "masterResourceId" integer,
    "pipelineId" integer NOT NULL,
    "isDeleted" boolean DEFAULT false NOT NULL,
    "deletedAt" timestamp with time zone,
    "isConsistent" boolean DEFAULT false NOT NULL,
    "isStale" boolean DEFAULT false NOT NULL,
    "staleAt" timestamp with time zone,
    "isPaused" boolean DEFAULT false NOT NULL,
    yml text NOT NULL,
    "createdBy" character varying(24) NOT NULL,
    "updatedBy" character varying(24) NOT NULL,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: pipelineSteps_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."pipelineSteps_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."pipelineSteps".id;


do $$
  begin

    -- add masterResourceId column to steps table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSteps' and column_name = 'masterResourceId') then
      ALTER TABLE "pipelineSteps" ADD COLUMN "masterResourceId" integer;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSteps' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "pipelineSteps" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- alter datatype of masterResourceId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSteps' and column_name = 'masterResourceId' and data_type = 'smallint') then
      ALTER TABLE "pipelineSteps" ALTER COLUMN "masterResourceId" TYPE integer;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'pipelineSteps' and column_name='id' and column_default='nextval(''"pipelineSteps_id_seq"''::regclass)'
    ) then
      -- Name: pipelineSteps_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."pipelineSteps" ALTER COLUMN id SET DEFAULT nextval('public."pipelineSteps_id_seq"'::regclass);
    end if;

    -- alter datatype of typeCode column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSteps' and column_name = 'typeCode' and data_type = 'smallint') then
        ALTER TABLE "pipelineSteps" ALTER COLUMN "typeCode" TYPE integer;
    end if;

  end
$$
