--
-- Name: pipelineSyncStatuses; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."pipelineSyncStatuses" (
    id integer NOT NULL,
    "projectId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "pipelineSourceBranch" character varying(255),
    "isSyncing" boolean DEFAULT false NOT NULL,
    "lastSyncStatusCode" smallint,
    "lastSyncStartedAt" timestamp with time zone NOT NULL,
    "lastSyncEndedAt" timestamp with time zone,
    "lastSyncLogs" text,
    "triggeredByResourceVersionId" integer,
    "isMissingConfig" boolean,
    "commitData" text,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: pipelineSyncStatuses_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."pipelineSyncStatuses_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."pipelineSyncStatuses".id;


do $$
  begin

    -- add triggeredByResourceVersionId column to pipelineSyncStatuses table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSyncStatuses' and column_name = 'triggeredByResourceVersionId') then
      ALTER TABLE "pipelineSyncStatuses" ADD COLUMN "triggeredByResourceVersionId" INTEGER;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'pipelineSyncStatuses' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "pipelineSyncStatuses" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- add isMissingConfig column to pipelineSyncStatuses table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSyncStatuses' and column_name = 'isMissingConfig') then
      ALTER TABLE "pipelineSyncStatuses" ADD COLUMN "isMissingConfig" BOOLEAN;
    end if;

    -- add commitData column to pipelineSyncStatuses table
    if not exists (select 1 from information_schema.columns where table_name = 'pipelineSyncStatuses' and column_name = 'commitData') then
      ALTER TABLE "pipelineSyncStatuses" ADD COLUMN "commitData" text;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'pipelineSyncStatuses' and column_name='id' and column_default='nextval(''"pipelineSyncStatuses_id_seq"''::regclass)'
    ) then
      -- Name: pipelineSyncStatuses_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."pipelineSyncStatuses" ALTER COLUMN id SET DEFAULT nextval('public."pipelineSyncStatuses_id_seq"'::regclass);
    end if;

  end
$$
