--
-- Name: pipelines; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public.pipelines (
    id integer NOT NULL,
    name character varying(255) NOT NULL,
    "projectId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "pipelineSourceBranch" character varying(255),
    "latestRunNumber" integer NOT NULL,
    "latestRunId" bigint,
    "latestSuccessfulRunId" bigint,
    "latestFailedRunId" bigint,
    "latestErrorRunId" bigint,
    "latestSkippedRunId" bigint,
    "latestTimedOutRunId" bigint,
    "latestCancelledRunId" bigint,
    "latestUnstableRunId" bigint,
    "latestCompletedRunId" bigint,
    "retentionMinRuns" integer,
    "retentionMaxAgeDays" integer,
    "ymlConfigPropertyBag" text,
    "ymlPropertyBag" text,
    "syntaxVersion" character varying(10),
    "isDeleted" boolean DEFAULT false NOT NULL,
    "deletedAt" timestamp with time zone,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: pipelines_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.pipelines_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public.pipelines.id;


do $$
  begin
    -- add latestSuccessfulRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestSuccessfulRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestSuccessfulRunId" bigint;
    end if;

    -- add latestFailedRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestFailedRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestFailedRunId" bigint;
    end if;

    -- add latestErrorRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestErrorRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestErrorRunId" bigint;
    end if;

    -- add latestSkippedRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestSkippedRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestSkippedRunId" bigint;
    end if;

    -- add latestTimedOutRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestTimedOutRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestTimedOutRunId" bigint;
    end if;

    -- add latestCancelledRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestCancelledRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestCancelledRunId" bigint;
    end if;

    -- add latestUnstableRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestUnstableRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestUnstableRunId" bigint;
    end if;

    -- add latestCompletedRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'latestCompletedRunId') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "latestCompletedRunId" bigint;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "pipelines" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'pipelines' and column_name='id' and column_default='nextval(''pipelines_id_seq''::regclass)'
    ) then
      -- Name: pipelines_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public.pipelines ALTER COLUMN id SET DEFAULT nextval('public.pipelines_id_seq'::regclass);
    end if;

    -- add retentionMinRuns column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'retentionMinRuns') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "retentionMinRuns" integer;
    end if;

    -- add retentionMaxAgeDays column
    if not exists (select 1 from information_schema.columns where table_name = 'pipelines' and column_name = 'retentionMaxAgeDays') then
      ALTER TABLE ONLY public.pipelines ADD COLUMN "retentionMaxAgeDays" integer;
    end if;

  end
$$;
