--
-- Name: projectIntegrations; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."projectIntegrations" (
    id integer NOT NULL,
    name character varying(255) NOT NULL,
    "projectId" integer NOT NULL,
    "environments" character varying(255)[],
    "masterIntegrationId" integer NOT NULL,
    "masterIntegrationType" character varying(255) NOT NULL,
    "masterIntegrationName" character varying(255) NOT NULL,
    "isInternal" boolean DEFAULT false NOT NULL,
    "providerId" integer,
    "accessResourceNamePrefix" character varying(255),
    "propertyBag" text,
    "permissions" text,
    "provider" character varying(255) NOT NULL,
    "createdByUserName" character varying(255) NOT NULL,
    "updatedByUserName" character varying(255) NOT NULL,
    "createdBy" integer NOT NULL,
    "updatedBy" integer NOT NULL,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: projectIntegrations_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."projectIntegrations_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."projectIntegrations".id;


do $$
  begin
    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'projectIntegrations' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "projectIntegrations" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- add environments column to projectIntegrations table
    if not exists (select 1 from information_schema.columns where table_name = 'projectIntegrations' and column_name = 'environments') then
      ALTER TABLE "projectIntegrations" ADD COLUMN "environments" character varying(255)[];
    end if;

    -- add accessResourceNamePrefix column to projectIntegrations table
    if not exists (select 1 from information_schema.columns where table_name = 'projectIntegrations' and column_name = 'accessResourceNamePrefix') then
      ALTER TABLE "projectIntegrations" ADD COLUMN "accessResourceNamePrefix" character varying(255);
    end if;

    -- add provider column to projectIntegrations table
    if not exists (select 1 from information_schema.columns where table_name = 'projectIntegrations' and column_name = 'provider') then
      ALTER TABLE "projectIntegrations" ADD COLUMN "provider" character varying(255) DEFAULT 'vault';
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'projectIntegrations' and column_name='id' and column_default='nextval(''"projectIntegrations_id_seq"''::regclass)'
    ) then
      -- Name: projectIntegrations_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."projectIntegrations" ALTER COLUMN id SET DEFAULT nextval('public."projectIntegrations_id_seq"'::regclass);
    end if;

  end
$$
