--
-- Name: resources; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public.resources (
    id integer NOT NULL,
    name character varying(255) NOT NULL,
    "projectIntegrationId" integer,
    "ymlConfigPropertyBag" text,
    "systemPropertyBag" text,
    "staticPropertyBag" text,
    "typeCode" integer NOT NULL,
    "latestResourceVersionId" integer,
    "pinnedVersionId" bigint,
    "projectId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "pipelineSourceBranch" character varying(255),
    "isDeleted" boolean DEFAULT false NOT NULL,
    "deletedAt" timestamp with time zone,
    "isConsistent" boolean DEFAULT false NOT NULL,
    "isInternal" boolean DEFAULT false NOT NULL,
    yml text,
    "masterResourceId" integer,
    "syntaxVersion" character varying(10),
    "nextTriggerTime" timestamp with time zone,
    "gitRepoFullName" character varying(255),
    "gitIncludeBranchPattern" text,
    "gitExcludeBranchPattern" text,
    "gitBuildOnCommit" boolean,
    "gitBuildOnPullRequestCreate" boolean,
    "gitBuildOnPullRequestClose" boolean,
    "gitBuildOnReleaseCreate" boolean,
    "gitBuildOnTagCreate" boolean,
    "gitBuildOnBranchDelete" boolean,
    "gitBuildOnBranchCreate" boolean,
    "storeVersionHistory" boolean,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: resources_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.resources_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public.resources.id;


do $$
  begin
    -- add masterResourceId column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'masterResourceId') then
      ALTER TABLE "resources" ADD COLUMN "masterResourceId" integer;
    end if;

    -- alter datatype of masterResourceId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'masterResourceId' and data_type = 'smallint') then
      ALTER TABLE "resources" ALTER COLUMN "masterResourceId" TYPE integer;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "resources" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- add pinnedVersionId column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'pinnedVersionId') then
      ALTER TABLE "resources" ADD COLUMN "pinnedVersionId" bigint;
    end if;

    -- add gitRepoFullName column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitRepoFullName') then
      ALTER TABLE "resources" ADD COLUMN "gitRepoFullName" varchar(255);
    end if;

    -- add gitIncludeBranchPattern column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitIncludeBranchPattern') then
      ALTER TABLE "resources" ADD COLUMN "gitIncludeBranchPattern" text;
    end if;

    -- add gitExcludeBranchPattern column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitExcludeBranchPattern') then
      ALTER TABLE "resources" ADD COLUMN "gitExcludeBranchPattern" text;
    end if;

    -- add gitBuildOnCommit column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitBuildOnCommit') then
      ALTER TABLE "resources" ADD COLUMN "gitBuildOnCommit" boolean;
    end if;

    -- add gitBuildOnPullRequestCreate column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitBuildOnPullRequestCreate') then
      ALTER TABLE "resources" ADD COLUMN "gitBuildOnPullRequestCreate" boolean;
    end if;

    -- add gitBuildOnPullRequestClose column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitBuildOnPullRequestClose') then
      ALTER TABLE "resources" ADD COLUMN "gitBuildOnPullRequestClose" boolean;
    end if;

    -- add gitBuildOnReleaseCreate column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitBuildOnReleaseCreate') then
      ALTER TABLE "resources" ADD COLUMN "gitBuildOnReleaseCreate" boolean;
    end if;

     -- add gitBuildOnTagCreate column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitBuildOnTagCreate') then
      ALTER TABLE "resources" ADD COLUMN "gitBuildOnTagCreate" boolean;
    end if;

      -- add gitBuildOnBranchDelete column to resources table
     if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitBuildOnBranchDelete') then
       ALTER TABLE "resources" ADD COLUMN "gitBuildOnBranchDelete" boolean;
     end if;

    -- add gitBuildOnBranchCreate column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'gitBuildOnBranchCreate') then
      ALTER TABLE "resources" ADD COLUMN "gitBuildOnBranchCreate" boolean;
    end if;

    -- add storeVersionHistory column to resources table
    if not exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'storeVersionHistory') then
      ALTER TABLE "resources" ADD COLUMN "storeVersionHistory" boolean;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'resources' and column_name='id' and column_default='nextval(''resources_id_seq''::regclass)'
    ) then
      -- Name: resources_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public.resources ALTER COLUMN id SET DEFAULT nextval('public.resources_id_seq'::regclass);
    end if;

    -- alter datatype of typeCode column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'resources' and column_name = 'typeCode' and data_type = 'smallint') then
        ALTER TABLE "resources" ALTER COLUMN "typeCode" TYPE integer;
    end if;

  end
$$
