--
-- Name: runResourceVersions; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."runResourceVersions" (
    id bigint NOT NULL,
    "projectId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "pipelineSourceBranch" character varying(255),
    "pipelineId" integer NOT NULL,
    "runId" bigint NOT NULL,
    "stepId" bigint NOT NULL,
    "resourceName" character varying(255) NOT NULL,
    "resourceTypeCode" integer NOT NULL,
    "masterResourceId" integer,
    "resourceVersionId" bigint NOT NULL,
    "resourceStaticPropertyBag" text,
    "resourceConfigPropertyBag" text,
    "resourceVersionContentPropertyBag" text,
    "resourceVersionCreatedByStepId" bigint,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: runResourceVersions_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."runResourceVersions_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."runResourceVersions".id;


do $$
  begin

    -- add masterResourceId column to runResourceVersions table
    if not exists (select 1 from information_schema.columns where table_name = 'runResourceVersions' and column_name = 'masterResourceId') then
      ALTER TABLE "runResourceVersions" ADD COLUMN "masterResourceId" integer;
    end if;

    -- alter datatype of masterResourceId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'runResourceVersions' and column_name = 'masterResourceId' and data_type = 'smallint') then
      ALTER TABLE "runResourceVersions" ALTER COLUMN "masterResourceId" TYPE integer;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'runResourceVersions' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "runResourceVersions" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- add pipelineSourceBranch
    if not exists (select 1 from information_schema.columns where table_name = 'runResourceVersions' and column_name = 'pipelineSourceBranch') then
      ALTER TABLE "runResourceVersions" ADD COLUMN "pipelineSourceBranch" character varying(255);
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'runResourceVersions' and column_name='id' and column_default='nextval(''"runResourceVersions_id_seq"''::regclass)'
    ) then
      -- Name: runResourceVersions_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."runResourceVersions" ALTER COLUMN id SET DEFAULT nextval('public."runResourceVersions_id_seq"'::regclass);
    end if;

    -- alter datatype of resourceTypeCode column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'runResourceVersions' and column_name = 'resourceTypeCode' and data_type = 'smallint') then
        ALTER TABLE "runResourceVersions" ALTER COLUMN "resourceTypeCode" TYPE integer;
    end if;

  end
$$
