--
-- Name: runs; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public.runs (
    id bigint NOT NULL,
    name character varying(255),
    "pipelineId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "projectId" integer NOT NULL,
    "parentRunId" bigint,
    "runNumber" integer NOT NULL,
    "statusCode" integer NOT NULL,
    "staticPropertyBag" text,
    "pubKey" text,
    "description" character varying(1024),
    "systemPropertyBag" text,
    "merkleLeaves" character varying(64)[],
    "merkleRoot" character varying(64),
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL,
    "startedAt" timestamp with time zone,
    "endedAt" timestamp with time zone,
    "durationSeconds" integer,
    "triggerId" bigint
);


--
-- Name: runs_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.runs_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: runs_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
--

ALTER SEQUENCE public.runs_id_seq OWNED BY public.runs.id;

--
-- Name: trigger_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.trigger_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1
    OWNED BY public.runs.id;


do $$
  begin
    -- add startedAt column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'startedAt') then
      ALTER TABLE ONLY public.runs ADD COLUMN "startedAt"  timestamp with time zone;
    end if;

    -- add endedAt column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'endedAt') then
      ALTER TABLE ONLY public.runs ADD COLUMN "endedAt"  timestamp with time zone;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "runs" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- add parentRunId column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'parentRunId') then
      ALTER TABLE ONLY public.runs ADD COLUMN "parentRunId"  bigint;
    end if;

    -- add pubKey column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'pubKey') then
      ALTER TABLE ONLY public.runs ADD COLUMN "pubKey"  text;
    end if;

    -- add systemPropertyBag column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'systemPropertyBag') then
      ALTER TABLE ONLY public.runs ADD COLUMN "systemPropertyBag"  text;
    end if;

    -- add merkleLeaves column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'merkleLeaves') then
      ALTER TABLE ONLY public.runs ADD COLUMN "merkleLeaves"  character varying(64)[];
    end if;

    -- add merkleRoot column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'merkleRoot') then
      ALTER TABLE ONLY public.runs ADD COLUMN "merkleRoot"  character varying(64);
    end if;

    -- add duration column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'durationSeconds') then
      ALTER TABLE ONLY public.runs ADD COLUMN "durationSeconds" integer;
    end if;

    --add triggerId column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'triggerId') then
      ALTER TABLE ONLY public.runs ADD COLUMN "triggerId" bigint;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'runs' and column_name='id' and column_default='nextval(''runs_id_seq''::regclass)'
    ) then
      -- Name: runs_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public.runs ALTER COLUMN id SET DEFAULT nextval('public.runs_id_seq'::regclass);
    end if;

    -- add description column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'description') then
      ALTER TABLE ONLY public.runs ADD COLUMN "description" character varying(1024);
    end if;

    -- add name column
    if not exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'name') then
      ALTER TABLE ONLY public.runs ADD COLUMN "name" character varying(1024);
    end if;

    -- alter datatype of statusCode column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'runs' and column_name = 'statusCode' and data_type = 'smallint') then
        ALTER TABLE "runs" ALTER COLUMN "statusCode" TYPE integer;
    end if;

  end
$$;
