--
-- Name: stepTestReports; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public."stepTestReports" (
    id bigint NOT NULL,
    "projectId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "stepId" bigint NOT NULL,
    "durationSeconds" integer,
    "errorDetails" text,
    "failureDetails" text,
    "totalTests" integer,
    "totalPassing" integer,
    "totalFailures" integer,
    "totalErrors" integer,
    "totalSkipped" integer,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: stepTestReports_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public."stepTestReports_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public."stepTestReports".id;


do $$
  begin

    -- increase test report column sizes
    if exists (select 1 from information_schema.columns where table_name = 'stepTestReports' and column_name = 'totalTests' and data_type = 'smallint') then
      ALTER TABLE "stepTestReports" ALTER COLUMN "totalTests" TYPE INTEGER;
    end if;

    if exists (select 1 from information_schema.columns where table_name = 'stepTestReports' and column_name = 'totalPassing' and data_type = 'smallint') then
      ALTER TABLE "stepTestReports" ALTER COLUMN "totalPassing" TYPE INTEGER;
    end if;

    if exists (select 1 from information_schema.columns where table_name = 'stepTestReports' and column_name = 'totalFailures' and data_type = 'smallint') then
      ALTER TABLE "stepTestReports" ALTER COLUMN "totalFailures" TYPE INTEGER;
    end if;

    if exists (select 1 from information_schema.columns where table_name = 'stepTestReports' and column_name = 'totalErrors' and data_type = 'smallint') then
      ALTER TABLE "stepTestReports" ALTER COLUMN "totalErrors" TYPE INTEGER;
    end if;

    if exists (select 1 from information_schema.columns where table_name = 'stepTestReports' and column_name = 'totalSkipped' and data_type = 'smallint') then
      ALTER TABLE "stepTestReports" ALTER COLUMN "totalSkipped" TYPE INTEGER;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'stepTestReports' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "stepTestReports" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'stepTestReports' and column_name='id' and column_default='nextval(''"stepTestReports_id_seq"''::regclass)'
    ) then
      -- Name: stepTestReports_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public."stepTestReports" ALTER COLUMN id SET DEFAULT nextval('public."stepTestReports_id_seq"'::regclass);
    end if;

  end
$$
