--
-- Name: steplets; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public.steplets (
    id bigint NOT NULL,
    "projectId" integer NOT NULL,
    "pipelineId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "stepId" bigint NOT NULL,
    "affinityGroup" character varying(1024),
    "priority" integer,
    "stepletNumber" smallint NOT NULL,
    "statusCode" integer NOT NULL,
    "configPropertyBag" text,
    "runtimePropertyBag" text,
    "isConsoleArchived" boolean DEFAULT false,
    "triggeredAt" timestamp with time zone,
    "queuedAt" timestamp with time zone,
    "endedAt" timestamp with time zone,
    "startedAt" timestamp with time zone,
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: steplets_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.steplets_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public.steplets.id;


do $$
  begin
    if exists (select 1 from information_schema.tables where table_name = 'steplets') then
      -- add pipelineSourceId column to steplets table
      if not exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'pipelineSourceId') then
        ALTER TABLE "steplets" ADD COLUMN "pipelineSourceId" INTEGER;
      end if;
      -- add configPropertyBag column to steplets table
      if not exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'configPropertyBag') then
        ALTER TABLE "steplets" ADD COLUMN "configPropertyBag" text;
      end if;

      -- alter datatype of projectId column from smallint to integer
      if exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'projectId' and data_type = 'smallint') then
        ALTER TABLE "steplets" ALTER COLUMN "projectId" TYPE integer;
      end if;

      -- add runtimePropertyBag column to steplets table
      if not exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'runtimePropertyBag') then
        ALTER TABLE "steplets" ADD COLUMN "runtimePropertyBag" text;
      end if;

       -- add priority column to steplets table
      if not exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'priority') then
        ALTER TABLE "steplets" ADD COLUMN "priority" INTEGER;
      end if;

      -- add affinityGroup column to steplets table
      if not exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'affinityGroup') then
        ALTER TABLE "steplets" ADD COLUMN "affinityGroup" character varying(1024);
      end if;

      -- set id column's default value to the sequence next value
      if not exists (
        select 1 from information_schema.columns
        where table_name = 'steplets' and column_name='id' and column_default='nextval(''steplets_id_seq''::regclass)'
      ) then
        -- Name: steplets_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
        ALTER TABLE ONLY public.steplets ALTER COLUMN id SET DEFAULT nextval('public.steplets_id_seq'::regclass);
      end if;

      -- alter datatype of statusCode column from smallint to integer
      if exists (select 1 from information_schema.columns where table_name = 'steplets' and column_name = 'statusCode' and data_type = 'smallint') then
          ALTER TABLE "steplets" ALTER COLUMN "statusCode" TYPE integer;
      end if;

    end if;
  end
$$
