--
-- Name: steps; Type: TABLE; Schema: public;
--

CREATE TABLE IF NOT EXISTS public.steps (
    id bigint NOT NULL,
    "pipelineId" integer NOT NULL,
    "pipelineSourceId" integer NOT NULL,
    "pipelineStepId" integer NOT NULL,
    "projectId" integer NOT NULL,
    name character varying(255) NOT NULL,
    "runId" integer NOT NULL,
    "statusCode" integer NOT NULL,
    "typeCode" integer NOT NULL,
    "masterResourceId" integer,
    "affinityGroup" character varying(255),
    "groupInProgress" boolean,
    "groupStartedAt" timestamp with time zone,
    "fileStoreProvider" character varying(64),
    "pipelineStateArtifactName" character varying(255),
    "triggeredByResourceVersionId" integer,
    "triggeredByStepId" bigint,
    "triggeredByIdentityId" integer,
    "configPropertyBag" text,
    "execPropertyBag" text,
    "staticPropertyBag" text,
    "systemPropertyBag" text,
    "triggeredAt" timestamp with time zone,
    "timeoutAt" timestamp with time zone,
    "readyAt" timestamp with time zone,
    "queuedAt" timestamp with time zone,
    "endedAt" timestamp with time zone,
    "startedAt" timestamp with time zone,
    "lastHeartbeatAt" timestamp with time zone,
    "approvalRequestedAt" timestamp with time zone,
    "pendingLogsComplete" boolean DEFAULT false,
    "isConsoleArchived" boolean DEFAULT false,
    "requiresApproval" boolean,
    "isApproved" boolean,
    "externalBuildId" character varying(255),
    "externalBuildUrl" character varying(510),
    "createdAt" timestamp with time zone NOT NULL,
    "updatedAt" timestamp with time zone NOT NULL
);


--
-- Name: steps_id_seq; Type: SEQUENCE; Schema: public;
--

CREATE SEQUENCE IF NOT EXISTS public.steps_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
    OWNED BY public.steps.id;


do $$
  begin

  -- add groupStartedAt column to steps table
    if exists (select 1 from information_schema.tables where table_name = 'steps') then
      if not exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'groupStartedAt') then
        ALTER TABLE "steps" ADD COLUMN "groupStartedAt" timestamp with time zone;
      end if;
    end if;

    -- add masterResourceId column to steps table
    if not exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'masterResourceId') then
      ALTER TABLE "steps" ADD COLUMN "masterResourceId" integer;
    end if;

    -- alter datatype of masterResourceId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'masterResourceId' and data_type = 'smallint') then
      ALTER TABLE "steps" ALTER COLUMN "masterResourceId" TYPE integer;
    end if;

    -- alter datatype of projectId column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'projectId' and data_type = 'smallint') then
      ALTER TABLE "steps" ALTER COLUMN "projectId" TYPE integer;
    end if;

    -- add requiresApproval column to steps table
    if not exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'requiresApproval') then
      ALTER TABLE "steps" ADD COLUMN "requiresApproval" boolean;
    end if;

    -- add isApproved column to steps table
    if not exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'isApproved') then
      ALTER TABLE "steps" ADD COLUMN "isApproved" boolean;
    end if;

    -- add approvalRequestedAt column to steps table
    if not exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'approvalRequestedAt') then
      ALTER TABLE "steps" ADD COLUMN "approvalRequestedAt" timestamp with time zone;
    end if;

    -- add lastHeartbeatAt column to steps table
    if not exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'lastHeartbeatAt') then
      ALTER TABLE "steps" ADD COLUMN "lastHeartbeatAt" timestamp with time zone;
    end if;

    -- add systemPropertyBag column
    if not exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'systemPropertyBag') then
      ALTER TABLE "steps" ADD COLUMN "systemPropertyBag"  text;
    end if;

    -- set id column's default value to the sequence next value
    if not exists (
      select 1 from information_schema.columns
      where table_name = 'steps' and column_name='id' and column_default='nextval(''steps_id_seq''::regclass)'
    ) then
      -- Name: steps_id_seq; Type: SEQUENCE OWNED BY; Schema: public;
      ALTER TABLE ONLY public.steps ALTER COLUMN id SET DEFAULT nextval('public.steps_id_seq'::regclass);
    end if;

    -- alter datatype of typeCode column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'typeCode' and data_type = 'smallint') then
        ALTER TABLE "steps" ALTER COLUMN "typeCode" TYPE integer;
    end if;

    -- alter datatype of statusCode column from smallint to integer
    if exists (select 1 from information_schema.columns where table_name = 'steps' and column_name = 'statusCode' and data_type = 'smallint') then
        ALTER TABLE "steps" ALTER COLUMN "statusCode" TYPE integer;
    end if;

  end
$$
