#!/bin/bash

urlParsePath=../urlParse.sh

segmentsTest() {
  testUrl=$1
  echo "Testing segments for $testUrl"

  expectedProtocol=$2
  expectedUser=$3
  expectedHostname=$4
  expectedPort=$5
  expectedPath=$6

  gotProtocol=$($urlParsePath --protocol $testUrl)
  exitCode=$?
  if [[ "$exitCode" -ne "0" ]]; then
    echo "Failed to parse url $testUrl. Exit code: $exitCode"
    exit 2
  fi

  gotUser=$($urlParsePath --user $testUrl)
  gotHostname=$($urlParsePath --hostname $testUrl)
  gotPort=$($urlParsePath --port $testUrl)
  gotPath=$($urlParsePath --path $testUrl)

  if [[ "$expectedProtocol" != "$gotProtocol" ]]; then
    echo "Got wrong protocol for $testUrl. Expected: $expectedProtocol. Got: $gotProtocol."
    exit 1
  fi

  if [[ "$expectedUser" != "$gotUser" ]]; then
    echo "Got wrong user for $testUrl. Expected: $expectedUser. Got: $gotUser."
    exit 1
  fi

  if [[ "$expectedHostname" != "$gotHostname" ]]; then
    echo "Got wrong hostname for $testUrl. Expected: $expectedHostname. Got: $gotHostname."
    exit 1
  fi

  if [[ "$expectedPort" != "$gotPort" ]]; then
    echo "Got wrong port for $testUrl. Expected: $expectedPort. Got: $gotPort."
    exit 1
  fi

  if [[ "$expectedPath" != "$gotPath" ]]; then
    echo "Got wrong path for $testUrl. Expected: $expectedPath. Got: $gotPath."
    exit 1
  fi
}

removeCredentialsTest() {
  testUrl=$1
  echo "Testing credentials removal for $testUrl"

  expectedUrl=$2
  gotUrl=$($urlParsePath --remove_credentials $testUrl)
  exitCode=$?
  if [[ "$exitCode" -ne "0" ]]; then
    echo "Failed to parse url $testUrl. Exit code: $exitCode"
    exit 3
  fi

  if [[ "$expectedUrl" != "$gotUrl" ]]; then
    echo "Got wrong url without credentials for $testUrl. Expected: $expectedUrl. Got: $gotUrl."
    exit 1
  fi
}

# Most test cases came from https://github.com/cweb/url-testing/blob/master/urls.json
# Test Case                                          Expected Result
#                                                    Protocol  User      Domain              Port      Path
segmentsTest ''                                      ""        ""        ""                  ""        ""
segmentsTest ':foo.com/'                             ""        ""        ""                  ""        ""
segmentsTest ':'                                     ""        ""        ""                  ""        ""
segmentsTest ':a'                                    ""        ""        ""                  ""        ""
segmentsTest ':/'                                    ""        ""        ""                  ""        ""
segmentsTest ':\\\\'                                 ""        ""        ""                  ""        ""
segmentsTest ':#'                                    ""        ""        ""                  ""        ""
segmentsTest '#'                                     ""        ""        ""                  ""        ""
segmentsTest '#/'                                    ""        ""        ""                  ""        ""
segmentsTest '#\\\\'                                 ""        ""        ""                  ""        ""
segmentsTest '#;?'                                   ""        ""        ""                  ""        ""
segmentsTest '?'                                     ""        ""        ""                  ""        ""
segmentsTest '/'                                     ""        ""        ""                  ""        ""
segmentsTest ":23"                                   ""        ""        ""                  ""        ""
segmentsTest "/:23"                                  ""        ""        ""                  ""        ""
segmentsTest "//"                                    ""        ""        ""                  ""        ""
segmentsTest "::"                                    ""        ""        ""                  ""        ""
segmentsTest "::23"                                  ""        ""        "23"                ""        ""
segmentsTest 'www.jfrog.com'                         ""        ""        "www.jfrog.com"     ""        ""
segmentsTest 'www.jfrog.com:8080'                    ""        ""        "www.jfrog.com"     "8080"    ""
segmentsTest 'localhost'                             ""        ""        "localhost"         ""        ""
segmentsTest 'localhost:80'                          ""        ""        "localhost"         "80"      ""
segmentsTest 'http://localhost'                      "http"    ""        "localhost"         ""        ""
segmentsTest 'http://localhost:80'                   "http"    ""        "localhost"         "80"      ""
segmentsTest 'user@localhost'                        ""        "user"    "localhost"         ""        ""
segmentsTest 'user@localhost:80'                     ""        "user"    "localhost"         "80"      ""
segmentsTest 'http://user@localhost'                 "http"    "user"    "localhost"         ""        ""
segmentsTest 'http://user@localhost:80'              "http"    "user"    "localhost"         "80"      ""
segmentsTest 'user:pass@localhost'                   ""        "user"    "localhost"         ""        ""
segmentsTest 'user:pass@localhost:80'                ""        "user"    "localhost"         "80"      ""
segmentsTest 'http://user:pass@localhost'            "http"    "user"    "localhost"         ""        ""
segmentsTest 'http://user:pass@localhost:80'         "http"    "user"    "localhost"         "80"      ""
segmentsTest '192.168.0.10'                          ""        ""        "192.168.0.10"      ""        ""
segmentsTest '192.168.0.10:80'                       ""        ""        "192.168.0.10"      "80"      ""
segmentsTest 'http://192.168.0.10'                   "http"    ""        "192.168.0.10"      ""        ""
segmentsTest 'http://192.168.0.10:80'                "http"    ""        "192.168.0.10"      "80"      ""
segmentsTest 'user@192.168.0.10'                     ""        "user"    "192.168.0.10"      ""        ""
segmentsTest 'user@192.168.0.10:80'                  ""        "user"    "192.168.0.10"      "80"      ""
segmentsTest 'http://user@192.168.0.10'              "http"    "user"    "192.168.0.10"      ""        ""
segmentsTest 'http://user@192.168.0.10:80'           "http"    "user"    "192.168.0.10"      "80"      ""
segmentsTest 'user:pass@192.168.0.10'                ""        "user"    "192.168.0.10"      ""        ""
segmentsTest 'user:pass@192.168.0.10:80'             ""        "user"    "192.168.0.10"      "80"      ""
segmentsTest 'http://user:pass@192.168.0.10'         "http"    "user"    "192.168.0.10"      ""        ""
segmentsTest 'http://user:pass@192.168.0.10:80'      "http"    "user"    "192.168.0.10"      "80"      ""
segmentsTest 'http://www.jfrog.com'                  "http"    ""        "www.jfrog.com"     ""        ""
segmentsTest 'https://www.jfrog.com'                 "https"   ""        "www.jfrog.com"     ""        ""
segmentsTest 'https://www.jfrog.com/'                "https"   ""        "www.jfrog.com"     ""        "/"
segmentsTest 'https://www.jfrog.com:8080/'           "https"   ""        "www.jfrog.com"     "8080"    "/"
segmentsTest 'https://user:pass@www.jfrog.com'       "https"   "user"    "www.jfrog.com"     ""        ""
segmentsTest 'https://user:pa:ss@www.jfrog.com'      "https"   "user"    "www.jfrog.com"     ""        ""
segmentsTest 'https://user:pa:s@s@www.jfrog.com'     "https"   "user"    "www.jfrog.com"     ""        ""
segmentsTest 'https://user:pa:s%40s@www.jfrog.com'   "https"   "user"    "www.jfrog.com"    ""        ""
segmentsTest "http://user:p\$!'+*a:s%40s@site.com"   "http"    "user"    "site.com"   ""        ""
segmentsTest 'https://user:pass@www.jfrog.com:8080'  "https"   "user"    "www.jfrog.com"     "8080"    ""
segmentsTest 'http://user:pass@foo:21/bar;par?b#c'   "http"    "user"    "foo"               "21"      "/bar;par?b#c"
segmentsTest 'http://f:/c'                           "http"    ""        "f"                 ""        "/c"
segmentsTest 'http://f:0/c'                          "http"    ""        "f"                 "0"       "/c"
segmentsTest 'http://f:00000/c'                      "http"    ""        "f"                 "00000"   "/c"
segmentsTest 'http://f:b/c'                          "http"    ""        "f"                 "b"       "/c"
segmentsTest 'http://f: /c'                          "http"    ""        "f"                 ""        ""
segmentsTest 'http://f:999999/c'                     "http"    ""        "f"                 "999999"  "/c"
segmentsTest 'http://f: 21 / b ? d # e '             "http"    ""        "f"                 ""        ""
segmentsTest "foo://"                                "foo"     ""        ""                  ""        ""
segmentsTest "foo:/"                                 "foo"     ""        ""                  ""        ""
segmentsTest "http://a:b@c:29/d"                     "http"    "a"       "c"                 "29"      "/d"
segmentsTest "http::@c:29"                           "http"    ""        "c"                 "29"      ""
segmentsTest "http://&amp;a:foo(b]c@d:2/"            "http"    "&amp;a"  "d"                 "2"       "/"
segmentsTest "http://::@c@d:2"                       "http"    ""        "d"                 "2"       ""
segmentsTest "http://foo.com:b@d/"                   "http"    "foo.com" "d"                 ""        "/"
segmentsTest "http://foo.com/\\\\@"                  "http"    ""        "foo.com"           ""        "/\\\\@"
segmentsTest "foo:/bar.com/"                         "foo"     ""        "bar.com"           ""        "/"
segmentsTest "foo://///////"                         "foo"     ""        ""                  ""        ""
segmentsTest "foo://///////bar.com/"                 "foo"     ""        "bar.com"           ""        "/"
segmentsTest "foo:////://///"                        "foo"     ""        ""                  ""        ""
segmentsTest "c:/foo"                                "c"       ""        "foo"               ""        ""
segmentsTest "//foo/bar"                             ""        ""        ""                  ""        ""
segmentsTest "http://foo/path;a??e#f#g"              "http"    ""        "foo"               ""        "/path;a??e#f#g"
segmentsTest "http://foo/abcd?efgh?ijkl"             "http"    ""        "foo"               ""        "/abcd?efgh?ijkl"
segmentsTest "http://foo/abcd#foo?bar"               "http"    ""        "foo"               ""        "/abcd#foo?bar"
segmentsTest "http://www.google.com/foo?bar=baz#"    "http"    ""        "www.google.com"    ""        "/foo?bar=baz#"
segmentsTest "http://[www.google.com]/"              "http"    ""        "[www.google.com]"  ""        "/"
segmentsTest "http:////////user:@google.com:99?foo"  "http"    "user"    "google.com"        "99"      "?foo"
segmentsTest "http://192.0x00A80001"                 "http"    ""        "192.0x00A80001"    ""        ""
segmentsTest "http://www/foo%2Ehtml"                 "http"    ""        "www"               ""        "/foo%2Ehtml"
segmentsTest "http://user:pass@/"                    "http"    "user"    ""                  ""        ""
segmentsTest "http://%25DOM:foobar@domain.com/"      "http"    "%25DOM"  "domain.com"        ""        "/"
segmentsTest "http:\\\\\\\\www.google.com\\\\foo"    "http"    ""        "www.google.com"    ""        "\\\\foo"
segmentsTest "http://www.google.com/asdf#\\\ud800"   "http"    ""        "www.google.com"    ""        "/asdf#\\\ud800"
segmentsTest "http://foo:80/"                        "http"    ""        "foo"               "80"      "/"
segmentsTest "httpa://foo:80/"                       "httpa"   ""        "foo"               "80"      "/"
segmentsTest "http://foo:-80/"                       "http"    ""        "foo"               "-80"     "/"
segmentsTest "https://foo:443/"                      "https"   ""        "foo"               "443"     "/"
segmentsTest "https://foo:80/"                       "https"   ""        "foo"               "80"      "/"
segmentsTest "ftp://foo:21/"                         "ftp"     ""        "foo"               "21"      "/"
segmentsTest "ftp://foo:80/"                         "ftp"     ""        "foo"               "80"      "/"
segmentsTest "gopher://foo:70/"                      "gopher"  ""        "foo"               "70"      "/"
segmentsTest "gopher://foo:443/"                     "gopher"  ""        "foo"               "443"     "/"
segmentsTest "ws://foo:80/"                          "ws"      ""        "foo"               "80"      "/"
segmentsTest "ws://foo:81/"                          "ws"      ""        "foo"               "81"      "/"
segmentsTest "ws://foo:443/"                         "ws"      ""        "foo"               "443"     "/"
segmentsTest "ws://foo:815/"                         "ws"      ""        "foo"               "815"     "/"
segmentsTest "wss://foo:80/"                         "wss"     ""        "foo"               "80"      "/"
segmentsTest "wss://foo:81/"                         "wss"     ""        "foo"               "81"      "/"
segmentsTest "wss://foo:443/"                        "wss"     ""        "foo"               "443"     "/"
segmentsTest "wss://foo:815/"                        "wss"     ""        "foo"               "815"     "/"
segmentsTest "http://example.org/foo/bar"            "http"    ""        "example.org"       ""        "/foo/bar"
segmentsTest "http://user@example.com/"              "http"    "user"    "example.com"       ""        "/"
segmentsTest "http://user:info@/"                    "http"    "user"    ""                  ""        ""
segmentsTest "http://user@/"                         "http"    "user"    ""                  ""        ""
segmentsTest "mailto::foo@bar.com"                   "mailto"  "foo"     "bar.com"           ""        ""
segmentsTest "mailto:foo@bar.com"                    ""        "mailto"  "bar.com"           ""        ""
segmentsTest "$:foo/bar"                             ""        ""        "$"                 "foo"     "/bar"
segmentsTest "http://[2a01:5cc0:1:2::4]"             "http"    ""        "[2a01:5cc0:1:2::4]" ""       ""
segmentsTest "http://[2a01:5cc0:1:2::4]:80"          "http"    ""        "[2a01:5cc0:1:2::4]" "80"     ""
segmentsTest "http://[2a01:5cc0:1:2::4]:80/[test]"   "http"    ""        "[2a01:5cc0:1:2::4]" "80"     "/[test]"

# Test Case                                                     Expected Result
removeCredentialsTest ""                                        ""
removeCredentialsTest "www.jfrog.com"                           "www.jfrog.com"
removeCredentialsTest "www.jfrog.com:80"                        "www.jfrog.com:80"
removeCredentialsTest "http://www.jfrog.com"                    "http://www.jfrog.com"
removeCredentialsTest "http://www.jfrog.com:80"                 "http://www.jfrog.com:80"
removeCredentialsTest "www.jfrog.com/test"                      "www.jfrog.com/test"
removeCredentialsTest "www.jfrog.com:80/test"                   "www.jfrog.com:80/test"
removeCredentialsTest "http://www.jfrog.com/test"               "http://www.jfrog.com/test"
removeCredentialsTest "http://www.jfrog.com:80/test"            "http://www.jfrog.com:80/test"
removeCredentialsTest "user@www.jfrog.com"                      "www.jfrog.com"
removeCredentialsTest "user@www.jfrog.com:80"                   "www.jfrog.com:80"
removeCredentialsTest "http://user@www.jfrog.com"               "http://www.jfrog.com"
removeCredentialsTest "http://user@www.jfrog.com:80"            "http://www.jfrog.com:80"
removeCredentialsTest "user@www.jfrog.com/test"                 "www.jfrog.com/test"
removeCredentialsTest "user@www.jfrog.com:80/test"              "www.jfrog.com:80/test"
removeCredentialsTest "http://user@www.jfrog.com/test"          "http://www.jfrog.com/test"
removeCredentialsTest "http://user@www.jfrog.com:80/test"       "http://www.jfrog.com:80/test"
removeCredentialsTest "user:pass@www.jfrog.com"                 "www.jfrog.com"
removeCredentialsTest "user:pass@www.jfrog.com:80"              "www.jfrog.com:80"
removeCredentialsTest "http://user:pass@www.jfrog.com"          "http://www.jfrog.com"
removeCredentialsTest "http://user:pass@www.jfrog.com:80"       "http://www.jfrog.com:80"
removeCredentialsTest "user:pass@www.jfrog.com/test"            "www.jfrog.com/test"
removeCredentialsTest "user:pass@www.jfrog.com:80/test"         "www.jfrog.com:80/test"
removeCredentialsTest "http://user:pass@www.jfrog.com/test"     "http://www.jfrog.com/test"
removeCredentialsTest "http://user:pass@www.jfrog.com:80/test"  "http://www.jfrog.com:80/test"
removeCredentialsTest "https://user:pa:s%40s@www.jfrog.com"     "https://www.jfrog.com"
removeCredentialsTest "http://user:p\$!'+*a:s%40s@site.com"     "http://site.com"
removeCredentialsTest "http://[2a01:5cc0:1:2::4]"               "http://[2a01:5cc0:1:2::4]"
removeCredentialsTest "http://[2a01:5cc0:1:2::4]:80"            "http://[2a01:5cc0:1:2::4]:80"
removeCredentialsTest "http://[2a01:5cc0:1:2::4]:80/[test]"     "http://[2a01:5cc0:1:2::4]:80/[test]"
removeCredentialsTest "http://user@[2a01:5cc0:1:2::4]"          "http://[2a01:5cc0:1:2::4]"
removeCredentialsTest "http://user@[2a01:5cc0:1:2::4]:80"       "http://[2a01:5cc0:1:2::4]:80"
removeCredentialsTest "http://user@[2a01:5cc0:1:2::4]:80/[test]" "http://[2a01:5cc0:1:2::4]:80/[test]"
removeCredentialsTest "http://u:p@[2a01:5cc0:1:2::4]"           "http://[2a01:5cc0:1:2::4]"
removeCredentialsTest "http://u:p@[2a01:5cc0:1:2::4]:80"        "http://[2a01:5cc0:1:2::4]:80"
removeCredentialsTest "http://u:p@[2a01:5cc0:1:2::4]:80/[test]" "http://[2a01:5cc0:1:2::4]:80/[test]"