#!/bin/bash
set -e

protocolRegex='^([^:\/\\\.]*)(:(:+|[\/\\]+)).*'
credentialsRegex='^([^:\/\\]*)(:?)([^\/\\]*)(@).*'
urlRegex='^((\[[^\s]*\])|([^\/\\#@?:]+)):?([^\/\\#@?:]*)(.*)'

printUsage() {
  echo "
  Usage: urlParse <command> url

  Supported commands:
    --protocol
    --user
    --hostname
    --port
    --path
    --remove_credentials
  "
}

urlParse() {

  url=""

  if [[ $# -ge 2 ]]; then
    url=$2
  fi

  # extract the protocol
  if [[ $url =~ $protocolRegex ]]; then
    protocol="${BASH_REMATCH[1]}"
    protocolLength=$((${#BASH_REMATCH[1]}+${#BASH_REMATCH[2]}))
    url=${url:protocolLength}
  else
    protocol=""
  fi

  # extract credentials
  if [[ $url =~ $credentialsRegex ]]; then
    user="${BASH_REMATCH[1]}"
    password="${BASH_REMATCH[3]}"
    credentialsLength=$((${#BASH_REMATCH[1]}+${#BASH_REMATCH[2]}+${#BASH_REMATCH[3]}+${#BASH_REMATCH[4]}))
    url=${url:credentialsLength}
  else
    user=""
    password=""
  fi

  # extract host, port and path
  if [[ $url =~ $urlRegex ]]; then
    hostname="${BASH_REMATCH[1]}"
    port="${BASH_REMATCH[4]}"
    urlpath="${BASH_REMATCH[5]}"
  else
    hostname=""
    port=""
    urlpath=""
  fi

  case $1 in
    --protocol)
      echo $protocol
      ;;

    --user)
      echo $user
      ;;

    --hostname)
      echo $hostname
      ;;

    --port)
      echo $port
      ;;

    --path)
      echo $urlpath
      ;;

    --remove_credentials)
      result=""
      if [ ! -z "$protocol" ]; then
        result="$protocol://"
      fi
      result="$result$hostname"
      if [ ! -z "$port" ]; then
        result="$result:$port"
      fi
      result="$result$urlpath"
      echo $result
      ;;

    *)
      echo "Invalid command"
      printUsage
      exit 2
      ;;
  esac
}

main() {
  urlParse "$@"
}

main "$@"
