'use strict';

var self = wwwConfig;
module.exports = self;

var async = require('async');
var path = require('path');
var fs = require('fs-extra');
var _ = require('underscore');

var systemYamlHandler = require('./lib/systemYamlHandler.js');

function wwwConfig(params, callback) {
  var bag = {
    runMode: global.config.runMode,
    name: params.name,
    apiAdapter: params.apiAdapter,
    envs: '',
    mounts: '',
    runCommand: ''
  };

  bag.who = util.format('wwwConfig|%s', self.name);
  logger.info(bag.who, 'Starting');

  async.series([
      _getConfigs.bind(null, bag),
      _generateEnvs.bind(null, bag),
      _generateMounts.bind(null, bag),
      _generateRunCommandOnebox.bind(null, bag),
    ],
    function (err) {
      logger.info(bag.who, 'Completed');
      if (err)
        return callback(err);
      callback(null, bag.runCommand);
    }
  );
}

function _getConfigs(bag, next) {
  var who = bag.who + '|' + _getConfigs.name;
  logger.verbose(who, 'Inside');

  systemYamlHandler.get(
    function (err, config) {
      if (err) {
        return next(
          new ActErr(who, ActErr.DataNotFound,
            'Failed to get ' + bag.component, err)
        );
      }

      if (config.core) {
        bag.pipelinesNodeId = config.core.id;
        bag.imageRegistryUrl = config.core.registryUrl;
        bag.httpProxy = config.core.proxy && config.core.proxy.httpProxy;
        bag.httpsProxy = config.core.proxy && config.core.proxy.httpsProxy;
        bag.noProxy = config.core.proxy && config.core.proxy.noProxy;
        bag.noVerifySsl = config.core.noVerifySsl;
        bag.configDir = global.config.hostConfigDir;
        bag.logsDir = global.config.logsDir;
        if (!_.isEmpty(config.core.customCACertsPath))
          bag.customCAEnabled = true
        else
          bag.customCAEnabled = false

        if (config.core.services && config.core.services.www) {
          bag.image = config.core.services.www.image;
          bag.servicePort = config.core.services.www.port;
        } else {
          return next(
            new ActErr(who, ActErr.DataNotFound,
              'Failed to get core.services.www')
          );
        }
      } else {
        return next(
          new ActErr(who, ActErr.DataNotFound,
            'Failed to get core core.services.' + bag.name)
        );
      }

      bag.image = util.format('%s/%s:%s',
        bag.imageRegistryUrl, bag.image, global.config.controlplaneVersion);
      return next();
    }
  );
}

function _generateEnvs(bag, next) {
  var who = bag.who + '|' + _generateEnvs.name;
  logger.verbose(who, 'Inside');

  var composeTemplate = util.format('%s_compose.yml.template', bag.name);
  var composeTemplatePath =
    path.join(global.config.scriptsDir, 'configs', composeTemplate);

  var composeYml = util.format('%s_compose.yml', bag.name);
  var composeYmlPath = path.join(global.config.containerConfigDir,
    'master', composeYml);

  var fileContent = fs.readFileSync(composeTemplatePath).toString();
  var template = _.template(fileContent);

  var ymlContent = template(bag);

  fs.writeFileSync(composeYmlPath, ymlContent, 'utf8');
  logger.info(
    util.format('Successfully generated docker compose file for %s', bag.name));

  return next();
}

function _generateMounts(bag, next) {
  var who = bag.who + '|' + _generateMounts.name;
  logger.verbose(who, 'Inside');

  bag.mounts = '';
  return next();
}

function _generateRunCommandOnebox(bag, next) {
  var who = bag.who + '|' + _generateRunCommandOnebox.name;
  logger.verbose(who, 'Inside');

  var composeYml = util.format('%s_compose.yml', bag.name);
  var composeYmlPath = path.join(global.config.containerConfigDir,
    'master', composeYml);
  var runCommand = util.format('docker-compose ' +
    ' --file %s ' +
    ' up ' +
    ' --force-recreate ' +
    ' --detach %s',
    composeYmlPath,
    bag.name
  );

  bag.runCommand = runCommand;
  return next();
}
