#!/bin/bash
# This script is for installing dependencies on ubuntu distributions
# Usage: ./testInstallerDependencies apiUser apiKey


export ENTPLUS_USERNAME="$1"
export ENTPLUS_APIKEY="$2"

check_args() {
  if [ -z "$ENTPLUS_USERNAME" ]; then
    echo "ENTPLUS_USERNAME is empty"
    exit 1
  fi

  if [ -z "$ENTPLUS_APIKEY" ]; then
    echo "ENTPLUS_APIKEY is empty"
    exit 1
  fi
}

install_dependencies(){
    #install docker taken from https://docs.docker.com/engine/install/ubuntu/
    apt-get update
    apt-get install \
        apt-transport-https \
        ca-certificates \
        curl \
        gnupg-agent \
        software-properties-common
    curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
    add-apt-repository \
    "deb [arch=amd64] https://download.docker.com/linux/ubuntu \
    $(lsb_release -cs) \
    stable"
    apt-get update
    #apt-get install docker-ce=18.06.3~ce~3-0~ubuntu docker-ce-cli=5:19.03.13~3-0~ubuntu-bionic containerd.io
    yes | apt install docker.io

    # ---------------install docker-compose ---------------------
    curl -L "https://github.com/docker/compose/releases/download/1.27.4/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose
    chmod +x /usr/local/bin/docker-compose

    # --- install jq -----
    yes | apt install jq

    # --- install nodejs ---
    wget -qO- https://deb.nodesource.com/setup_12.x | sudo bash -
    sudo apt-get install -y nodejs


    #--- install cli  ---
    JFROG_VERSION=1.38.0 
    wget -nv     https://api.bintray.com/content/jfrog/jfrog-cli-go/"$JFROG_VERSION"/jfrog-cli-linux-amd64/jfrog?bt_package=jfrog-cli-linux-amd64 -O jfrog
    sudo chmod +x jfrog
    mv jfrog /usr/bin/jfrog

    #--- test all ---
    jq --version
    docker --version
    docker-compose --version
    nodejs --version
    jfrog --version

}


configure_docker(){
    # Configure Docker 
    # Fixing up Z-scalar issues with dns record
    #must be root
    #add nameserver 100.64.0.1 to resolv.conf : to be the 1st one in the file
    #steps:
    #1. installing additional resolvconf feature
    #2. adding correct nameserver to head file
    #3. restart the service
  apt-get install resolvconf
  echo nameserver 100.64.0.1 > /etc/resolvconf/resolv.conf.d/head
  resolvconf -u
  systemctl restart systemd-networkd.service
  cat /etc/resolv.conf
  sleep 2
}




docker_login() {
  echo "Logging in to docker"

  if ! which docker &> /dev/null; then
    echo "install docker"
    exit 1
  else
    docker login docker.jfrog.io -u $ENTPLUS_USERNAME -p $ENTPLUS_APIKEY
  fi
}


main() {
  if [ "$EUID" -ne 0 ]
    then echo "Please run as root"
    exit 1
  fi

  check_args
  install_dependencies
  configure_docker
  docker_login
  
}

main